SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO




/*==============================================================*/
/* Database name :  WorkflowGen v7                              */
/* Database type :  Microsoft SQL Server                        */
/* Update date   :  2017/12/05                                  */
/*==============================================================*/



/*  Update trigger "tu_directory" for table "DIRECTORY"  */
CREATE trigger tu_directory on DIRECTORY for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "DIRECTORY" to child "USERS"  */
      if update(ID_DIRECTORY)
      begin
         update USERS
          set   ID_DIRECTORY = i1.ID_DIRECTORY
         from   USERS t2, inserted i1, deleted d1
         where  t2.ID_DIRECTORY = d1.ID_DIRECTORY
          and  (i1.ID_DIRECTORY != d1.ID_DIRECTORY)
      end

      /*  Check and apply change from parent "DIRECTORY" to child "GROUPS"  */
      if update(ID_DIRECTORY)
      begin
         update GROUPS
          set   ID_DIRECTORY = i1.ID_DIRECTORY
         from   GROUPS t2, inserted i1, deleted d1
         where  t2.ID_DIRECTORY = d1.ID_DIRECTORY
          and  (i1.ID_DIRECTORY != d1.ID_DIRECTORY)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_directory" for table "DIRECTORY"  */
CREATE trigger td_directory on DIRECTORY for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  DB_DIR_DEL_DEF_002: Delete child in "USERS"  */
    delete USERS
    from   USERS t2, deleted t1
    where  t2.ID_DIRECTORY = t1.ID_DIRECTORY

    /*  DB_DIR_DEL_DEF_003: Delete child in "GROUPS"  */
    delete GROUPS
    from   GROUPS t2, deleted t1
    where  t2.ID_DIRECTORY = t1.ID_DIRECTORY

    /*  DB_DIR_DEL_DEF_001: Delete child in "WFPARTICIPANT_MAPTO"  */
    delete WFPARTICIPANT_MAPTO
    from   WFPARTICIPANT_MAPTO t2, deleted t1
    where  t2.ID_DIRECTORY = t1.ID_DIRECTORY

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_groups" for table "GROUPS"  */
CREATE trigger ti_groups on GROUPS for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "DIRECTORY" must exist in order to create child in "GROUPS"  */
    if update(ID_DIRECTORY)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DIRECTORY is null)
       if @numnull != @numrows
          if (select count(*)
              from   DIRECTORY t1, inserted t2
              where  t1.ID_DIRECTORY = t2.ID_DIRECTORY) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in DIRECTORY. Failed to create a child row in GROUPS.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_groups" for table "GROUPS"  */
CREATE trigger tu_groups on GROUPS for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "DIRECTORY" must exist in order to modify child in "GROUPS"  */
      if update(ID_DIRECTORY)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DIRECTORY is null)
         if @numnull != @numrows
            if (select count(*)
                from   DIRECTORY t1, inserted t2
                where  t1.ID_DIRECTORY = t2.ID_DIRECTORY) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in DIRECTORY. Failed to modify the child row in GROUPS.'
             goto error
          end
      end
      /*  Check and apply change from parent "GROUPS" to child "USERS_GROUPS"  */
      if update(ID_GROUP)
      begin
         update USERS_GROUPS
          set   ID_GROUP = i1.ID_GROUP
         from   USERS_GROUPS t2, inserted i1, deleted d1
         where  t2.ID_GROUP = d1.ID_GROUP
          and  (i1.ID_GROUP != d1.ID_GROUP)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_groups" for table "GROUPS"  */
CREATE trigger td_groups on GROUPS for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  DB_GROUP_DEL_DIR_001: Delete child in "USERS_GROUPS"  */
    delete USERS_GROUPS
    from   USERS_GROUPS t2, deleted t1
    where  t2.ID_GROUP = t1.ID_GROUP

    /*  DB_GROUP_DEL_DEF_001: Delete child in "WFPARTICIPANT_MAPTO"  */
    delete WFPARTICIPANT_MAPTO
    from   WFPARTICIPANT_MAPTO t2, deleted t1
    where  t2.ID_GROUP = t1.ID_GROUP

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_profile" for table "PROFILE"  */
CREATE trigger tu_profile on PROFILE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "PROFILE" to child "USERS_PROFILE"  */
      if update(ID_PROFILE)
      begin
         update USERS_PROFILE
          set   ID_PROFILE = i1.ID_PROFILE
         from   USERS_PROFILE t2, inserted i1, deleted d1
         where  t2.ID_PROFILE = d1.ID_PROFILE
          and  (i1.ID_PROFILE != d1.ID_PROFILE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_profile" for table "PROFILE"  */
CREATE trigger td_profile on PROFILE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "USERS_PROFILE"  */
    delete USERS_PROFILE
    from   USERS_PROFILE t2, deleted t1
    where  t2.ID_PROFILE = t1.ID_PROFILE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO



SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_users" for table "USERS"  */
CREATE trigger ti_users on USERS for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "DIRECTORY" must exist in order to create child in "USERS"  */
    if update(ID_DIRECTORY)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DIRECTORY is null)
       if @numnull != @numrows
          if (select count(*)
              from   DIRECTORY t1, inserted t2
              where  t1.ID_DIRECTORY = t2.ID_DIRECTORY) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in DIRECTORY. Failed to create a child row in USERS.'
           goto error
        end
    end
    /*  The parent "USERS" must exist in order to create child in "USERS"  */
    if update(ID_USER_MANAGER)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_USER_MANAGER is null)
       if @numnull != @numrows
          if (select count(*)
              from   USERS t1, inserted t2
              where  t1.ID_USER = t2.ID_USER_MANAGER) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in USERS.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_users" for table "USERS"  */
CREATE trigger tu_users on USERS for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "DIRECTORY" must exist in order to modify child in "USERS"  */
      if update(ID_DIRECTORY)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DIRECTORY is null)
         if @numnull != @numrows
            if (select count(*)
                from   DIRECTORY t1, inserted t2
                where  t1.ID_DIRECTORY = t2.ID_DIRECTORY) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in DIRECTORY. Failed to modify the child row in USERS.'
             goto error
          end
      end
      /*  The parent "USERS" must exist in order to modify child in "USERS"  */
      if update(ID_USER_MANAGER)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_USER_MANAGER is null)
         if @numnull != @numrows
            if (select count(*)
                from   USERS t1, inserted t2
                where  t1.ID_USER = t2.ID_USER_MANAGER) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in USERS.'
             goto error
          end
      end
      /*  Check and apply change from parent "USERS" to child "WFACTIVITY_INST"  */
      if update(ID_USER)
      begin
         update WFACTIVITY_INST
          set   ID_USER_REQUESTER = i1.ID_USER
         from   WFACTIVITY_INST t2, inserted i1, deleted d1
         where  t2.ID_USER_REQUESTER = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      /*  Check and apply change from parent "USERS" to child "USERS_GROUPS"  */
      if update(ID_USER)
      begin
         update USERS_GROUPS
          set   ID_USER = i1.ID_USER
         from   USERS_GROUPS t2, inserted i1, deleted d1
         where  t2.ID_USER = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      /*  Check and apply change from parent "USERS" to child "USERS_PROFILE"  */
      if update(ID_USER)
      begin
         update USERS_PROFILE
          set   ID_USER = i1.ID_USER
         from   USERS_PROFILE t2, inserted i1, deleted d1
         where  t2.ID_USER = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      /*  Check and apply change from parent "USERS" to child "WFPROCESS_INST"  */
      if update(ID_USER)
      begin
         update WFPROCESS_INST
          set   ID_USER_REQUESTER = i1.ID_USER
         from   WFPROCESS_INST t2, inserted i1, deleted d1
         where  t2.ID_USER_REQUESTER = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      /*  Check and apply change from parent "USERS" to child "WFPROCESS_INST_RELDATA"  */
      if update(ID_USER)
      begin
         update WFPROCESS_INST_RELDATA
          set   ID_USER_LOCK_BY = i1.ID_USER
         from   WFPROCESS_INST_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_USER_LOCK_BY = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end
      
      /*  Check and apply change from parent "USERS" to child "WFPROCESS_INST_COMMENT"  */
      if update(ID_USER)
      begin
         update WFPROCESS_INST_COMMENT
          set   ID_USER_AUTHOR = i1.ID_USER
         from   WFPROCESS_INST_COMMENT t2, inserted i1, deleted d1
         where  t2.ID_USER_AUTHOR = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      /*  Check and apply change from parent "USERS" to child "WFACTIVITY_INST"  */
      if update(ID_USER)
      begin
         update WFACTIVITY_INST
          set   ID_USER_ASSIGNEE = i1.ID_USER
         from   WFACTIVITY_INST t2, inserted i1, deleted d1
         where  t2.ID_USER_ASSIGNEE = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      /*  Check and apply change from parent "USERS" to child "WFACTIVITY_INST"  */
      if update(ID_USER)
      begin
         update WFACTIVITY_INST
          set   ID_USER_ASSIGNED_BY = i1.ID_USER
         from   WFACTIVITY_INST t2, inserted i1, deleted d1
         where  t2.ID_USER_ASSIGNED_BY = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      /*  Check and apply change from parent "USERS" to child "WFACTIVITY_INST_MAPTO"  */
      if update(ID_USER)
      begin
         update WFACTIVITY_INST_MAPTO
          set   ID_USER = i1.ID_USER
         from   WFACTIVITY_INST_MAPTO t2, inserted i1, deleted d1
         where  t2.ID_USER = d1.ID_USER
          and  (i1.ID_USER != d1.ID_USER)
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_users" for table "USERS"  */
CREATE trigger td_users on USERS for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return


    /*  DB_USER_DEL_DIR_003: Delete child in "USERS_GROUPS"  */
    delete USERS_GROUPS
    from   USERS_GROUPS t2, deleted t1
    where  t2.ID_USER = t1.ID_USER

    /*  DB_USER_DEL_DIR_002: Delete child in "USERS_PROFILE"  */
    delete USERS_PROFILE
    from   USERS_PROFILE t2, deleted t1
    where  t2.ID_USER = t1.ID_USER

    /*  DB_USER_DEL_REQ_001: Delete child in "WFPROCESS_INST"  */
    delete WFPROCESS_INST
    from   WFPROCESS_INST t2, deleted t1
    where  t2.ID_USER_REQUESTER = t1.ID_USER

    /*  DB_USER_DEL_REQ_002: Delete child in "WFPROCESS_INST"  */
    delete WFPROCESS_INST
    from   WFPROCESS_INST t2, deleted t1
    where  t2.ID_USER_REQUESTER_REAL = t1.ID_USER

    /*  DB_USER_DEL_REQ_003: Delete child in "WFPROCESS_INST"  */
    delete WFPROCESS_INST
    from   WFPROCESS_INST t2, deleted t1
    where  t2.ID_USER_ABORTED = t1.ID_USER

    /*  DB_USER_DEL_REQ_004: Delete child in "WFPROCESS_INST_RELDATA"  */
    delete WFPROCESS_INST_RELDATA
    from   WFPROCESS_INST_RELDATA t2, deleted t1
    where  t2.ID_USER_LOCK_BY = t1.ID_USER
    
    /*  DB_USER_DEL_REQ_010: Delete child in "WFPROCESS_INST_COMMENT"  */
    delete WFPROCESS_INST_COMMENT
    from   WFPROCESS_INST_COMMENT t2, deleted t1
    where  t2.ID_USER_AUTHOR = t1.ID_USER

    /*  DB_USER_DEL_REQ_005: Delete child in "WFACTIVITY_INST"  */
    delete WFACTIVITY_INST
    from   WFACTIVITY_INST t2, deleted t1
    where  t2.ID_USER_REQUESTER = t1.ID_USER

    /*  DB_USER_DEL_REQ_006: Delete child in "WFACTIVITY_INST"  */
    delete WFACTIVITY_INST
    from   WFACTIVITY_INST t2, deleted t1
    where  t2.ID_USER_ASSIGNEE = t1.ID_USER

    /*  DB_USER_DEL_REQ_007: Delete child in "WFACTIVITY_INST"  */
    delete WFACTIVITY_INST
    from   WFACTIVITY_INST t2, deleted t1
    where  t2.ID_USER_ASSIGNEE_REAL = t1.ID_USER

    /*  DB_USER_DEL_REQ_008: Delete child in "WFACTIVITY_INST"  */
    delete WFACTIVITY_INST
    from   WFACTIVITY_INST t2, deleted t1
    where  t2.ID_USER_ASSIGNED_BY = t1.ID_USER

    /*  DB_USER_DEL_REQ_009: Delete child in "WFACTIVITY_INST_MAPTO"  */
    delete WFACTIVITY_INST_MAPTO
    from   WFACTIVITY_INST_MAPTO t2, deleted t1
    where  t2.ID_USER = t1.ID_USER

    /*  DB_USER_DEL_DEF_003: Delete child in "WFPARTICIPANT_MAPTO"  */
    delete WFPARTICIPANT_MAPTO
    from   WFPARTICIPANT_MAPTO t2, deleted t1
    where  t2.ID_USER = t1.ID_USER

    /*  DB_USER_DEL_DIR_004: Delete child in "USERS_VIEWS"  */
    delete USERS_VIEWS
    from   USERS_VIEWS t2, deleted t1
    where  t2.ID_USER = t1.ID_USER

    /*  DB_USER_DEL_DIR_005: Delete child in "WFDELEGATE"  */
    delete WFDELEGATE
    from   WFDELEGATE t2, deleted t1
    where  t2.ID_USER = t1.ID_USER

    /*  DB_USER_DEL_DIR_006: Delete child in "WFDELEGATE"  */
    delete WFDELEGATE
    from   WFDELEGATE t2, deleted t1
    where  t2.ID_USER_DELEGATE = t1.ID_USER

	 /*  Delete child in "FAVORITE"  */
	 /*  This operation is needed to avoid the multiple cascade paths SQL Server issue (present in SQL Server 2016 and previous versions)   */
    delete FAVORITE
    from   FAVORITE t2, deleted t1
    where  t2.ID_USER_FAVORITE = t1.ID_USER

    /*  DB_USER_DEL_DIR_001: Update ID_USER_MANAGER to NULL in child "USERS"  */
    update USERS
    set    ID_USER_MANAGER = NULL
    from   USERS t2, deleted t1
    where  t2.ID_USER_MANAGER = t1.ID_USER

    /*  DB_USER_DEL_DEF_001: Update ID_USER_CREATION to NULL in child "WFPROCESS"  */
    update WFPROCESS
    set    ID_USER_CREATION = NULL
    from   WFPROCESS t2, deleted t1
    where  t2.ID_USER_CREATION = t1.ID_USER

    /*  DB_USER_DEL_DEF_002: Update ID_USER_UPDATE to NULL in child "WFPROCESS"  */
    update WFPROCESS
    set    ID_USER_UPDATE = NULL
    from   WFPROCESS t2, deleted t1
    where  t2.ID_USER_UPDATE = t1.ID_USER

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_users_groups" for table "USERS_GROUPS"  */
CREATE trigger ti_users_groups on USERS_GROUPS for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "USERS" must exist in order to create child in "USERS_GROUPS"  */
    if update(ID_USER)
    begin
       if (select count(*)
           from   USERS t1, inserted t2
           where  t1.ID_USER = t2.ID_USER) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in USERS_GROUPS.'
           goto error
        end
    end
    /*  The parent "GROUPS" must exist in order to create child in "USERS_GROUPS"  */
    if update(ID_GROUP)
    begin
       if (select count(*)
           from   GROUPS t1, inserted t2
           where  t1.ID_GROUP = t2.ID_GROUP) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in GROUPS. Failed to create a child row in USERS_GROUPS.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_users_groups" for table "USERS_GROUPS"  */
CREATE trigger tu_users_groups on USERS_GROUPS for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "USERS" must exist in order to modify child in "USERS_GROUPS"  */
      if update(ID_USER)
      begin
         if (select count(*)
             from   USERS t1, inserted t2
             where  t1.ID_USER = t2.ID_USER) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in USERS_GROUPS.'
             goto error
          end
      end
      /*  The parent "GROUPS" must exist in order to modify child in "USERS_GROUPS"  */
      if update(ID_GROUP)
      begin
         if (select count(*)
             from   GROUPS t1, inserted t2
             where  t1.ID_GROUP = t2.ID_GROUP) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in GROUPS. Failed to modify the child row in USERS_GROUPS.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO



SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_users_profile" for table "USERS_PROFILE"  */
CREATE trigger ti_users_profile on USERS_PROFILE for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "USERS" must exist in order to create child in "USERS_PROFILE"  */
    if update(ID_USER)
    begin
       if (select count(*)
           from   USERS t1, inserted t2
           where  t1.ID_USER = t2.ID_USER) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in USERS_PROFILE.'
           goto error
        end
    end
    /*  The parent "PROFILE" must exist in order to create child in "USERS_PROFILE"  */
    if update(ID_PROFILE)
    begin
       if (select count(*)
           from   PROFILE t1, inserted t2
           where  t1.ID_PROFILE = t2.ID_PROFILE) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in PROFILE. Failed to create a child row in USERS_PROFILE.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_users_profile" for table "USERS_PROFILE"  */
CREATE trigger tu_users_profile on USERS_PROFILE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "USERS" must exist in order to modify child in "USERS_PROFILE"  */
      if update(ID_USER)
      begin
         if (select count(*)
             from   USERS t1, inserted t2
             where  t1.ID_USER = t2.ID_USER) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in USERS_PROFILE.'
             goto error
          end
      end
      /*  The parent "PROFILE" must exist in order to modify child in "USERS_PROFILE"  */
      if update(ID_PROFILE)
      begin
         if (select count(*)
             from   PROFILE t1, inserted t2
             where  t1.ID_PROFILE = t2.ID_PROFILE) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in PROFILE. Failed to modify the child row in USERS_PROFILE.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfactivity" for table "WFACTIVITY"  */
CREATE trigger ti_wfactivity on WFACTIVITY for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS" must exist in order to create child in "WFACTIVITY"  */
    if update(ID_PROCESS)
    begin
       if (select count(*)
           from   WFPROCESS t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFACTIVITY.'
           goto error
        end
    end
    /*  The parent "WFPARTICIPANT" must exist in order to create child in "WFACTIVITY"  */
    if update(ID_PARTICIPANT)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PARTICIPANT is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPARTICIPANT t1, inserted t2
              where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to create a child row in WFACTIVITY.'
           goto error
        end
    end
    /*  The parent "WFPROCESS_RELDATA" must exist in order to create child in "WFACTIVITY"  */
    if update(ID_PROCESS_ASSIGN) or
       update(ID_RELDATA_ASSIGN)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS_ASSIGN is null
                           and   ID_RELDATA_ASSIGN is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPROCESS_RELDATA t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS_ASSIGN
               and   t1.ID_RELDATA = t2.ID_RELDATA_ASSIGN) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS_RELDATA. Failed to create a child row in WFACTIVITY.'
           goto error
        end
    end
    /*  The parent "WFAPPLICATION" must exist in order to create child in "WFACTIVITY"  */
    if update(ID_APPLICATION)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_APPLICATION is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFAPPLICATION t1, inserted t2
              where  t1.ID_APPLICATION = t2.ID_APPLICATION) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFAPPLICATION. Failed to create a child row in WFACTIVITY.'
           goto error
        end
    end
    /*  The parent "WFACTIVITY_TYPE" must exist in order to create child in "WFACTIVITY"  */
    if update(ID_ACTIVITY_TYPE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_ACTIVITY_TYPE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFACTIVITY_TYPE t1, inserted t2
              where  t1.ID_ACTIVITY_TYPE = t2.ID_ACTIVITY_TYPE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY_TYPE. Failed to create a child row in WFACTIVITY.'
           goto error
        end
    end
    /*  The parent "WFACTIVITY_ASSIGN_TYPE" must exist in order to create child in "WFACTIVITY"  */
    if update(ID_ASSIGN_TYPE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_ASSIGN_TYPE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFACTIVITY_ASSIGN_TYPE t1, inserted t2
              where  t1.ID_ASSIGN_TYPE = t2.ID_ASSIGN_TYPE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY_ASSIGN_TYPE. Failed to create a child row in WFACTIVITY.'
           goto error
        end
    end
    /*  The parent "WFDURATION_UNIT" must exist in order to create child in "WFACTIVITY"  */
    if update(ID_DURATION_UNIT)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DURATION_UNIT is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFDURATION_UNIT t1, inserted t2
              where  t1.ID_DURATION_UNIT = t2.ID_DURATION_UNIT) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFDURATION_UNIT. Failed to create a child row in WFACTIVITY.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity" for table "WFACTIVITY"  */
CREATE trigger tu_wfactivity on WFACTIVITY for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS" must exist in order to modify child in "WFACTIVITY"  */
      if update(ID_PROCESS)
      begin
         if (select count(*)
             from   WFPROCESS t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFACTIVITY.'
             goto error
          end
      end
      /*  The parent "WFPARTICIPANT" must exist in order to modify child in "WFACTIVITY"  */
      if update(ID_PARTICIPANT)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PARTICIPANT is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPARTICIPANT t1, inserted t2
                where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to modify the child row in WFACTIVITY.'
             goto error
          end
      end
      /*  The parent "WFPROCESS_RELDATA" must exist in order to modify child in "WFACTIVITY"  */
      if update(ID_PROCESS_ASSIGN) or
         update(ID_RELDATA_ASSIGN)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS_ASSIGN is null
                             and   ID_RELDATA_ASSIGN is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPROCESS_RELDATA t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS_ASSIGN
                 and   t1.ID_RELDATA = t2.ID_RELDATA_ASSIGN) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS_RELDATA. Failed to modify the child row in WFACTIVITY.'
             goto error
          end
      end
      /*  The parent "WFAPPLICATION" must exist in order to modify child in "WFACTIVITY"  */
      if update(ID_APPLICATION)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_APPLICATION is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFAPPLICATION t1, inserted t2
                where  t1.ID_APPLICATION = t2.ID_APPLICATION) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFAPPLICATION. Failed to modify the child row in WFACTIVITY.'
             goto error
          end
      end
      /*  The parent "WFACTIVITY_TYPE" must exist in order to modify child in "WFACTIVITY"  */
      if update(ID_ACTIVITY_TYPE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_ACTIVITY_TYPE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFACTIVITY_TYPE t1, inserted t2
                where  t1.ID_ACTIVITY_TYPE = t2.ID_ACTIVITY_TYPE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY_TYPE. Failed to modify the child row in WFACTIVITY.'
             goto error
          end
      end
      /*  The parent "WFACTIVITY_ASSIGN_TYPE" must exist in order to modify child in "WFACTIVITY"  */
      if update(ID_ASSIGN_TYPE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_ASSIGN_TYPE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFACTIVITY_ASSIGN_TYPE t1, inserted t2
                where  t1.ID_ASSIGN_TYPE = t2.ID_ASSIGN_TYPE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY_ASSIGN_TYPE. Failed to modify the child row in WFACTIVITY.'
             goto error
          end
      end
      /*  The parent "WFDURATION_UNIT" must exist in order to modify child in "WFACTIVITY"  */
      if update(ID_DURATION_UNIT)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DURATION_UNIT is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFDURATION_UNIT t1, inserted t2
                where  t1.ID_DURATION_UNIT = t2.ID_DURATION_UNIT) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFDURATION_UNIT. Failed to modify the child row in WFACTIVITY.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFACTIVITY" to child "WFPROCESS_TRANSITION"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         update WFPROCESS_TRANSITION
          set   ID_PROCESS_FROM = i1.ID_PROCESS,
                ID_ACTIVITY_FROM = i1.ID_ACTIVITY
         from   WFPROCESS_TRANSITION t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_FROM = d1.ID_PROCESS
          and   t2.ID_ACTIVITY_FROM = d1.ID_ACTIVITY
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_ACTIVITY != d1.ID_ACTIVITY)
      end

      /*  Check and apply change from parent "WFACTIVITY" to child "WFPROCESS_TRANSITION"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         update WFPROCESS_TRANSITION
          set   ID_PROCESS_TO = i1.ID_PROCESS,
                ID_ACTIVITY_TO = i1.ID_ACTIVITY
         from   WFPROCESS_TRANSITION t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_TO = d1.ID_PROCESS
          and   t2.ID_ACTIVITY_TO = d1.ID_ACTIVITY
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_ACTIVITY != d1.ID_ACTIVITY)
      end

      /*  Check and apply change from parent "WFACTIVITY" to child "WFACTIVITY_PARAM"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         update WFACTIVITY_PARAM
          set   ID_PROCESS = i1.ID_PROCESS,
                ID_ACTIVITY = i1.ID_ACTIVITY
         from   WFACTIVITY_PARAM t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and   t2.ID_ACTIVITY = d1.ID_ACTIVITY
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_ACTIVITY != d1.ID_ACTIVITY)
      end

      /*  Check and apply change from parent "WFACTIVITY" to child "WFACTIVITY_NOTIFY"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         update WFACTIVITY_NOTIFY
          set   ID_PROCESS = i1.ID_PROCESS,
                ID_ACTIVITY = i1.ID_ACTIVITY
         from   WFACTIVITY_NOTIFY t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and   t2.ID_ACTIVITY = d1.ID_ACTIVITY
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_ACTIVITY != d1.ID_ACTIVITY)
      end

      /*  Check and apply change from parent "WFACTIVITY" to child "WFACTIVITY_NOTIFY"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         update WFACTIVITY_NOTIFY
          set   ID_PROCESS_NOTIFY = i1.ID_PROCESS,
                ID_ACTIVITY_NOTIFY = i1.ID_ACTIVITY
         from   WFACTIVITY_NOTIFY t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_NOTIFY = d1.ID_PROCESS
          and   t2.ID_ACTIVITY_NOTIFY = d1.ID_ACTIVITY
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_ACTIVITY != d1.ID_ACTIVITY)
      end

      /*  Check and apply change from parent "WFACTIVITY" to child "WFACTIVITY_INST"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         update WFACTIVITY_INST
          set   ID_PROCESS = i1.ID_PROCESS,
                ID_ACTIVITY = i1.ID_ACTIVITY
         from   WFACTIVITY_INST t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and   t2.ID_ACTIVITY = d1.ID_ACTIVITY
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_ACTIVITY != d1.ID_ACTIVITY)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfactivity" for table "WFACTIVITY"  */
CREATE trigger td_wfactivity on WFACTIVITY for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_TRANSITION"  */
    delete WFPROCESS_TRANSITION
    from   WFPROCESS_TRANSITION t2, deleted t1
    where  t2.ID_PROCESS_FROM = t1.ID_PROCESS
     and   t2.ID_ACTIVITY_FROM = t1.ID_ACTIVITY

    /*  Delete child in "WFPROCESS_TRANSITION"  */
    delete WFPROCESS_TRANSITION
    from   WFPROCESS_TRANSITION t2, deleted t1
    where  t2.ID_PROCESS_TO = t1.ID_PROCESS
     and   t2.ID_ACTIVITY_TO = t1.ID_ACTIVITY

    /*  Delete child in "WFACTIVITY_PARAM"  */
    delete WFACTIVITY_PARAM
    from   WFACTIVITY_PARAM t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS
     and   t2.ID_ACTIVITY = t1.ID_ACTIVITY

    /*  Delete child in "WFACTIVITY_NOTIFY"  */
    delete WFACTIVITY_NOTIFY
    from   WFACTIVITY_NOTIFY t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS
     and   t2.ID_ACTIVITY = t1.ID_ACTIVITY

    /*  Delete child in "WFACTIVITY_NOTIFY"  */
    delete WFACTIVITY_NOTIFY
    from   WFACTIVITY_NOTIFY t2, deleted t1
    where  t2.ID_PROCESS_NOTIFY = t1.ID_PROCESS
     and   t2.ID_ACTIVITY_NOTIFY = t1.ID_ACTIVITY

    /*  Delete child in "WFACTIVITY_INST"  */
    delete WFACTIVITY_INST
    from   WFACTIVITY_INST t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS
     and   t2.ID_ACTIVITY = t1.ID_ACTIVITY


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity_assign_type" for table "WFACTIVITY_ASSIGN_TYPE"  */
CREATE trigger tu_wfactivity_assign_type on WFACTIVITY_ASSIGN_TYPE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFACTIVITY_ASSIGN_TYPE" to child "WFACTIVITY"  */
      if update(ID_ASSIGN_TYPE)
      begin
         update WFACTIVITY
          set   ID_ASSIGN_TYPE = i1.ID_ASSIGN_TYPE
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_ASSIGN_TYPE = d1.ID_ASSIGN_TYPE
          and  (i1.ID_ASSIGN_TYPE != d1.ID_ASSIGN_TYPE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfactivity_assign_type" for table "WFACTIVITY_ASSIGN_TYPE"  */
CREATE trigger td_wfactivity_assign_type on WFACTIVITY_ASSIGN_TYPE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_ASSIGN_TYPE = t1.ID_ASSIGN_TYPE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfactivity_inst" for table "WFACTIVITY_INST"  */
CREATE trigger ti_wfactivity_inst on WFACTIVITY_INST for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS_INST" must exist in order to create child in "WFACTIVITY_INST"  */
    if update(ID_PROCESS_INST)
    begin
       if (select count(*)
           from   WFPROCESS_INST t1, inserted t2
           where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS_INST. Failed to create a child row in WFACTIVITY_INST.'
           goto error
        end
    end
    /*  The parent "USERS" must exist in order to create child in "WFACTIVITY_INST"  */
    if update(ID_USER_REQUESTER)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_USER_REQUESTER is null)
       if @numnull != @numrows
          if (select count(*)
              from   USERS t1, inserted t2
              where  t1.ID_USER = t2.ID_USER_REQUESTER) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in WFACTIVITY_INST.'
           goto error
        end
    end
    /*  The parent "WFSUBSTATE" must exist in order to create child in "WFACTIVITY_INST"  */
    if update(ID_STATE) or
       update(ID_SUBSTATE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_STATE is null
                           and   ID_SUBSTATE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFSUBSTATE t1, inserted t2
              where  t1.ID_STATE = t2.ID_STATE
               and   t1.ID_SUBSTATE = t2.ID_SUBSTATE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFSUBSTATE. Failed to create a child row in WFACTIVITY_INST.'
           goto error
        end
    end
    /*  The parent "WFACTIVITY" must exist in order to create child in "WFACTIVITY_INST"  */
    if update(ID_PROCESS) or
       update(ID_ACTIVITY)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS is null
                           and   ID_ACTIVITY is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFACTIVITY t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS
               and   t1.ID_ACTIVITY = t2.ID_ACTIVITY) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY. Failed to create a child row in WFACTIVITY_INST.'
           goto error
        end
    end
    /*  The parent "USERS" must exist in order to create child in "WFACTIVITY_INST"  */
    if update(ID_USER_ASSIGNEE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_USER_ASSIGNEE is null)
       if @numnull != @numrows
          if (select count(*)
              from   USERS t1, inserted t2
              where  t1.ID_USER = t2.ID_USER_ASSIGNEE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in WFACTIVITY_INST.'
           goto error
        end
    end
    /*  The parent "USERS" must exist in order to create child in "WFACTIVITY_INST"  */
    if update(ID_USER_ASSIGNED_BY)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_USER_ASSIGNED_BY is null)
       if @numnull != @numrows
          if (select count(*)
              from   USERS t1, inserted t2
              where  t1.ID_USER = t2.ID_USER_ASSIGNED_BY) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in WFACTIVITY_INST.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity_inst" for table "WFACTIVITY_INST"  */
CREATE trigger tu_wfactivity_inst on WFACTIVITY_INST for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS_INST" must exist in order to modify child in "WFACTIVITY_INST"  */
      if update(ID_PROCESS_INST)
      begin
         if (select count(*)
             from   WFPROCESS_INST t1, inserted t2
             where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS_INST. Failed to modify the child row in WFACTIVITY_INST.'
             goto error
          end
      end
      /*  The parent "USERS" must exist in order to modify child in "WFACTIVITY_INST"  */
      if update(ID_USER_REQUESTER)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_USER_REQUESTER is null)
         if @numnull != @numrows
            if (select count(*)
                from   USERS t1, inserted t2
                where  t1.ID_USER = t2.ID_USER_REQUESTER) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in WFACTIVITY_INST.'
             goto error
          end
      end
      /*  The parent "WFSUBSTATE" must exist in order to modify child in "WFACTIVITY_INST"  */
      if update(ID_STATE) or
         update(ID_SUBSTATE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_STATE is null
                             and   ID_SUBSTATE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFSUBSTATE t1, inserted t2
                where  t1.ID_STATE = t2.ID_STATE
                 and   t1.ID_SUBSTATE = t2.ID_SUBSTATE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFSUBSTATE. Failed to modify the child row in WFACTIVITY_INST.'
             goto error
          end
      end
      /*  The parent "WFACTIVITY" must exist in order to modify child in "WFACTIVITY_INST"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS is null
                             and   ID_ACTIVITY is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFACTIVITY t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS
                 and   t1.ID_ACTIVITY = t2.ID_ACTIVITY) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY. Failed to modify the child row in WFACTIVITY_INST.'
             goto error
          end
      end
      /*  The parent "USERS" must exist in order to modify child in "WFACTIVITY_INST"  */
      if update(ID_USER_ASSIGNEE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_USER_ASSIGNEE is null)
         if @numnull != @numrows
            if (select count(*)
                from   USERS t1, inserted t2
                where  t1.ID_USER = t2.ID_USER_ASSIGNEE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in WFACTIVITY_INST.'
             goto error
          end
      end
      /*  The parent "USERS" must exist in order to modify child in "WFACTIVITY_INST"  */
      if update(ID_USER_ASSIGNED_BY)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_USER_ASSIGNED_BY is null)
         if @numnull != @numrows
            if (select count(*)
                from   USERS t1, inserted t2
                where  t1.ID_USER = t2.ID_USER_ASSIGNED_BY) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in WFACTIVITY_INST.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFACTIVITY_INST" to child "WFACTIVITY_INST_RELDATA"  */
      if update(ID_PROCESS_INST) or
         update(ID_ACTIVITY_INST)
      begin
         update WFACTIVITY_INST_RELDATA
          set   ID_PROCESS_INST = i1.ID_PROCESS_INST,
                ID_ACTIVITY_INST = i1.ID_ACTIVITY_INST
         from   WFACTIVITY_INST_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_INST = d1.ID_PROCESS_INST
          and   t2.ID_ACTIVITY_INST = d1.ID_ACTIVITY_INST
          and  (i1.ID_PROCESS_INST != d1.ID_PROCESS_INST or
                i1.ID_ACTIVITY_INST != d1.ID_ACTIVITY_INST)
      end

      /*  Check and apply change from parent "WFACTIVITY_INST" to child "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
      if update(ID_PROCESS_INST) or
         update(ID_ACTIVITY_INST)
      begin
         update WFACTIVITY_INST_NOTIFY_OVERDUE
          set   ID_PROCESS_INST = i1.ID_PROCESS_INST,
                ID_ACTIVITY_INST = i1.ID_ACTIVITY_INST
         from   WFACTIVITY_INST_NOTIFY_OVERDUE t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_INST = d1.ID_PROCESS_INST
          and   t2.ID_ACTIVITY_INST = d1.ID_ACTIVITY_INST
          and  (i1.ID_PROCESS_INST != d1.ID_PROCESS_INST or
                i1.ID_ACTIVITY_INST != d1.ID_ACTIVITY_INST)
      end

      /*  Check and apply change from parent "WFACTIVITY_INST" to child "WFACTIVITY_INST_MAPTO"  */
      if update(ID_PROCESS_INST) or
         update(ID_ACTIVITY_INST)
      begin
         update WFACTIVITY_INST_MAPTO
          set   ID_PROCESS_INST = i1.ID_PROCESS_INST,
                ID_ACTIVITY_INST = i1.ID_ACTIVITY_INST
         from   WFACTIVITY_INST_MAPTO t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_INST = d1.ID_PROCESS_INST
          and   t2.ID_ACTIVITY_INST = d1.ID_ACTIVITY_INST
          and  (i1.ID_PROCESS_INST != d1.ID_PROCESS_INST or
                i1.ID_ACTIVITY_INST != d1.ID_ACTIVITY_INST)
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfactivity_inst" for table "WFACTIVITY_INST"  */
CREATE trigger td_wfactivity_inst on WFACTIVITY_INST for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFACTIVITY_INST_RELDATA"  */
    delete WFACTIVITY_INST_RELDATA
    from   WFACTIVITY_INST_RELDATA t2, deleted t1
    where  t2.ID_PROCESS_INST = t1.ID_PROCESS_INST
     and   t2.ID_ACTIVITY_INST = t1.ID_ACTIVITY_INST

    /*  Delete child in "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
    delete WFACTIVITY_INST_NOTIFY_OVERDUE
    from   WFACTIVITY_INST_NOTIFY_OVERDUE t2, deleted t1
    where  t2.ID_PROCESS_INST = t1.ID_PROCESS_INST
     and   t2.ID_ACTIVITY_INST = t1.ID_ACTIVITY_INST

    /*  Delete child in "WFACTIVITY_INST_MAPTO"  */
    delete WFACTIVITY_INST_MAPTO
    from   WFACTIVITY_INST_MAPTO t2, deleted t1
    where  t2.ID_PROCESS_INST = t1.ID_PROCESS_INST
     and   t2.ID_ACTIVITY_INST = t1.ID_ACTIVITY_INST

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO



SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfactivity_inst_mapto" for table "WFACTIVITY_INST_MAPTO"  */
CREATE trigger ti_wfactivity_inst_mapto on WFACTIVITY_INST_MAPTO for insert as
begin
    declare  
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFACTIVITY_INST" must exist in order to create child in "WFACTIVITY_INST_MAPTO"  */
    if update(ID_PROCESS_INST) or
       update(ID_ACTIVITY_INST)
    begin
       if (select count(*)
           from   WFACTIVITY_INST t1, inserted t2
           where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST
            and   t1.ID_ACTIVITY_INST = t2.ID_ACTIVITY_INST) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY_INST. Failed to create a child row in WFACTIVITY_INST_MAPTO.'
           goto error
        end
    end
    /*  The parent "USERS" must exist in order to create child in "WFACTIVITY_INST_MAPTO"  */
    if update(ID_USER)
    begin
       if (select count(*)
           from   USERS t1, inserted t2
           where  t1.ID_USER = t2.ID_USER) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in WFACTIVITY_INST_MAPTO.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO



SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO




/*  Update trigger "tu_wfactivity_inst_mapto" for table "WFACTIVITY_INST_MAPTO"  */
CREATE trigger tu_wfactivity_inst_mapto on WFACTIVITY_INST_MAPTO for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFACTIVITY_INST" must exist in order to modify child in "WFACTIVITY_INST_MAPTO"  */
      if update(ID_PROCESS_INST) or
         update(ID_ACTIVITY_INST)
      begin
         if (select count(*)
             from   WFACTIVITY_INST t1, inserted t2
             where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST
              and   t1.ID_ACTIVITY_INST = t2.ID_ACTIVITY_INST) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY_INST. Failed to modify the child row in WFACTIVITY_INST_MAPTO.'
             goto error
          end
      end
      /*  The parent "USERS" must exist in order to modify child in "WFACTIVITY_INST_MAPTO"  */
      if update(ID_USER)
      begin
         if (select count(*)
             from   USERS t1, inserted t2
             where  t1.ID_USER = t2.ID_USER) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in WFACTIVITY_INST_MAPTO.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO



SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfactivity_inst_notify_overdue" for table "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
CREATE trigger ti_wfactivity_inst_notify_overdue on WFACTIVITY_INST_NOTIFY_OVERDUE for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFACTIVITY_NOTIFY" must exist in order to create child in "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
    if update(ID_PROCESS) or
       update(ID_ACTIVITY) or
       update(NUM_NOTIFY)
    begin
       if (select count(*)
           from   WFACTIVITY_NOTIFY t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS
            and   t1.ID_ACTIVITY = t2.ID_ACTIVITY
            and   t1.NUM_NOTIFY = t2.NUM_NOTIFY) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY_NOTIFY. Failed to create a child row in WFACTIVITY_INST_NOTIFY_OVERDUE.'
           goto error
        end
    end
    /*  The parent "WFACTIVITY_INST" must exist in order to create child in "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
    if update(ID_PROCESS_INST) or
       update(ID_ACTIVITY_INST)
    begin
       if (select count(*)
           from   WFACTIVITY_INST t1, inserted t2
           where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST
            and   t1.ID_ACTIVITY_INST = t2.ID_ACTIVITY_INST) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY_INST. Failed to create a child row in WFACTIVITY_INST_NOTIFY_OVERDUE.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity_inst_notify_overdue" for table "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
CREATE trigger tu_wfactivity_inst_notify_overdue on WFACTIVITY_INST_NOTIFY_OVERDUE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFACTIVITY_NOTIFY" must exist in order to modify child in "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY) or
         update(NUM_NOTIFY)
      begin
         if (select count(*)
             from   WFACTIVITY_NOTIFY t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS
              and   t1.ID_ACTIVITY = t2.ID_ACTIVITY
              and   t1.NUM_NOTIFY = t2.NUM_NOTIFY) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY_NOTIFY. Failed to modify the child row in WFACTIVITY_INST_NOTIFY_OVERDUE.'
             goto error
          end
      end
      /*  The parent "WFACTIVITY_INST" must exist in order to modify child in "WFACTIVITY_INST_NOTIFY_OVERDUE"  */
      if update(ID_PROCESS_INST) or
         update(ID_ACTIVITY_INST)
      begin
         if (select count(*)
             from   WFACTIVITY_INST t1, inserted t2
             where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST
              and   t1.ID_ACTIVITY_INST = t2.ID_ACTIVITY_INST) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY_INST. Failed to modify the child row in WFACTIVITY_INST_NOTIFY_OVERDUE.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfactivity_inst_reldata" for table "WFACTIVITY_INST_RELDATA"  */
CREATE trigger ti_wfactivity_inst_reldata on WFACTIVITY_INST_RELDATA for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFACTIVITY_INST" must exist in order to create child in "WFACTIVITY_INST_RELDATA"  */
    if update(ID_PROCESS_INST) or
       update(ID_ACTIVITY_INST)
    begin
       if (select count(*)
           from   WFACTIVITY_INST t1, inserted t2
           where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST
            and   t1.ID_ACTIVITY_INST = t2.ID_ACTIVITY_INST) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY_INST. Failed to create a child row in WFACTIVITY_INST_RELDATA.'
           goto error
        end
    end
    /*  The parent "WFDATASET" must exist in order to create child in "WFACTIVITY_INST_RELDATA"  */
    if update(ID_DATASET)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DATASET is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFDATASET t1, inserted t2
              where  t1.ID_DATASET = t2.ID_DATASET) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFDATASET. Failed to create a child row in WFACTIVITY_INST_RELDATA.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity_inst_reldata" for table "WFACTIVITY_INST_RELDATA"  */
CREATE trigger tu_wfactivity_inst_reldata on WFACTIVITY_INST_RELDATA for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFACTIVITY_INST" must exist in order to modify child in "WFACTIVITY_INST_RELDATA"  */
      if update(ID_PROCESS_INST) or
         update(ID_ACTIVITY_INST)
      begin
         if (select count(*)
             from   WFACTIVITY_INST t1, inserted t2
             where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST
              and   t1.ID_ACTIVITY_INST = t2.ID_ACTIVITY_INST) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY_INST. Failed to modify the child row in WFACTIVITY_INST_RELDATA.'
             goto error
          end
      end
      /*  The parent "WFDATASET" must exist in order to modify child in "WFACTIVITY_INST_RELDATA"  */
      if update(ID_DATASET)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DATASET is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFDATASET t1, inserted t2
                where  t1.ID_DATASET = t2.ID_DATASET) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFDATASET. Failed to modify the child row in WFACTIVITY_INST_RELDATA.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfactivity_notify" for table "WFACTIVITY_NOTIFY"  */
CREATE trigger ti_wfactivity_notify on WFACTIVITY_NOTIFY for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFACTIVITY" must exist in order to create child in "WFACTIVITY_NOTIFY"  */
    if update(ID_PROCESS) or
       update(ID_ACTIVITY)
    begin
       if (select count(*)
           from   WFACTIVITY t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS
            and   t1.ID_ACTIVITY = t2.ID_ACTIVITY) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY. Failed to create a child row in WFACTIVITY_NOTIFY.'
           goto error
        end
    end
    /*  The parent "WFPARTICIPANT" must exist in order to create child in "WFACTIVITY_NOTIFY"  */
    if update(ID_PARTICIPANT)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PARTICIPANT is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPARTICIPANT t1, inserted t2
              where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to create a child row in WFACTIVITY_NOTIFY.'
           goto error
        end
    end
    /*  The parent "WFACTIVITY" must exist in order to create child in "WFACTIVITY_NOTIFY"  */
    if update(ID_PROCESS_NOTIFY) or
       update(ID_ACTIVITY_NOTIFY)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS_NOTIFY is null
                           and   ID_ACTIVITY_NOTIFY is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFACTIVITY t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS_NOTIFY
               and   t1.ID_ACTIVITY = t2.ID_ACTIVITY_NOTIFY) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY. Failed to create a child row in WFACTIVITY_NOTIFY.'
           goto error
        end
    end
    /*  The parent "WFNOTIFY_TYPE" must exist in order to create child in "WFACTIVITY_NOTIFY"  */
    if update(ID_NOTIFY_TYPE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_NOTIFY_TYPE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFNOTIFY_TYPE t1, inserted t2
              where  t1.ID_NOTIFY_TYPE = t2.ID_NOTIFY_TYPE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFNOTIFY_TYPE. Failed to create a child row in WFACTIVITY_NOTIFY.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity_notify" for table "WFACTIVITY_NOTIFY"  */
CREATE trigger tu_wfactivity_notify on WFACTIVITY_NOTIFY for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFACTIVITY" must exist in order to modify child in "WFACTIVITY_NOTIFY"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         if (select count(*)
             from   WFACTIVITY t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS
              and   t1.ID_ACTIVITY = t2.ID_ACTIVITY) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY. Failed to modify the child row in WFACTIVITY_NOTIFY.'
             goto error
          end
      end
      /*  The parent "WFPARTICIPANT" must exist in order to modify child in "WFACTIVITY_NOTIFY"  */
      if update(ID_PARTICIPANT)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PARTICIPANT is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPARTICIPANT t1, inserted t2
                where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to modify the child row in WFACTIVITY_NOTIFY.'
             goto error
          end
      end
      /*  The parent "WFACTIVITY" must exist in order to modify child in "WFACTIVITY_NOTIFY"  */
      if update(ID_PROCESS_NOTIFY) or
         update(ID_ACTIVITY_NOTIFY)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS_NOTIFY is null
                             and   ID_ACTIVITY_NOTIFY is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFACTIVITY t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS_NOTIFY
                 and   t1.ID_ACTIVITY = t2.ID_ACTIVITY_NOTIFY) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY. Failed to modify the child row in WFACTIVITY_NOTIFY.'
             goto error
          end
      end
      /*  The parent "WFNOTIFY_TYPE" must exist in order to modify child in "WFACTIVITY_NOTIFY"  */
      if update(ID_NOTIFY_TYPE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_NOTIFY_TYPE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFNOTIFY_TYPE t1, inserted t2
                where  t1.ID_NOTIFY_TYPE = t2.ID_NOTIFY_TYPE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFNOTIFY_TYPE. Failed to modify the child row in WFACTIVITY_NOTIFY.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfactivity_param" for table "WFACTIVITY_PARAM"  */
CREATE trigger ti_wfactivity_param on WFACTIVITY_PARAM for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFACTIVITY" must exist in order to create child in "WFACTIVITY_PARAM"  */
    if update(ID_PROCESS) or
       update(ID_ACTIVITY)
    begin
       if (select count(*)
           from   WFACTIVITY t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS
            and   t1.ID_ACTIVITY = t2.ID_ACTIVITY) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY. Failed to create a child row in WFACTIVITY_PARAM.'
           goto error
        end
    end
    /*  The parent "WFRELDATA" must exist in order to create child in "WFACTIVITY_PARAM"  */
    if update(ID_RELDATA)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_RELDATA is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFRELDATA t1, inserted t2
              where  t1.ID_RELDATA = t2.ID_RELDATA) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFRELDATA. Failed to create a child row in WFACTIVITY_PARAM.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity_param" for table "WFACTIVITY_PARAM"  */
CREATE trigger tu_wfactivity_param on WFACTIVITY_PARAM for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFACTIVITY" must exist in order to modify child in "WFACTIVITY_PARAM"  */
      if update(ID_PROCESS) or
         update(ID_ACTIVITY)
      begin
         if (select count(*)
             from   WFACTIVITY t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS
              and   t1.ID_ACTIVITY = t2.ID_ACTIVITY) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY. Failed to modify the child row in WFACTIVITY_PARAM.'
             goto error
          end
      end
      /*  The parent "WFRELDATA" must exist in order to modify child in "WFACTIVITY_PARAM"  */
      if update(ID_RELDATA)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_RELDATA is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFRELDATA t1, inserted t2
                where  t1.ID_RELDATA = t2.ID_RELDATA) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFRELDATA. Failed to modify the child row in WFACTIVITY_PARAM.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfactivity_type" for table "WFACTIVITY_TYPE"  */
CREATE trigger tu_wfactivity_type on WFACTIVITY_TYPE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFACTIVITY_TYPE" to child "WFACTIVITY"  */
      if update(ID_ACTIVITY_TYPE)
      begin
         update WFACTIVITY
          set   ID_ACTIVITY_TYPE = i1.ID_ACTIVITY_TYPE
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_ACTIVITY_TYPE = d1.ID_ACTIVITY_TYPE
          and  (i1.ID_ACTIVITY_TYPE != d1.ID_ACTIVITY_TYPE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfactivity_type" for table "WFACTIVITY_TYPE"  */
CREATE trigger td_wfactivity_type on WFACTIVITY_TYPE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_ACTIVITY_TYPE = t1.ID_ACTIVITY_TYPE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfapplication" for table "WFAPPLICATION"  */
CREATE trigger ti_wfapplication on WFAPPLICATION for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFAPPLICATION_TYPE" must exist in order to create child in "WFAPPLICATION"  */
    if update(ID_APP_TYPE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_APP_TYPE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFAPPLICATION_TYPE t1, inserted t2
              where  t1.ID_APP_TYPE = t2.ID_APP_TYPE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFAPPLICATION_TYPE. Failed to create a child row in WFAPPLICATION.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfapplication" for table "WFAPPLICATION"  */
CREATE trigger tu_wfapplication on WFAPPLICATION for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFAPPLICATION_TYPE" must exist in order to modify child in "WFAPPLICATION"  */
      if update(ID_APP_TYPE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_APP_TYPE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFAPPLICATION_TYPE t1, inserted t2
                where  t1.ID_APP_TYPE = t2.ID_APP_TYPE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFAPPLICATION_TYPE. Failed to modify the child row in WFAPPLICATION.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFAPPLICATION" to child "WFAPPLICATION_PARAM"  */
      if update(ID_APPLICATION)
      begin
         update WFAPPLICATION_PARAM
          set   ID_APPLICATION = i1.ID_APPLICATION
         from   WFAPPLICATION_PARAM t2, inserted i1, deleted d1
         where  t2.ID_APPLICATION = d1.ID_APPLICATION
          and  (i1.ID_APPLICATION != d1.ID_APPLICATION)
      end

      /*  Check and apply change from parent "WFAPPLICATION" to child "WFACTIVITY"  */
      if update(ID_APPLICATION)
      begin
         update WFACTIVITY
          set   ID_APPLICATION = i1.ID_APPLICATION
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_APPLICATION = d1.ID_APPLICATION
          and  (i1.ID_APPLICATION != d1.ID_APPLICATION)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfapplication" for table "WFAPPLICATION"  */
CREATE trigger td_wfapplication on WFAPPLICATION for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFAPPLICATION_PARAM"  */
    delete WFAPPLICATION_PARAM
    from   WFAPPLICATION_PARAM t2, deleted t1
    where  t2.ID_APPLICATION = t1.ID_APPLICATION

    /*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_APPLICATION = t1.ID_APPLICATION


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfapplication_param" for table "WFAPPLICATION_PARAM"  */
CREATE trigger ti_wfapplication_param on WFAPPLICATION_PARAM for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFAPPLICATION" must exist in order to create child in "WFAPPLICATION_PARAM"  */
    if update(ID_APPLICATION)
    begin
       if (select count(*)
           from   WFAPPLICATION t1, inserted t2
           where  t1.ID_APPLICATION = t2.ID_APPLICATION) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFAPPLICATION. Failed to create a child row in WFAPPLICATION_PARAM.'
           goto error
        end
    end
    /*  The parent "WFDATATYPE" must exist in order to create child in "WFAPPLICATION_PARAM"  */
    if update(ID_DATATYPE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DATATYPE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFDATATYPE t1, inserted t2
              where  t1.ID_DATATYPE = t2.ID_DATATYPE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFDATATYPE. Failed to create a child row in WFAPPLICATION_PARAM.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfapplication_param" for table "WFAPPLICATION_PARAM"  */
CREATE trigger tu_wfapplication_param on WFAPPLICATION_PARAM for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFAPPLICATION" must exist in order to modify child in "WFAPPLICATION_PARAM"  */
      if update(ID_APPLICATION)
      begin
         if (select count(*)
             from   WFAPPLICATION t1, inserted t2
             where  t1.ID_APPLICATION = t2.ID_APPLICATION) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFAPPLICATION. Failed to modify the child row in WFAPPLICATION_PARAM.'
             goto error
          end
      end
      /*  The parent "WFDATATYPE" must exist in order to modify child in "WFAPPLICATION_PARAM"  */
      if update(ID_DATATYPE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DATATYPE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFDATATYPE t1, inserted t2
                where  t1.ID_DATATYPE = t2.ID_DATATYPE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFDATATYPE. Failed to modify the child row in WFAPPLICATION_PARAM.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfapplication_type" for table "WFAPPLICATION_TYPE"  */
CREATE trigger tu_wfapplication_type on WFAPPLICATION_TYPE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFAPPLICATION_TYPE" to child "WFAPPLICATION"  */
      if update(ID_APP_TYPE)
      begin
         update WFAPPLICATION
          set   ID_APP_TYPE = i1.ID_APP_TYPE
         from   WFAPPLICATION t2, inserted i1, deleted d1
         where  t2.ID_APP_TYPE = d1.ID_APP_TYPE
          and  (i1.ID_APP_TYPE != d1.ID_APP_TYPE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfapplication_type" for table "WFAPPLICATION_TYPE"  */
CREATE trigger td_wfapplication_type on WFAPPLICATION_TYPE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFAPPLICATION"  */
    delete WFAPPLICATION
    from   WFAPPLICATION t2, deleted t1
    where  t2.ID_APP_TYPE = t1.ID_APP_TYPE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfcategory" for table "WFCATEGORY"  */
CREATE trigger tu_wfcategory on WFCATEGORY for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFCATEGORY" to child "WFPROCESS_CATEGORY"  */
      if update(ID_CATEGORY)
      begin
         update WFPROCESS_CATEGORY
          set   ID_CATEGORY = i1.ID_CATEGORY
         from   WFPROCESS_CATEGORY t2, inserted i1, deleted d1
         where  t2.ID_CATEGORY = d1.ID_CATEGORY
          and  (i1.ID_CATEGORY != d1.ID_CATEGORY)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfcategory" for table "WFCATEGORY"  */
CREATE trigger td_wfcategory on WFCATEGORY for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_CATEGORY"  */
    delete WFPROCESS_CATEGORY
    from   WFPROCESS_CATEGORY t2, deleted t1
    where  t2.ID_CATEGORY = t1.ID_CATEGORY


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO



SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfdataset" for table "WFDATASET"  */
CREATE trigger tu_wfdataset on WFDATASET for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFDATASET" to child "WFPROCESS_RELDATA"  */
      if update(ID_DATASET)
      begin
         update WFPROCESS_RELDATA
          set   ID_DATASET_DEFAULT = i1.ID_DATASET
         from   WFPROCESS_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_DATASET_DEFAULT = d1.ID_DATASET
          and  (i1.ID_DATASET != d1.ID_DATASET)
      end

      /*  Check and apply change from parent "WFDATASET" to child "WFDATASET_VALUE"  */
      if update(ID_DATASET)
      begin
         update WFDATASET_VALUE
          set   ID_DATASET = i1.ID_DATASET
         from   WFDATASET_VALUE t2, inserted i1, deleted d1
         where  t2.ID_DATASET = d1.ID_DATASET
          and  (i1.ID_DATASET != d1.ID_DATASET)
      end

      /*  Check and apply change from parent "WFDATASET" to child "WFACTIVITY_INST_RELDATA"  */
      if update(ID_DATASET)
      begin
         update WFACTIVITY_INST_RELDATA
          set   ID_DATASET = i1.ID_DATASET
         from   WFACTIVITY_INST_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_DATASET = d1.ID_DATASET
          and  (i1.ID_DATASET != d1.ID_DATASET)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfdataset" for table "WFDATASET"  */
CREATE trigger td_wfdataset on WFDATASET for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_RELDATA"  */
    delete WFPROCESS_RELDATA
    from   WFPROCESS_RELDATA t2, deleted t1
    where  t2.ID_DATASET_DEFAULT = t1.ID_DATASET

    /*  Delete child in "WFDATASET_VALUE"  */
    delete WFDATASET_VALUE
    from   WFDATASET_VALUE t2, deleted t1
    where  t2.ID_DATASET = t1.ID_DATASET

    /*  Delete child in "WFACTIVITY_INST_RELDATA"  */
    delete WFACTIVITY_INST_RELDATA
    from   WFACTIVITY_INST_RELDATA t2, deleted t1
    where  t2.ID_DATASET = t1.ID_DATASET
	
    /*  Delete child in WFPROCESS_INST_RELDATA"  */
    delete WFPROCESS_INST_RELDATA
    from   WFPROCESS_INST_RELDATA t2, deleted t1
    where  t2.ID_DATASET = t1.ID_DATASET

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfdataset_value" for table "WFDATASET_VALUE"  */
CREATE trigger ti_wfdataset_value on WFDATASET_VALUE for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFDATASET" must exist in order to create child in "WFDATASET_VALUE"  */
    if update(ID_DATASET)
    begin
       if (select count(*)
           from   WFDATASET t1, inserted t2
           where  t1.ID_DATASET = t2.ID_DATASET) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFDATASET. Failed to create a child row in WFDATASET_VALUE.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfdataset_value" for table "WFDATASET_VALUE"  */
CREATE trigger tu_wfdataset_value on WFDATASET_VALUE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFDATASET" must exist in order to modify child in "WFDATASET_VALUE"  */
      if update(ID_DATASET)
      begin
         if (select count(*)
             from   WFDATASET t1, inserted t2
             where  t1.ID_DATASET = t2.ID_DATASET) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFDATASET. Failed to modify the child row in WFDATASET_VALUE.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfdatatype" for table "WFDATATYPE"  */
CREATE trigger tu_wfdatatype on WFDATATYPE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFDATATYPE" to child "WFAPPLICATION_PARAM"  */
      if update(ID_DATATYPE)
      begin
         update WFAPPLICATION_PARAM
          set   ID_DATATYPE = i1.ID_DATATYPE
         from   WFAPPLICATION_PARAM t2, inserted i1, deleted d1
         where  t2.ID_DATATYPE = d1.ID_DATATYPE
          and  (i1.ID_DATATYPE != d1.ID_DATATYPE)
      end

      /*  Check and apply change from parent "WFDATATYPE" to child "WFRELDATA"  */
      if update(ID_DATATYPE)
      begin
         update WFRELDATA
          set   ID_DATATYPE = i1.ID_DATATYPE
         from   WFRELDATA t2, inserted i1, deleted d1
         where  t2.ID_DATATYPE = d1.ID_DATATYPE
          and  (i1.ID_DATATYPE != d1.ID_DATATYPE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfdatatype" for table "WFDATATYPE"  */
CREATE trigger td_wfdatatype on WFDATATYPE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFAPPLICATION_PARAM"  */
    delete WFAPPLICATION_PARAM
    from   WFAPPLICATION_PARAM t2, deleted t1
    where  t2.ID_DATATYPE = t1.ID_DATATYPE

    /*  Delete child in "WFRELDATA"  */
    delete WFRELDATA
    from   WFRELDATA t2, deleted t1
    where  t2.ID_DATATYPE = t1.ID_DATATYPE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfdelegate" for table "WFDELEGATE"  */
CREATE trigger ti_wfdelegate on WFDELEGATE for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS_PARTICIPANT" must exist in order to create child in "WFDELEGATE"  */
    if update(ID_PROCESS) or
       update(ID_PARTICIPANT)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS is null
                           and   ID_PARTICIPANT is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPROCESS_PARTICIPANT t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS
               and   t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS_PARTICIPANT. Failed to create a child row in WFDELEGATE.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfdelegate" for table "WFDELEGATE"  */
CREATE trigger tu_wfdelegate on WFDELEGATE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS_PARTICIPANT" must exist in order to modify child in "WFDELEGATE"  */
      if update(ID_PROCESS) or
         update(ID_PARTICIPANT)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS is null
                             and   ID_PARTICIPANT is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPROCESS_PARTICIPANT t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS
                 and   t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS_PARTICIPANT. Failed to modify the child row in WFDELEGATE.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfduration_unit" for table "WFDURATION_UNIT"  */
CREATE trigger tu_wfduration_unit on WFDURATION_UNIT for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFDURATION_UNIT" to child "WFPROCESS"  */
      if update(ID_DURATION_UNIT)
      begin
         update WFPROCESS
          set   ID_DURATION_UNIT = i1.ID_DURATION_UNIT
         from   WFPROCESS t2, inserted i1, deleted d1
         where  t2.ID_DURATION_UNIT = d1.ID_DURATION_UNIT
          and  (i1.ID_DURATION_UNIT != d1.ID_DURATION_UNIT)
      end

      /*  Check and apply change from parent "WFDURATION_UNIT" to child "WFACTIVITY"  */
      if update(ID_DURATION_UNIT)
      begin
         update WFACTIVITY
          set   ID_DURATION_UNIT = i1.ID_DURATION_UNIT
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_DURATION_UNIT = d1.ID_DURATION_UNIT
          and  (i1.ID_DURATION_UNIT != d1.ID_DURATION_UNIT)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfduration_unit" for table "WFDURATION_UNIT"  */
CREATE trigger td_wfduration_unit on WFDURATION_UNIT for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS"  */
    delete WFPROCESS
    from   WFPROCESS t2, deleted t1
    where  t2.ID_DURATION_UNIT = t1.ID_DURATION_UNIT

    /*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_DURATION_UNIT = t1.ID_DURATION_UNIT


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wffolder" for table "WFFOLDER"  */
CREATE trigger td_wffolder on WFFOLDER for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFFOLDER_PERM"  */
    delete WFFOLDER_PERM
    from   WFFOLDER_PERM t2, deleted t1
    where  t2.ID_FOLDER = t1.ID_FOLDER

    /*  Delete child in "WFPROCESS"  */
    delete WFPROCESS
    from   WFPROCESS t2, deleted t1
    where  t2.ID_FOLDER = t1.ID_FOLDER


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wffolder" for table "WFFOLDER"  */
CREATE trigger tu_wffolder on WFFOLDER for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFFOLDER" to child "WFFOLDER_PERM"  */
      if update(ID_FOLDER)
      begin
         update WFFOLDER_PERM
          set   ID_FOLDER = i1.ID_FOLDER
         from   WFFOLDER_PERM t2, inserted i1, deleted d1
         where  t2.ID_FOLDER = d1.ID_FOLDER
          and  (i1.ID_FOLDER != d1.ID_FOLDER)
      end

      /*  Check and apply change from parent "WFFOLDER" to child "WFPROCESS"  */
      if update(ID_FOLDER)
      begin
         update WFPROCESS
          set   ID_FOLDER = i1.ID_FOLDER
         from   WFPROCESS t2, inserted i1, deleted d1
         where  t2.ID_FOLDER = d1.ID_FOLDER
          and  (i1.ID_FOLDER != d1.ID_FOLDER)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wffolder_perm" for table "WFFOLDER_PERM"  */
CREATE trigger ti_wffolder_perm on WFFOLDER_PERM for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFFOLDER" must exist in order to create child in "WFFOLDER_PERM"  */
    if update(ID_FOLDER)
    begin
       if (select count(*)
           from   WFFOLDER t1, inserted t2
           where  t1.ID_FOLDER = t2.ID_FOLDER) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFFOLDER. Failed to create a child row in WFFOLDER_PERM.'
           goto error
        end
    end
    /*  The parent "WFPERM_TYPE" must exist in order to create child in "WFFOLDER_PERM"  */
    if update(ID_PERM_TYPE)
    begin
       if (select count(*)
           from   WFPERM_TYPE t1, inserted t2
           where  t1.ID_PERM_TYPE = t2.ID_PERM_TYPE) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPERM_TYPE. Failed to create a child row in WFFOLDER_PERM.'
           goto error
        end
    end
    /*  The parent "WFPARTICIPANT" must exist in order to create child in "WFFOLDER_PERM"  */
    if update(ID_PARTICIPANT)
    begin
       if (select count(*)
           from   WFPARTICIPANT t1, inserted t2
           where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to create a child row in WFFOLDER_PERM.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wffolder_perm" for table "WFFOLDER_PERM"  */
CREATE trigger tu_wffolder_perm on WFFOLDER_PERM for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFFOLDER" must exist in order to modify child in "WFFOLDER_PERM"  */
      if update(ID_FOLDER)
      begin
         if (select count(*)
             from   WFFOLDER t1, inserted t2
             where  t1.ID_FOLDER = t2.ID_FOLDER) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFFOLDER. Failed to modify the child row in WFFOLDER_PERM.'
             goto error
          end
      end
      /*  The parent "WFPERM_TYPE" must exist in order to modify child in "WFFOLDER_PERM"  */
      if update(ID_PERM_TYPE)
      begin
         if (select count(*)
             from   WFPERM_TYPE t1, inserted t2
             where  t1.ID_PERM_TYPE = t2.ID_PERM_TYPE) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPERM_TYPE. Failed to modify the child row in WFFOLDER_PERM.'
             goto error
          end
      end
      /*  The parent "WFPARTICIPANT" must exist in order to modify child in "WFFOLDER_PERM"  */
      if update(ID_PARTICIPANT)
      begin
         if (select count(*)
             from   WFPARTICIPANT t1, inserted t2
             where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to modify the child row in WFFOLDER_PERM.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO



SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfparticipant" for table "WFPARTICIPANT"  */
CREATE trigger ti_wfparticipant on WFPARTICIPANT for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS" must exist in order to create child in "WFPARTICIPANT"  */
    if update(ID_PROCESS)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPROCESS t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFPARTICIPANT.'
           goto error
        end
    end
    /*  The parent "WFPARTICIPANT_TYPE" must exist in order to create child in "WFPARTICIPANT"  */
    if update(ID_PARTICIPANT_TYPE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PARTICIPANT_TYPE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPARTICIPANT_TYPE t1, inserted t2
              where  t1.ID_PARTICIPANT_TYPE = t2.ID_PARTICIPANT_TYPE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT_TYPE. Failed to create a child row in WFPARTICIPANT.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfparticipant" for table "WFPARTICIPANT"  */
CREATE trigger tu_wfparticipant on WFPARTICIPANT for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS" must exist in order to modify child in "WFPARTICIPANT"  */
      if update(ID_PROCESS)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPROCESS t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFPARTICIPANT.'
             goto error
          end
      end
      /*  The parent "WFPARTICIPANT_TYPE" must exist in order to modify child in "WFPARTICIPANT"  */
      if update(ID_PARTICIPANT_TYPE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PARTICIPANT_TYPE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPARTICIPANT_TYPE t1, inserted t2
                where  t1.ID_PARTICIPANT_TYPE = t2.ID_PARTICIPANT_TYPE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT_TYPE. Failed to modify the child row in WFPARTICIPANT.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFPARTICIPANT" to child "WFFOLDER_PERM"  */
      if update(ID_PARTICIPANT)
      begin
         update WFFOLDER_PERM
          set   ID_PARTICIPANT = i1.ID_PARTICIPANT
         from   WFFOLDER_PERM t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT = d1.ID_PARTICIPANT
          and  (i1.ID_PARTICIPANT != d1.ID_PARTICIPANT)
      end

      /*  Check and apply change from parent "WFPARTICIPANT" to child "WFPARTICIPANT_MAPTO"  */
      if update(ID_PARTICIPANT)
      begin
         update WFPARTICIPANT_MAPTO
          set   ID_PARTICIPANT = i1.ID_PARTICIPANT
         from   WFPARTICIPANT_MAPTO t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT = d1.ID_PARTICIPANT
          and  (i1.ID_PARTICIPANT != d1.ID_PARTICIPANT)
      end

      /*  Check and apply change from parent "WFPARTICIPANT" to child "WFPROCESS_PARTICIPANT"  */
      if update(ID_PARTICIPANT)
      begin
         update WFPROCESS_PARTICIPANT
          set   ID_PARTICIPANT = i1.ID_PARTICIPANT
         from   WFPROCESS_PARTICIPANT t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT = d1.ID_PARTICIPANT
          and  (i1.ID_PARTICIPANT != d1.ID_PARTICIPANT)
      end

      /*  Check and apply change from parent "WFPARTICIPANT" to child "WFACTIVITY"  */
      if update(ID_PARTICIPANT)
      begin
         update WFACTIVITY
          set   ID_PARTICIPANT = i1.ID_PARTICIPANT
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT = d1.ID_PARTICIPANT
          and  (i1.ID_PARTICIPANT != d1.ID_PARTICIPANT)
      end

      /*  Check and apply change from parent "WFPARTICIPANT" to child "WFPROCESS_RELDATA_RESTRICT"  */
      if update(ID_PARTICIPANT)
      begin
         update WFPROCESS_RELDATA_RESTRICT
          set   ID_PARTICIPANT = i1.ID_PARTICIPANT
         from   WFPROCESS_RELDATA_RESTRICT t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT = d1.ID_PARTICIPANT
          and  (i1.ID_PARTICIPANT != d1.ID_PARTICIPANT)
      end

      /*  Check and apply change from parent "WFPARTICIPANT" to child "WFACTIVITY_NOTIFY"  */
      if update(ID_PARTICIPANT)
      begin
         update WFACTIVITY_NOTIFY
          set   ID_PARTICIPANT = i1.ID_PARTICIPANT
         from   WFACTIVITY_NOTIFY t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT = d1.ID_PARTICIPANT
          and  (i1.ID_PARTICIPANT != d1.ID_PARTICIPANT)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfparticipant" for table "WFPARTICIPANT"  */
CREATE trigger td_wfparticipant on WFPARTICIPANT for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFFOLDER_PERM"  */
    delete WFFOLDER_PERM
    from   WFFOLDER_PERM t2, deleted t1
    where  t2.ID_PARTICIPANT = t1.ID_PARTICIPANT

    /*  Delete child in "WFPARTICIPANT_MAPTO"  */
    delete WFPARTICIPANT_MAPTO
    from   WFPARTICIPANT_MAPTO t2, deleted t1
    where  t2.ID_PARTICIPANT = t1.ID_PARTICIPANT

    /*  Delete child in "WFPROCESS_PARTICIPANT"  */
    delete WFPROCESS_PARTICIPANT
    from   WFPROCESS_PARTICIPANT t2, deleted t1
    where  t2.ID_PARTICIPANT = t1.ID_PARTICIPANT

    /*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_PARTICIPANT = t1.ID_PARTICIPANT

    /*  Delete child in "WFPROCESS_RELDATA_RESTRICT"  */
    delete WFPROCESS_RELDATA_RESTRICT
    from   WFPROCESS_RELDATA_RESTRICT t2, deleted t1
    where  t2.ID_PARTICIPANT = t1.ID_PARTICIPANT

    /*  Delete child in "WFACTIVITY_NOTIFY"  */
    delete WFACTIVITY_NOTIFY
    from   WFACTIVITY_NOTIFY t2, deleted t1
    where  t2.ID_PARTICIPANT = t1.ID_PARTICIPANT


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfparticipant_mapto" for table "WFPARTICIPANT_MAPTO"  */
CREATE trigger ti_wfparticipant_mapto on WFPARTICIPANT_MAPTO for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPARTICIPANT" must exist in order to create child in "WFPARTICIPANT_MAPTO"  */
    if update(ID_PARTICIPANT)
    begin
       if (select count(*)
           from   WFPARTICIPANT t1, inserted t2
           where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to create a child row in WFPARTICIPANT_MAPTO.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfparticipant_mapto" for table "WFPARTICIPANT_MAPTO"  */
CREATE trigger tu_wfparticipant_mapto on WFPARTICIPANT_MAPTO for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPARTICIPANT" must exist in order to modify child in "WFPARTICIPANT_MAPTO"  */
      if update(ID_PARTICIPANT)
      begin
         if (select count(*)
             from   WFPARTICIPANT t1, inserted t2
             where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to modify the child row in WFPARTICIPANT_MAPTO.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfparticipant_role" for table "WFPARTICIPANT_ROLE"  */
CREATE trigger tu_wfparticipant_role on WFPARTICIPANT_ROLE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFPARTICIPANT_ROLE" to child "WFPROCESS_PARTICIPANT"  */
      if update(ID_PARTICIPANT_ROLE)
      begin
         update WFPROCESS_PARTICIPANT
          set   ID_PARTICIPANT_ROLE = i1.ID_PARTICIPANT_ROLE
         from   WFPROCESS_PARTICIPANT t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT_ROLE = d1.ID_PARTICIPANT_ROLE
          and  (i1.ID_PARTICIPANT_ROLE != d1.ID_PARTICIPANT_ROLE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfparticipant_role" for table "WFPARTICIPANT_ROLE"  */
CREATE trigger td_wfparticipant_role on WFPARTICIPANT_ROLE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_PARTICIPANT"  */
    delete WFPROCESS_PARTICIPANT
    from   WFPROCESS_PARTICIPANT t2, deleted t1
    where  t2.ID_PARTICIPANT_ROLE = t1.ID_PARTICIPANT_ROLE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfparticipant_type" for table "WFPARTICIPANT_TYPE"  */
CREATE trigger tu_wfparticipant_type on WFPARTICIPANT_TYPE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFPARTICIPANT_TYPE" to child "WFPARTICIPANT"  */
      if update(ID_PARTICIPANT_TYPE)
      begin
         update WFPARTICIPANT
          set   ID_PARTICIPANT_TYPE = i1.ID_PARTICIPANT_TYPE
         from   WFPARTICIPANT t2, inserted i1, deleted d1
         where  t2.ID_PARTICIPANT_TYPE = d1.ID_PARTICIPANT_TYPE
          and  (i1.ID_PARTICIPANT_TYPE != d1.ID_PARTICIPANT_TYPE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfparticipant_type" for table "WFPARTICIPANT_TYPE"  */
CREATE trigger td_wfparticipant_type on WFPARTICIPANT_TYPE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPARTICIPANT"  */
    delete WFPARTICIPANT
    from   WFPARTICIPANT t2, deleted t1
    where  t2.ID_PARTICIPANT_TYPE = t1.ID_PARTICIPANT_TYPE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfperm_type" for table "WFPERM_TYPE"  */
CREATE trigger tu_wfperm_type on WFPERM_TYPE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFPERM_TYPE" to child "WFFOLDER_PERM"  */
      if update(ID_PERM_TYPE)
      begin
         update WFFOLDER_PERM
          set   ID_PERM_TYPE = i1.ID_PERM_TYPE
         from   WFFOLDER_PERM t2, inserted i1, deleted d1
         where  t2.ID_PERM_TYPE = d1.ID_PERM_TYPE
          and  (i1.ID_PERM_TYPE != d1.ID_PERM_TYPE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfperm_type" for table "WFPERM_TYPE"  */
CREATE trigger td_wfperm_type on WFPERM_TYPE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFFOLDER_PERM"  */
    delete WFFOLDER_PERM
    from   WFFOLDER_PERM t2, deleted t1
    where  t2.ID_PERM_TYPE = t1.ID_PERM_TYPE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess" for table "WFPROCESS"  */
CREATE trigger ti_wfprocess on WFPROCESS for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFFOLDER" must exist in order to create child in "WFPROCESS"  */
    if update(ID_FOLDER)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_FOLDER is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFFOLDER t1, inserted t2
              where  t1.ID_FOLDER = t2.ID_FOLDER) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFFOLDER. Failed to create a child row in WFPROCESS.'
           goto error
        end
    end
    /*  The parent "WFDURATION_UNIT" must exist in order to create child in "WFPROCESS"  */
    if update(ID_DURATION_UNIT)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DURATION_UNIT is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFDURATION_UNIT t1, inserted t2
              where  t1.ID_DURATION_UNIT = t2.ID_DURATION_UNIT) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFDURATION_UNIT. Failed to create a child row in WFPROCESS.'
           goto error
        end
    end
    /*  The parent "WFPROCESS_STATUS" must exist in order to create child in "WFPROCESS"  */
    if update(ID_PROCESS_STATUS)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS_STATUS is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPROCESS_STATUS t1, inserted t2
              where  t1.ID_PROCESS_STATUS = t2.ID_PROCESS_STATUS) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS_STATUS. Failed to create a child row in WFPROCESS.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess" for table "WFPROCESS"  */
CREATE trigger tu_wfprocess on WFPROCESS for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFFOLDER" must exist in order to modify child in "WFPROCESS"  */
      if update(ID_FOLDER)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_FOLDER is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFFOLDER t1, inserted t2
                where  t1.ID_FOLDER = t2.ID_FOLDER) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFFOLDER. Failed to modify the child row in WFPROCESS.'
             goto error
          end
      end
      /*  The parent "WFDURATION_UNIT" must exist in order to modify child in "WFPROCESS"  */
      if update(ID_DURATION_UNIT)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DURATION_UNIT is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFDURATION_UNIT t1, inserted t2
                where  t1.ID_DURATION_UNIT = t2.ID_DURATION_UNIT) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFDURATION_UNIT. Failed to modify the child row in WFPROCESS.'
             goto error
          end
      end
      /*  The parent "WFPROCESS_STATUS" must exist in order to modify child in "WFPROCESS"  */
      if update(ID_PROCESS_STATUS)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS_STATUS is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPROCESS_STATUS t1, inserted t2
                where  t1.ID_PROCESS_STATUS = t2.ID_PROCESS_STATUS) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS_STATUS. Failed to modify the child row in WFPROCESS.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFPROCESS" to child "WFPROCESS_CATEGORY"  */
      if update(ID_PROCESS)
      begin
         update WFPROCESS_CATEGORY
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFPROCESS_CATEGORY t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end

      /*  Check and apply change from parent "WFPROCESS" to child "WFPROCESS_PARTICIPANT"  */
      if update(ID_PROCESS)
      begin
         update WFPROCESS_PARTICIPANT
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFPROCESS_PARTICIPANT t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end

      /*  Check and apply change from parent "WFPROCESS" to child "WFPROCESS_RELDATA"  */
      if update(ID_PROCESS)
      begin
         update WFPROCESS_RELDATA
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFPROCESS_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end

      /*  Check and apply change from parent "WFPROCESS" to child "WFPARTICIPANT"  */
      if update(ID_PROCESS)
      begin
         update WFPARTICIPANT
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFPARTICIPANT t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end

      /*  Check and apply change from parent "WFPROCESS" to child "WFRELDATA"  */
      if update(ID_PROCESS)
      begin
         update WFRELDATA
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFRELDATA t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end

      /*  Check and apply change from parent "WFPROCESS" to child "WFPROCESS_TRANSITION"  */
      if update(ID_PROCESS)
      begin
         update WFPROCESS_TRANSITION
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFPROCESS_TRANSITION t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end

      /*  Check and apply change from parent "WFPROCESS" to child "WFACTIVITY"  */
      if update(ID_PROCESS)
      begin
         update WFACTIVITY
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end

      /*  Check and apply change from parent "WFPROCESS" to child "WFPROCESS_INST"  */
      if update(ID_PROCESS)
      begin
         update WFPROCESS_INST
          set   ID_PROCESS = i1.ID_PROCESS
         from   WFPROCESS_INST t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and  (i1.ID_PROCESS != d1.ID_PROCESS)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfprocess" for table "WFPROCESS"  */
CREATE trigger td_wfprocess on WFPROCESS for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_CATEGORY"  */
    delete WFPROCESS_CATEGORY
    from   WFPROCESS_CATEGORY t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS

    /*  Delete child in "WFPROCESS_PARTICIPANT"  */
    delete WFPROCESS_PARTICIPANT
    from   WFPROCESS_PARTICIPANT t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS

    /*  Delete child in "WFPROCESS_RELDATA"  */
    delete WFPROCESS_RELDATA
    from   WFPROCESS_RELDATA t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS

    /*  Delete child in "WFPARTICIPANT"  */
    delete WFPARTICIPANT
    from   WFPARTICIPANT t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS

    /*  Delete child in "WFRELDATA"  */
    delete WFRELDATA
    from   WFRELDATA t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS

    /*  Delete child in "WFPROCESS_TRANSITION"  */
    delete WFPROCESS_TRANSITION
    from   WFPROCESS_TRANSITION t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS

    /*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS

    /*  Delete child in "WFPROCESS_INST"  */
    delete WFPROCESS_INST
    from   WFPROCESS_INST t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess_category" for table "WFPROCESS_CATEGORY"  */
CREATE trigger ti_wfprocess_category on WFPROCESS_CATEGORY for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS" must exist in order to create child in "WFPROCESS_CATEGORY"  */
    if update(ID_PROCESS)
    begin
       if (select count(*)
           from   WFPROCESS t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFPROCESS_CATEGORY.'
           goto error
        end
    end
    /*  The parent "WFCATEGORY" must exist in order to create child in "WFPROCESS_CATEGORY"  */
    if update(ID_CATEGORY)
    begin
       if (select count(*)
           from   WFCATEGORY t1, inserted t2
           where  t1.ID_CATEGORY = t2.ID_CATEGORY) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFCATEGORY. Failed to create a child row in WFPROCESS_CATEGORY.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_category" for table "WFPROCESS_CATEGORY"  */
CREATE trigger tu_wfprocess_category on WFPROCESS_CATEGORY for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS" must exist in order to modify child in "WFPROCESS_CATEGORY"  */
      if update(ID_PROCESS)
      begin
         if (select count(*)
             from   WFPROCESS t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFPROCESS_CATEGORY.'
             goto error
          end
      end
      /*  The parent "WFCATEGORY" must exist in order to modify child in "WFPROCESS_CATEGORY"  */
      if update(ID_CATEGORY)
      begin
         if (select count(*)
             from   WFCATEGORY t1, inserted t2
             where  t1.ID_CATEGORY = t2.ID_CATEGORY) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFCATEGORY. Failed to modify the child row in WFPROCESS_CATEGORY.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess_inst" for table "WFPROCESS_INST"  */
CREATE trigger ti_wfprocess_inst on WFPROCESS_INST for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFSUBSTATE" must exist in order to create child in "WFPROCESS_INST"  */
    if update(ID_STATE) or
       update(ID_SUBSTATE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_STATE is null
                           and   ID_SUBSTATE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFSUBSTATE t1, inserted t2
              where  t1.ID_STATE = t2.ID_STATE
               and   t1.ID_SUBSTATE = t2.ID_SUBSTATE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFSUBSTATE. Failed to create a child row in WFPROCESS_INST.'
           goto error
        end
    end
    /*  The parent "WFPROCESS" must exist in order to create child in "WFPROCESS_INST"  */
    if update(ID_PROCESS)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPROCESS t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFPROCESS_INST.'
           goto error
        end
    end
    /*  The parent "USERS" must exist in order to create child in "WFPROCESS_INST"  */
    if update(ID_USER_REQUESTER)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_USER_REQUESTER is null)
       if @numnull != @numrows
          if (select count(*)
              from   USERS t1, inserted t2
              where  t1.ID_USER = t2.ID_USER_REQUESTER) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in WFPROCESS_INST.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_inst" for table "WFPROCESS_INST"  */
CREATE trigger tu_wfprocess_inst on WFPROCESS_INST for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFSUBSTATE" must exist in order to modify child in "WFPROCESS_INST"  */
      if update(ID_STATE) or
         update(ID_SUBSTATE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_STATE is null
                             and   ID_SUBSTATE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFSUBSTATE t1, inserted t2
                where  t1.ID_STATE = t2.ID_STATE
                 and   t1.ID_SUBSTATE = t2.ID_SUBSTATE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFSUBSTATE. Failed to modify the child row in WFPROCESS_INST.'
             goto error
          end
      end
      /*  The parent "WFPROCESS" must exist in order to modify child in "WFPROCESS_INST"  */
      if update(ID_PROCESS)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPROCESS t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFPROCESS_INST.'
             goto error
          end
      end
      /*  The parent "USERS" must exist in order to modify child in "WFPROCESS_INST"  */
      if update(ID_USER_REQUESTER)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_USER_REQUESTER is null)
         if @numnull != @numrows
            if (select count(*)
                from   USERS t1, inserted t2
                where  t1.ID_USER = t2.ID_USER_REQUESTER) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in WFPROCESS_INST.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFPROCESS_INST" to child "WFPROCESS_INST_RELDATA"  */
      if update(ID_PROCESS_INST)
      begin
         update WFPROCESS_INST_RELDATA
          set   ID_PROCESS_INST = i1.ID_PROCESS_INST
         from   WFPROCESS_INST_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_INST = d1.ID_PROCESS_INST
          and  (i1.ID_PROCESS_INST != d1.ID_PROCESS_INST)
      end
      
      /*  Check and apply change from parent "WFPROCESS_INST" to child "WFPROCESS_INST_COMMENT"  */
      if update(ID_PROCESS_INST)
      begin
         update WFPROCESS_INST_COMMENT
          set   ID_PROCESS_INST = i1.ID_PROCESS_INST
         from   WFPROCESS_INST_COMMENT t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_INST = d1.ID_PROCESS_INST
          and  (i1.ID_PROCESS_INST != d1.ID_PROCESS_INST)
      end

      /*  Check and apply change from parent "WFPROCESS_INST" to child "WFACTIVITY_INST"  */
      if update(ID_PROCESS_INST)
      begin
         update WFACTIVITY_INST
          set   ID_PROCESS_INST = i1.ID_PROCESS_INST
         from   WFACTIVITY_INST t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_INST = d1.ID_PROCESS_INST
          and  (i1.ID_PROCESS_INST != d1.ID_PROCESS_INST)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfprocess_inst" for table "WFPROCESS_INST"  */
CREATE trigger td_wfprocess_inst on WFPROCESS_INST for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_INST_RELDATA"  */
    delete WFPROCESS_INST_RELDATA
    from   WFPROCESS_INST_RELDATA t2, deleted t1
    where  t2.ID_PROCESS_INST = t1.ID_PROCESS_INST
    
    /*  Delete child in "WFPROCESS_INST_COMMENT"  */
    delete WFPROCESS_INST_COMMENT
    from   WFPROCESS_INST_COMMENT t2, deleted t1
    where  t2.ID_PROCESS_INST = t1.ID_PROCESS_INST

    /*  Delete child in "WFACTIVITY_INST"  */
    delete WFACTIVITY_INST
    from   WFACTIVITY_INST t2, deleted t1
    where  t2.ID_PROCESS_INST = t1.ID_PROCESS_INST


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess_inst_reldata" for table "WFPROCESS_INST_RELDATA"  */
CREATE trigger ti_wfprocess_inst_reldata on WFPROCESS_INST_RELDATA for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS_INST" must exist in order to create child in "WFPROCESS_INST_RELDATA"  */
    if update(ID_PROCESS_INST)
    begin
       if (select count(*)
           from   WFPROCESS_INST t1, inserted t2
           where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS_INST. Failed to create a child row in WFPROCESS_INST_RELDATA.'
           goto error
        end
    end
    /*  The parent "WFRELDATA" must exist in order to create child in "WFPROCESS_INST_RELDATA"  */
    if update(ID_RELDATA)
    begin
       if (select count(*)
           from   WFRELDATA t1, inserted t2
           where  t1.ID_RELDATA = t2.ID_RELDATA) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFRELDATA. Failed to create a child row in WFPROCESS_INST_RELDATA.'
           goto error
        end
    end
    /*  The parent "USERS" must exist in order to create child in "WFPROCESS_INST_RELDATA"  */
    if update(ID_USER_LOCK_BY)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_USER_LOCK_BY is null)
       if @numnull != @numrows
          if (select count(*)
              from   USERS t1, inserted t2
              where  t1.ID_USER = t2.ID_USER_LOCK_BY) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in WFPROCESS_INST_RELDATA.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_inst_reldata" for table "WFPROCESS_INST_RELDATA"  */
CREATE trigger tu_wfprocess_inst_reldata on WFPROCESS_INST_RELDATA for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS_INST" must exist in order to modify child in "WFPROCESS_INST_RELDATA"  */
      if update(ID_PROCESS_INST)
      begin
         if (select count(*)
             from   WFPROCESS_INST t1, inserted t2
             where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS_INST. Failed to modify the child row in WFPROCESS_INST_RELDATA.'
             goto error
          end
      end
      /*  The parent "WFRELDATA" must exist in order to modify child in "WFPROCESS_INST_RELDATA"  */
      if update(ID_RELDATA)
      begin
         if (select count(*)
             from   WFRELDATA t1, inserted t2
             where  t1.ID_RELDATA = t2.ID_RELDATA) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFRELDATA. Failed to modify the child row in WFPROCESS_INST_RELDATA.'
             goto error
          end
      end
      /*  The parent "USERS" must exist in order to modify child in "WFPROCESS_INST_RELDATA"  */
      if update(ID_USER_LOCK_BY)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_USER_LOCK_BY is null)
         if @numnull != @numrows
            if (select count(*)
                from   USERS t1, inserted t2
                where  t1.ID_USER = t2.ID_USER_LOCK_BY) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in WFPROCESS_INST_RELDATA.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO





/*  Insert trigger "ti_wfprocess_inst_comment" for table "WFPROCESS_INST_COMMENT"  */
CREATE trigger ti_wfprocess_inst_comment on WFPROCESS_INST_COMMENT for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS_INST" must exist in order to create child in "WFPROCESS_INST_COMMENT"  */
    if update(ID_PROCESS_INST)
    begin
       if (select count(*)
           from   WFPROCESS_INST t1, inserted t2
           where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS_INST. Failed to create a child row in WFPROCESS_INST_COMMENT.'
           goto error
        end
    end

    /*  The parent "USERS" must exist in order to create child in "WFPROCESS_INST_COMMENT"  */
    if update(ID_USER_AUTHOR)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_USER_AUTHOR is null)
       if @numnull != @numrows
          if (select count(*)
              from   USERS t1, inserted t2
              where  t1.ID_USER = t2.ID_USER_AUTHOR) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in USERS. Failed to create a child row in WFPROCESS_INST_COMMENT.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_inst_comment" for table "WFPROCESS_INST_COMMENT"  */
CREATE trigger tu_wfprocess_inst_comment on WFPROCESS_INST_COMMENT for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS_INST" must exist in order to modify child in "WFPROCESS_INST_COMMENT"  */
      if update(ID_PROCESS_INST)
      begin
         if (select count(*)
             from   WFPROCESS_INST t1, inserted t2
             where  t1.ID_PROCESS_INST = t2.ID_PROCESS_INST) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS_INST. Failed to modify the child row in WFPROCESS_INST_COMMENT.'
             goto error
          end
      end
      
      /*  The parent "USERS" must exist in order to modify child in "WFPROCESS_INST_COMMENT"  */
      if update(ID_USER_AUTHOR)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_USER_AUTHOR is null)
         if @numnull != @numrows
            if (select count(*)
                from   USERS t1, inserted t2
                where  t1.ID_USER = t2.ID_USER_AUTHOR) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in USERS. Failed to modify the child row in WFPROCESS_INST_COMMENT.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess_participant" for table "WFPROCESS_PARTICIPANT"  */
CREATE trigger ti_wfprocess_participant on WFPROCESS_PARTICIPANT for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS" must exist in order to create child in "WFPROCESS_PARTICIPANT"  */
    if update(ID_PROCESS)
    begin
       if (select count(*)
           from   WFPROCESS t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFPROCESS_PARTICIPANT.'
           goto error
        end
    end
    /*  The parent "WFPARTICIPANT" must exist in order to create child in "WFPROCESS_PARTICIPANT"  */
    if update(ID_PARTICIPANT)
    begin
       if (select count(*)
           from   WFPARTICIPANT t1, inserted t2
           where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to create a child row in WFPROCESS_PARTICIPANT.'
           goto error
        end
    end
    /*  The parent "WFPARTICIPANT_ROLE" must exist in order to create child in "WFPROCESS_PARTICIPANT"  */
    if update(ID_PARTICIPANT_ROLE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PARTICIPANT_ROLE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPARTICIPANT_ROLE t1, inserted t2
              where  t1.ID_PARTICIPANT_ROLE = t2.ID_PARTICIPANT_ROLE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT_ROLE. Failed to create a child row in WFPROCESS_PARTICIPANT.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_participant" for table "WFPROCESS_PARTICIPANT"  */
CREATE trigger tu_wfprocess_participant on WFPROCESS_PARTICIPANT for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS" must exist in order to modify child in "WFPROCESS_PARTICIPANT"  */
      if update(ID_PROCESS)
      begin
         if (select count(*)
             from   WFPROCESS t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFPROCESS_PARTICIPANT.'
             goto error
          end
      end
      /*  The parent "WFPARTICIPANT" must exist in order to modify child in "WFPROCESS_PARTICIPANT"  */
      if update(ID_PARTICIPANT)
      begin
         if (select count(*)
             from   WFPARTICIPANT t1, inserted t2
             where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to modify the child row in WFPROCESS_PARTICIPANT.'
             goto error
          end
      end
      /*  The parent "WFPARTICIPANT_ROLE" must exist in order to modify child in "WFPROCESS_PARTICIPANT"  */
      if update(ID_PARTICIPANT_ROLE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PARTICIPANT_ROLE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPARTICIPANT_ROLE t1, inserted t2
                where  t1.ID_PARTICIPANT_ROLE = t2.ID_PARTICIPANT_ROLE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT_ROLE. Failed to modify the child row in WFPROCESS_PARTICIPANT.'
             goto error
          end
      end


      return



error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess_reldata" for table "WFPROCESS_RELDATA"  */
CREATE trigger ti_wfprocess_reldata on WFPROCESS_RELDATA for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS" must exist in order to create child in "WFPROCESS_RELDATA"  */
    if update(ID_PROCESS)
    begin
       if (select count(*)
           from   WFPROCESS t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFPROCESS_RELDATA.'
           goto error
        end
    end
    /*  The parent "WFRELDATA" must exist in order to create child in "WFPROCESS_RELDATA"  */
    if update(ID_RELDATA)
    begin
       if (select count(*)
           from   WFRELDATA t1, inserted t2
           where  t1.ID_RELDATA = t2.ID_RELDATA) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFRELDATA. Failed to create a child row in WFPROCESS_RELDATA.'
           goto error
        end
    end
    /*  The parent "WFDATASET" must exist in order to create child in "WFPROCESS_RELDATA"  */
    if update(ID_DATASET_DEFAULT)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DATASET_DEFAULT is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFDATASET t1, inserted t2
              where  t1.ID_DATASET = t2.ID_DATASET_DEFAULT) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFDATASET. Failed to create a child row in WFPROCESS_RELDATA.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_reldata" for table "WFPROCESS_RELDATA"  */
CREATE trigger tu_wfprocess_reldata on WFPROCESS_RELDATA for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS" must exist in order to modify child in "WFPROCESS_RELDATA"  */
      if update(ID_PROCESS)
      begin
         if (select count(*)
             from   WFPROCESS t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFPROCESS_RELDATA.'
             goto error
          end
      end
      /*  The parent "WFRELDATA" must exist in order to modify child in "WFPROCESS_RELDATA"  */
      if update(ID_RELDATA)
      begin
         if (select count(*)
             from   WFRELDATA t1, inserted t2
             where  t1.ID_RELDATA = t2.ID_RELDATA) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFRELDATA. Failed to modify the child row in WFPROCESS_RELDATA.'
             goto error
          end
      end
      /*  The parent "WFDATASET" must exist in order to modify child in "WFPROCESS_RELDATA"  */
      if update(ID_DATASET_DEFAULT)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DATASET_DEFAULT is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFDATASET t1, inserted t2
                where  t1.ID_DATASET = t2.ID_DATASET_DEFAULT) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFDATASET. Failed to modify the child row in WFPROCESS_RELDATA.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFPROCESS_RELDATA" to child "WFACTIVITY"  */
      if update(ID_PROCESS) or
         update(ID_RELDATA)
      begin
         update WFACTIVITY
          set   ID_PROCESS_ASSIGN = i1.ID_PROCESS,
                ID_RELDATA_ASSIGN = i1.ID_RELDATA
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_ASSIGN = d1.ID_PROCESS
          and   t2.ID_RELDATA_ASSIGN = d1.ID_RELDATA
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_RELDATA != d1.ID_RELDATA)
      end

      /*  Check and apply change from parent "WFPROCESS_RELDATA" to child "WFPROCESS_RELDATA_RESTRICT"  */
      if update(ID_PROCESS) or
         update(ID_RELDATA)
      begin
         update WFPROCESS_RELDATA_RESTRICT
          set   ID_PROCESS = i1.ID_PROCESS,
                ID_RELDATA = i1.ID_RELDATA
         from   WFPROCESS_RELDATA_RESTRICT t2, inserted i1, deleted d1
         where  t2.ID_PROCESS = d1.ID_PROCESS
          and   t2.ID_RELDATA = d1.ID_RELDATA
          and  (i1.ID_PROCESS != d1.ID_PROCESS or
                i1.ID_RELDATA != d1.ID_RELDATA)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfprocess_reldata" for table "WFPROCESS_RELDATA"  */
CREATE trigger td_wfprocess_reldata on WFPROCESS_RELDATA for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_PROCESS_ASSIGN = t1.ID_PROCESS
     and   t2.ID_RELDATA_ASSIGN = t1.ID_RELDATA

    /*  Delete child in "WFPROCESS_RELDATA_RESTRICT"  */
    delete WFPROCESS_RELDATA_RESTRICT
    from   WFPROCESS_RELDATA_RESTRICT t2, deleted t1
    where  t2.ID_PROCESS = t1.ID_PROCESS
     and   t2.ID_RELDATA = t1.ID_RELDATA


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess_reldata_restrict" for table "WFPROCESS_RELDATA_RESTRICT"  */
CREATE trigger ti_wfprocess_reldata_restrict on WFPROCESS_RELDATA_RESTRICT for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS_RELDATA" must exist in order to create child in "WFPROCESS_RELDATA_RESTRICT"  */
    if update(ID_PROCESS) or
       update(ID_RELDATA)
    begin
       if (select count(*)
           from   WFPROCESS_RELDATA t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS
            and   t1.ID_RELDATA = t2.ID_RELDATA) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS_RELDATA. Failed to create a child row in WFPROCESS_RELDATA_RESTRICT.'
           goto error
        end
    end
    /*  The parent "WFPARTICIPANT" must exist in order to create child in "WFPROCESS_RELDATA_RESTRICT"  */
    if update(ID_PARTICIPANT)
    begin
       if (select count(*)
           from   WFPARTICIPANT t1, inserted t2
           where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to create a child row in WFPROCESS_RELDATA_RESTRICT.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_reldata_restrict" for table "WFPROCESS_RELDATA_RESTRICT"  */
CREATE trigger tu_wfprocess_reldata_restrict on WFPROCESS_RELDATA_RESTRICT for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS_RELDATA" must exist in order to modify child in "WFPROCESS_RELDATA_RESTRICT"  */
      if update(ID_PROCESS) or
         update(ID_RELDATA)
      begin
         if (select count(*)
             from   WFPROCESS_RELDATA t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS
              and   t1.ID_RELDATA = t2.ID_RELDATA) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS_RELDATA. Failed to modify the child row in WFPROCESS_RELDATA_RESTRICT.'
             goto error
          end
      end
      /*  The parent "WFPARTICIPANT" must exist in order to modify child in "WFPROCESS_RELDATA_RESTRICT"  */
      if update(ID_PARTICIPANT)
      begin
         if (select count(*)
             from   WFPARTICIPANT t1, inserted t2
             where  t1.ID_PARTICIPANT = t2.ID_PARTICIPANT) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPARTICIPANT. Failed to modify the child row in WFPROCESS_RELDATA_RESTRICT.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_status" for table "WFPROCESS_STATUS"  */
CREATE trigger tu_wfprocess_status on WFPROCESS_STATUS for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFPROCESS_STATUS" to child "WFPROCESS"  */
      if update(ID_PROCESS_STATUS)
      begin
         update WFPROCESS
          set   ID_PROCESS_STATUS = i1.ID_PROCESS_STATUS
         from   WFPROCESS t2, inserted i1, deleted d1
         where  t2.ID_PROCESS_STATUS = d1.ID_PROCESS_STATUS
          and  (i1.ID_PROCESS_STATUS != d1.ID_PROCESS_STATUS)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfprocess_status" for table "WFPROCESS_STATUS"  */
CREATE trigger td_wfprocess_status on WFPROCESS_STATUS for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS"  */
    delete WFPROCESS
    from   WFPROCESS t2, deleted t1
    where  t2.ID_PROCESS_STATUS = t1.ID_PROCESS_STATUS


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfprocess_transition" for table "WFPROCESS_TRANSITION"  */
CREATE trigger ti_wfprocess_transition on WFPROCESS_TRANSITION for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFPROCESS" must exist in order to create child in "WFPROCESS_TRANSITION"  */
    if update(ID_PROCESS)
    begin
       if (select count(*)
           from   WFPROCESS t1, inserted t2
           where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFPROCESS_TRANSITION.'
           goto error
        end
    end
    /*  The parent "WFACTIVITY" must exist in order to create child in "WFPROCESS_TRANSITION"  */
    if update(ID_PROCESS_FROM) or
       update(ID_ACTIVITY_FROM)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS_FROM is null
                           and   ID_ACTIVITY_FROM is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFACTIVITY t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS_FROM
               and   t1.ID_ACTIVITY = t2.ID_ACTIVITY_FROM) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY. Failed to create a child row in WFPROCESS_TRANSITION.'
           goto error
        end
    end
    /*  The parent "WFACTIVITY" must exist in order to create child in "WFPROCESS_TRANSITION"  */
    if update(ID_PROCESS_TO) or
       update(ID_ACTIVITY_TO)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS_TO is null
                           and   ID_ACTIVITY_TO is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFACTIVITY t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS_TO
               and   t1.ID_ACTIVITY = t2.ID_ACTIVITY_TO) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFACTIVITY. Failed to create a child row in WFPROCESS_TRANSITION.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfprocess_transition" for table "WFPROCESS_TRANSITION"  */
CREATE trigger tu_wfprocess_transition on WFPROCESS_TRANSITION for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFPROCESS" must exist in order to modify child in "WFPROCESS_TRANSITION"  */
      if update(ID_PROCESS)
      begin
         if (select count(*)
             from   WFPROCESS t1, inserted t2
             where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFPROCESS_TRANSITION.'
             goto error
          end
      end
      /*  The parent "WFACTIVITY" must exist in order to modify child in "WFPROCESS_TRANSITION"  */
      if update(ID_PROCESS_FROM) or
         update(ID_ACTIVITY_FROM)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS_FROM is null
                             and   ID_ACTIVITY_FROM is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFACTIVITY t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS_FROM
                 and   t1.ID_ACTIVITY = t2.ID_ACTIVITY_FROM) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY. Failed to modify the child row in WFPROCESS_TRANSITION.'
             goto error
          end
      end
      /*  The parent "WFACTIVITY" must exist in order to modify child in "WFPROCESS_TRANSITION"  */
      if update(ID_PROCESS_TO) or
         update(ID_ACTIVITY_TO)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS_TO is null
                             and   ID_ACTIVITY_TO is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFACTIVITY t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS_TO
                 and   t1.ID_ACTIVITY = t2.ID_ACTIVITY_TO) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFACTIVITY. Failed to modify the child row in WFPROCESS_TRANSITION.'
             goto error
          end
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfreldata" for table "WFRELDATA"  */
CREATE trigger ti_wfreldata on WFRELDATA for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFDATATYPE" must exist in order to create child in "WFRELDATA"  */
    if update(ID_DATATYPE)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_DATATYPE is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFDATATYPE t1, inserted t2
              where  t1.ID_DATATYPE = t2.ID_DATATYPE) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFDATATYPE. Failed to create a child row in WFRELDATA.'
           goto error
        end
    end
    /*  The parent "WFPROCESS" must exist in order to create child in "WFRELDATA"  */
    if update(ID_PROCESS)
    begin
       select @numnull = (select count(*)
                          from   inserted
                          where  ID_PROCESS is null)
       if @numnull != @numrows
          if (select count(*)
              from   WFPROCESS t1, inserted t2
              where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows - @numnull
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFPROCESS. Failed to create a child row in WFRELDATA.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfreldata" for table "WFRELDATA"  */
CREATE trigger tu_wfreldata on WFRELDATA for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFDATATYPE" must exist in order to modify child in "WFRELDATA"  */
      if update(ID_DATATYPE)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_DATATYPE is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFDATATYPE t1, inserted t2
                where  t1.ID_DATATYPE = t2.ID_DATATYPE) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFDATATYPE. Failed to modify the child row in WFRELDATA.'
             goto error
          end
      end
      /*  The parent "WFPROCESS" must exist in order to modify child in "WFRELDATA"  */
      if update(ID_PROCESS)
      begin
         select @numnull = (select count(*)
                            from   inserted
                            where  ID_PROCESS is null)
         if @numnull != @numrows
            if (select count(*)
                from   WFPROCESS t1, inserted t2
                where  t1.ID_PROCESS = t2.ID_PROCESS) != @numrows - @numnull
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFPROCESS. Failed to modify the child row in WFRELDATA.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFRELDATA" to child "WFPROCESS_RELDATA"  */
      if update(ID_RELDATA)
      begin
         update WFPROCESS_RELDATA
          set   ID_RELDATA = i1.ID_RELDATA
         from   WFPROCESS_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_RELDATA = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end

      /*  Check and apply change from parent "WFRELDATA" to child "WFACTIVITY_PARAM"  */
      if update(ID_RELDATA)
      begin
         update WFACTIVITY_PARAM
          set   ID_RELDATA = i1.ID_RELDATA
         from   WFACTIVITY_PARAM t2, inserted i1, deleted d1
         where  t2.ID_RELDATA = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end

      /*  Check and apply change from parent "WFRELDATA" to child "WFPROCESS_INST_RELDATA"  */
      if update(ID_RELDATA)
      begin
         update WFPROCESS_INST_RELDATA
          set   ID_RELDATA = i1.ID_RELDATA
         from   WFPROCESS_INST_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_RELDATA = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end
	  
      /*  Check and apply change from parent "WFRELDATA" to child "WFACTIVITY_INST_RELDATA"  */
      if update(ID_RELDATA)
      begin
         update WFACTIVITY_INST_RELDATA
          set   ID_RELDATA = i1.ID_RELDATA
         from   WFACTIVITY_INST_RELDATA t2, inserted i1, deleted d1
         where  t2.ID_RELDATA = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end

      /*  Check and apply change from parent "WFRELDATA" to child "WFACTIVITY_NOTIFY"  */
      if update(ID_RELDATA)
      begin
         update WFACTIVITY_NOTIFY
          set   ID_RELDATA = i1.ID_RELDATA
         from   WFACTIVITY_NOTIFY t2, inserted i1, deleted d1
         where  t2.ID_RELDATA = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end

      /*  Check and apply change from parent "WFRELDATA" to child "WFACTIVITY_NOTIFY"  */
      if update(ID_RELDATA)
      begin
         update WFACTIVITY_NOTIFY
          set   ID_RELDATA_TEMPLATE = i1.ID_RELDATA
         from   WFACTIVITY_NOTIFY t2, inserted i1, deleted d1
         where  t2.ID_RELDATA_TEMPLATE = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end
	  
      /*  Check and apply change from parent "WFRELDATA" to child "WFACTIVITY_PARAM"  */
      if update(ID_RELDATA)
      begin
         update WFACTIVITY_PARAM
          set   ID_RELDATA_DEFAULT = i1.ID_RELDATA
         from   WFACTIVITY_PARAM t2, inserted i1, deleted d1
         where  t2.ID_RELDATA_DEFAULT = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end
	  
      /*  Check and apply change from parent "WFRELDATA" to child "WFACTIVITY"  */
      if update(ID_RELDATA)
      begin
         update WFACTIVITY
          set   ID_RELDATA_LIMIT = i1.ID_RELDATA
         from   WFACTIVITY t2, inserted i1, deleted d1
         where  t2.ID_RELDATA_LIMIT = d1.ID_RELDATA
          and  (i1.ID_RELDATA != d1.ID_RELDATA)
      end

      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfreldata" for table "WFRELDATA"  */
CREATE trigger td_wfreldata on WFRELDATA for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_RELDATA"  */
    delete WFPROCESS_RELDATA
    from   WFPROCESS_RELDATA t2, deleted t1
    where  t2.ID_RELDATA = t1.ID_RELDATA

    /*  Delete child in "WFACTIVITY_PARAM"  */
    delete WFACTIVITY_PARAM
    from   WFACTIVITY_PARAM t2, deleted t1
    where  t2.ID_RELDATA = t1.ID_RELDATA

    /*  Delete child in "WFPROCESS_INST_RELDATA"  */
    delete WFPROCESS_INST_RELDATA
    from   WFPROCESS_INST_RELDATA t2, deleted t1
    where  t2.ID_RELDATA = t1.ID_RELDATA

    /*  Delete child in "WFACTIVITY_INST_RELDATA"  */
    delete WFACTIVITY_INST_RELDATA
    from   WFACTIVITY_INST_RELDATA t2, deleted t1
    where  t2.ID_RELDATA = t1.ID_RELDATA
	
	/*  Delete child in "WFACTIVITY_NOTIFY"  */
    delete WFACTIVITY_NOTIFY
    from   WFACTIVITY_NOTIFY t2, deleted t1
    where  t2.ID_RELDATA = t1.ID_RELDATA
	
	/*  Delete child in "WFACTIVITY_NOTIFY"  */
    delete WFACTIVITY_NOTIFY
    from   WFACTIVITY_NOTIFY t2, deleted t1
    where  t2.ID_RELDATA_TEMPLATE = t1.ID_RELDATA
	
	/*  Delete child in "WFACTIVITY_PARAM"  */
    delete WFACTIVITY_PARAM
    from   WFACTIVITY_PARAM t2, deleted t1
    where  t2.ID_RELDATA_DEFAULT = t1.ID_RELDATA
	
	/*  Delete child in "WFACTIVITY"  */
    delete WFACTIVITY
    from   WFACTIVITY t2, deleted t1
    where  t2.ID_RELDATA_LIMIT = t1.ID_RELDATA

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfstate" for table "WFSTATE"  */
CREATE trigger tu_wfstate on WFSTATE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  Check and apply change from parent "WFSTATE" to child "WFSUBSTATE"  */
      if update(ID_STATE)
      begin
         update WFSUBSTATE
          set   ID_STATE = i1.ID_STATE
         from   WFSUBSTATE t2, inserted i1, deleted d1
         where  t2.ID_STATE = d1.ID_STATE
          and  (i1.ID_STATE != d1.ID_STATE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfstate" for table "WFSTATE"  */
CREATE trigger td_wfstate on WFSTATE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFSUBSTATE"  */
    delete WFSUBSTATE
    from   WFSUBSTATE t2, deleted t1
    where  t2.ID_STATE = t1.ID_STATE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Insert trigger "ti_wfsubstate" for table "WFSUBSTATE"  */
CREATE trigger ti_wfsubstate on WFSUBSTATE for insert as
begin
    declare
       @numrows  int,
       @numnull  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  The parent "WFSTATE" must exist in order to create child in "WFSUBSTATE"  */
    if update(ID_STATE)
    begin
       if (select count(*)
           from   WFSTATE t1, inserted t2
           where  t1.ID_STATE = t2.ID_STATE) != @numrows
        begin
           select @errno  = 50002,
                  @errmsg = 'The parent row was not found in WFSTATE. Failed to create a child row in WFSUBSTATE.'
           goto error
        end
    end

    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Update trigger "tu_wfsubstate" for table "WFSUBSTATE"  */
CREATE trigger tu_wfsubstate on WFSUBSTATE for update as
begin
   declare
      @numrows  int,
      @numnull  int,
      @errno    int,
      @errmsg   varchar(255)

      select  @numrows = @@rowcount
      if @numrows = 0
         return

      /*  The parent "WFSTATE" must exist in order to modify child in "WFSUBSTATE"  */
      if update(ID_STATE)
      begin
         if (select count(*)
             from   WFSTATE t1, inserted t2
             where  t1.ID_STATE = t2.ID_STATE) != @numrows
          begin
             select @errno  = 50003,
                    @errmsg = 'The parent row was not found in WFSTATE. Failed to modify the child row in WFSUBSTATE.'
             goto error
          end
      end
      /*  Check and apply change from parent "WFSUBSTATE" to child "WFPROCESS_INST"  */
      if update(ID_STATE) or
         update(ID_SUBSTATE)
      begin
         update WFPROCESS_INST
          set   ID_STATE = i1.ID_STATE,
                ID_SUBSTATE = i1.ID_SUBSTATE
         from   WFPROCESS_INST t2, inserted i1, deleted d1
         where  t2.ID_STATE = d1.ID_STATE
          and   t2.ID_SUBSTATE = d1.ID_SUBSTATE
          and  (i1.ID_STATE != d1.ID_STATE or
                i1.ID_SUBSTATE != d1.ID_SUBSTATE)
      end

      /*  Check and apply change from parent "WFSUBSTATE" to child "WFACTIVITY_INST"  */
      if update(ID_STATE) or
         update(ID_SUBSTATE)
      begin
         update WFACTIVITY_INST
          set   ID_STATE = i1.ID_STATE,
                ID_SUBSTATE = i1.ID_SUBSTATE
         from   WFACTIVITY_INST t2, inserted i1, deleted d1
         where  t2.ID_STATE = d1.ID_STATE
          and   t2.ID_SUBSTATE = d1.ID_SUBSTATE
          and  (i1.ID_STATE != d1.ID_STATE or
                i1.ID_SUBSTATE != d1.ID_SUBSTATE)
      end


      return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO






/*  Delete trigger "td_wfsubstate" for table "WFSUBSTATE"  */
CREATE trigger td_wfsubstate on WFSUBSTATE for delete as
begin
    declare
       @numrows  int,
       @errno    int,
       @errmsg   varchar(255)

    select  @numrows = @@rowcount
    if @numrows = 0
       return

    /*  Delete child in "WFPROCESS_INST"  */
    delete WFPROCESS_INST
    from   WFPROCESS_INST t2, deleted t1
    where  t2.ID_STATE = t1.ID_STATE
     and   t2.ID_SUBSTATE = t1.ID_SUBSTATE

    /*  Delete child in "WFACTIVITY_INST"  */
    delete WFACTIVITY_INST
    from   WFACTIVITY_INST t2, deleted t1
    where  t2.ID_STATE = t1.ID_STATE
     and   t2.ID_SUBSTATE = t1.ID_SUBSTATE


    return


error:
    raiserror (@errmsg, 16, 1)
    rollback  transaction
end




GO
SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS ON
GO


