/*==============================================================*/
/* Database name :  WORKFLOWGEN 7.10.0                          */
/* Database type :  ORACLE Version 10g and later                */
/* Creation date :  05/01/2018                                  */
/*==============================================================*/

/*==============================================================*/
/* Table : DIRECTORY                                            */
/*==============================================================*/

create table DIRECTORY  (
   ID_DIRECTORY                 INTEGER                  not null,
   DIRNAME                      NVARCHAR2(255)           not null,
   DESCRIPTION                  NVARCHAR2(255),
   DISP_ORDER                   INTEGER,
   DEFAULTDIR                   NVARCHAR2(1),
   READONLY                     NVARCHAR2(1),
   BUILTIN                      NVARCHAR2(1),
   ADS_PATH                     NVARCHAR2(255),
   AUTH                         NVARCHAR2(1),
   PREFIX_GROUPNAME             NVARCHAR2(64),
   TYPE                         NVARCHAR2(255),
   MODE_USER                    NVARCHAR2(255),
   MODE_GROUP                   NVARCHAR2(255),
   DIR_USERNAME                 NVARCHAR2(255),
   DIR_PASSWORD                 NVARCHAR2(64),
   PREFIX_USERNAME              NVARCHAR2(64),
   SYNC_USERS                   NVARCHAR2(1),
   SYNC_GROUPS                  NVARCHAR2(1),
   LDAP_PATH                    NVARCHAR2(255),
   SYNC_ODS                     NVARCHAR2(64),
   SYNC_SUBTREE                 NVARCHAR2(64),
   DOMAIN_NAME                  NVARCHAR2(64),
   SYNC_AUTO                    NVARCHAR2(64),
   USER_DELETION_MODE           NVARCHAR2(64),
   FREQUENCY                    NVARCHAR2(64),
   SYNC_FIELD_USER              NVARCHAR2(255),
   SYNC_FIELD_GROUP             NVARCHAR2(255),
   TEXT_SEPARATOR               NVARCHAR2(64),
   FILE_PATH                    NVARCHAR2(255),
   LDAP_QUERY_GROUPS            CLOB,
   LDAP_QUERY_USERS             CLOB,
   FIELDS_MAPPING_USERS         CLOB,
   FIELDS_MAPPING_GROUPS        CLOB,
   NEW_USER_ACTIVE              NVARCHAR2(1),
   NEW_USER_SELFACTIVATION      NVARCHAR2(1),
   TOKEN                        NVARCHAR2(255),

   constraint PK_DIRECTORY primary key (ID_DIRECTORY)
);


/*==============================================================*/
/* Index : IDX_DIRECTORY_DIRNAME                                */
/*==============================================================*/


create unique index IDX_DIRECTORY_DIRNAME on DIRECTORY (
   DIRNAME ASC
);


/*==============================================================*/
/* Table : GROUPS                                               */
/*==============================================================*/


create table GROUPS  (
   ID_GROUP             INTEGER                          not null,
   ID_DIRECTORY         INTEGER,
   DATE_CREATION        DATE,
   DATE_UPDATE          DATE,
   GROUPNAME            NVARCHAR2(255)                   not null,
   DESCRIPTION          NVARCHAR2(255),
   READONLY             NVARCHAR2(1),
   EMAIL                NVARCHAR2(255),
   ADS_PATH             NVARCHAR2(255),
   ADS_DN               NVARCHAR2(255),
   ADS_CN               NVARCHAR2(255),
   BUILTIN              NVARCHAR2(1),
   GROUPNUMBER          NVARCHAR2(255),
   OBJECTSID            NVARCHAR2(255),
   SYNCHRO              NVARCHAR2(1),
   DATASOURCE_QUERY     NVARCHAR2(2000),
   constraint PK_GROUPS primary key (ID_GROUP),
   constraint FK_GROUPS_REFERENCE_DIRECTOR foreign key (ID_DIRECTORY)
         references DIRECTORY (ID_DIRECTORY)
         on delete cascade
);


/*==============================================================*/
/* Index : "IDX_DIRECTORY_ID_DIRECTORY_FK"                      */
/*==============================================================*/


create index "IDX_DIRECTORY_ID_DIRECTORY_FK" on GROUPS (
   ID_DIRECTORY ASC
);


/*==============================================================*/
/* Index : IDX_GROUPS_GROUPNAME                                 */
/*==============================================================*/


create index IDX_GROUPS_GROUPNAME on GROUPS (
   GROUPNAME ASC
);


/*==============================================================*/
/* Table : PROFILE                                              */
/*==============================================================*/


create table PROFILE  (
   ID_PROFILE           INTEGER                          not null,
   DESCRIPTION          NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   MAPTO_PASSWORD        NVARCHAR2(255),
   MAPTO_USERNAME       NVARCHAR2(255),
   constraint PK_PROFILE primary key (ID_PROFILE)
);


/*==============================================================*/
/* Table : USERS                                                */
/*==============================================================*/


create table USERS  (
   ID_USER              INTEGER                          not null,
   ID_DIRECTORY         INTEGER,
   DATE_CREATION        DATE,
   DATE_UPDATE          DATE,
   LASTNAME             NVARCHAR2(255)                   not null,
   FIRSTNAME            NVARCHAR2(255),
   USERNAME             NVARCHAR2(255)                   not null,
   PASSWORD             NVARCHAR2(255),
   SALT					NVARCHAR2(64),
   EMAIL                NVARCHAR2(255),
   ACTIVE               NVARCHAR2(1),
   READONLY             NVARCHAR2(1),
   BUILTIN              NVARCHAR2(1),
   PHONE                NVARCHAR2(255),
   MOBILE               NVARCHAR2(255),
   PAGER                NVARCHAR2(255),
   FAX                  NVARCHAR2(255),
   OFFICE               NVARCHAR2(255),
   DEPARTMENT           NVARCHAR2(255),
   COMPANY              NVARCHAR2(255),
   JOBTITLE             NVARCHAR2(255),
   INITIALS             NVARCHAR2(255),
   PERSONALTITLE        NVARCHAR2(255),
   EMPLOYEENUMBER       NVARCHAR2(255),
   EMPLOYEETYPE         NVARCHAR2(255),
   POSTALADDRESS        NVARCHAR2(255),
   POSTALCODE           NVARCHAR2(255),
   CITY                 NVARCHAR2(255),
   STATE                NVARCHAR2(255),
   COUNTRY              NVARCHAR2(255),
   ADS_PATH             NVARCHAR2(255),
   ADS_DN               NVARCHAR2(255),
   ADS_CN               NVARCHAR2(255),
   ARCHIVE              NVARCHAR2(1),
   DATE_ARCHIVE         DATE,
   DATE_LAST_VISIT      DATE,
   EXTATT_1             NVARCHAR2(255),
   EXTATT_2             NVARCHAR2(255),
   EXTATT_3             NVARCHAR2(255),
   EXTATT_4             NVARCHAR2(255),
   EXTATT_5             NVARCHAR2(255),
   MAPTO_PASSWORD       NVARCHAR2(255),
   MAPTO_USERNAME       NVARCHAR2(255),
   OBJECTSID            NVARCHAR2(255),
   SYNCHRO              NVARCHAR2(1),
   LANGUAGE             NVARCHAR2(64),
   LANGUAGE_PREF        NVARCHAR2(64),
   ID_USER_MANAGER      INTEGER,
   ID_TIMEZONE          INTEGER,
   DATE_ACTIVATION      DATE,
   CONN_ATTEMPTS	    INTEGER,
   RESETPWD_TOKEN       NVARCHAR2(255),
   RESETPWD_TIME      	DATE,
   constraint PK_USERS primary key (ID_USER),
   constraint FK_USERS_REFERENCE_DIRECTOR foreign key (ID_DIRECTORY)
         references DIRECTORY (ID_DIRECTORY)
         on delete cascade,
   constraint FK_USERS_ID_USER_MANAGER foreign key (ID_USER_MANAGER)
         references USERS (ID_USER) on delete set null
);


/*==============================================================*/
/* Table : USERS_VIEWS                                          */
/*==============================================================*/

create table USERS_VIEWS(
   ID_USER              INTEGER                          not null,
   NAME                 NVARCHAR2(64)                    not null,
   DESCRIPTION          NVARCHAR2(255),
   "DEFAULT"            NVARCHAR2(1),
   QUERY                NVARCHAR2(255),
   VALUE                CLOB,
   PORTAL               NVARCHAR2(1),
   NUM_VIEW             INTEGER                          not null,
   FILTER_ID_PROCESS    INTEGER,
   SHARED               NVARCHAR2(1),
   constraint PK_USERS_VIEWS primary key (ID_USER, NUM_VIEW),
   constraint FK_USERSVIEWS_REF_USERS foreign key (ID_USER)
         references USERS (ID_USER)
         on delete cascade
);


/*==============================================================*/
/* Index : "IDX_USERS_ID_DIRECTORY_FK"                          */
/*==============================================================*/

create index "IDX_USERS_ID_DIRECTORY_FK" on USERS (
   ID_DIRECTORY ASC
);


/*==============================================================*/
/* Index : "IDX_USERS_ID_USER_MANAGER"                          */
/*==============================================================*/

create index "IDX_USERS_ID_USER_MANAGER" on USERS (
   ID_USER_MANAGER ASC
);


/*==============================================================*/
/* Index : IDX_USERS_USERNAME                                   */
/*==============================================================*/

create unique index IDX_USERS_USERNAME on USERS (
   USERNAME ASC
);


/*==============================================================*/
/* Index : IDX_UPPER_USERS_USERNAME                             */
/*==============================================================*/

create unique index IDX_UPPER_USERS_USERNAME on USERS (
   UPPER(USERNAME) ASC
);


/*==============================================================*/
/* Index : IDX_UPPER_USERS_LASTNAME                             */
/*==============================================================*/

create index IDX_UPPER_USERS_LASTNAME on USERS (
   UPPER(LASTNAME) ASC
);


/*==============================================================*/
/* Index : IDX_UPPER_USERS_LASTFIRSTNAME                        */
/*==============================================================*/

create index IDX_UPPER_USERS_LASTFIRSTNAME on USERS (
   UPPER(LASTNAME) ASC,
   UPPER(FIRSTNAME) ASC
);


/*==============================================================*/
/* Index : "IDX_USERS_ACTIVE"                                   */
/*==============================================================*/

create index IDX_USERS_ACTIVE on USERS (
   ACTIVE ASC
);


/*==============================================================*/
/* Table : USERS_GROUPS                                         */
/*==============================================================*/


create table USERS_GROUPS  (
   ID_USER              INTEGER                          not null,
   ID_GROUP             INTEGER                          not null,
   constraint PK_USERS_GROUPS primary key (ID_USER, ID_GROUP),
   constraint FK_USERS_GR_REFERENCE_USERS foreign key (ID_USER)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_USERS_GR_REFERENCE_GROUPS foreign key (ID_GROUP)
         references GROUPS (ID_GROUP)
         on delete cascade
);


/*==============================================================*/
/* Index : "IDX_USERS_GROUPS_ID_USER"                           */
/*==============================================================*/


create index "IDX_USERS_GROUPS_ID_USER" on USERS_GROUPS (
   ID_USER ASC
);


/*==============================================================*/
/* Index : IDX_USERS_GROUPS_ID_GROUP                            */
/*==============================================================*/


create index IDX_USERS_GROUPS_ID_GROUP on USERS_GROUPS (
   ID_GROUP ASC
);



/*==============================================================*/
/* Table : USERS_PROFILE                                        */
/*==============================================================*/


create table USERS_PROFILE  (
   ID_USER              INTEGER                          not null,
   ID_PROFILE           INTEGER                          not null,
   constraint PK_USERS_PROFILE primary key (ID_USER, ID_PROFILE),
   constraint FK_USERS_PR_REFERENCE_USERS foreign key (ID_USER)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_USERS_PR_REFERENCE_PROFILE foreign key (ID_PROFILE)
         references PROFILE (ID_PROFILE)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_USERS_PROFILE_ID_USER                            */
/*==============================================================*/


create index IDX_USERS_PROFILE_ID_USER on USERS_PROFILE (
   ID_USER ASC
);


/*==============================================================*/
/* Index : IDX_USERS_PROFILE_ID_PROFILE                         */
/*==============================================================*/


create index IDX_USERS_PROFILE_ID_PROFILE on USERS_PROFILE (
   ID_PROFILE ASC
);



/*==============================================================*/
/* Table : USERS_PREFS                                          */
/*==============================================================*/


create table USERS_PREFS  (
   ID_USER              INTEGER                          not null,
   NAME                       NVARCHAR2(64)                    not null,
   VALUE                                NVARCHAR2(4000),
   CLSID                                NVARCHAR2(64),
   constraint PK_USERS_PREFS primary key (ID_USER, NAME),
   constraint FK_USERS_PREFS_REFERENCE_USERS foreign key (ID_USER)
         references USERS (ID_USER)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_USERS_PREFS_ID_USER                              */
/*==============================================================*/

create index IDX_USERS_PREFS_ID_USER on USERS_PREFS (
   ID_USER ASC
);

/*==============================================================*/
/* Index : IDX_USERS_PREFS_NAME                                 */
/*==============================================================*/


create index IDX_USERS_PREFS_NAME on USERS_PREFS (
   NAME ASC
);


/*==============================================================*/
/* Table : WFACTIVITY_ASSIGN_TYPE                               */
/*==============================================================*/


create table WFACTIVITY_ASSIGN_TYPE  (
   ID_ASSIGN_TYPE       NVARCHAR2(64)                     not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFACTIVITY_ASSIGN_TYPE primary key (ID_ASSIGN_TYPE)
);


/*==============================================================*/
/* Table : WFACTIVITY_TYPE                                      */
/*==============================================================*/


create table WFACTIVITY_TYPE  (
   ID_ACTIVITY_TYPE     NVARCHAR2(64)                     not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   HELP_FR              NVARCHAR2(255),
   HELP_EN              NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFACTIVITY_TYPE primary key (ID_ACTIVITY_TYPE)
);


/*==============================================================*/
/* Table : WFAPPLICATION_TYPE                                   */
/*==============================================================*/


create table WFAPPLICATION_TYPE  (
   ID_APP_TYPE          NVARCHAR2(64)                     not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFAPPLICATION_TYPE primary key (ID_APP_TYPE)
);


/*==============================================================*/
/* Table : WFCATEGORY                                           */
/*==============================================================*/


create table WFCATEGORY  (
   ID_CATEGORY          INTEGER                          not null,
   NAME                 NVARCHAR2(64)                     not null,
   DESCRIPTION          NVARCHAR2(255),
   constraint PK_WFCATEGORY primary key (ID_CATEGORY)
);


/*==============================================================*/
/* Index : IDX_WFCATEGORY_PK                                    */
/*==============================================================*/


create unique index IDX_WFCATEGORY_PK on WFCATEGORY (
   ID_CATEGORY ASC,
   NAME ASC
);


/*==============================================================*/
/* Index : IDX_WFCATEGORY_NAME                                  */
/*==============================================================*/


create index IDX_WFCATEGORY_NAME on WFCATEGORY (
   NAME ASC
);


/*==============================================================*/
/* Table : WFCOUNTER                                            */
/*==============================================================*/


create table WFCOUNTER  (
   ID_COUNTER           NVARCHAR2(255)                   not null,
   COUNTER_VALUE        INTEGER,
   constraint PK_WFCOUNTER primary key (ID_COUNTER)
);


/*==============================================================*/
/* Table : WFDATASET                                            */
/*==============================================================*/


create table WFDATASET  (
   ID_DATASET           INTEGER                          not null,
   ID_DATATYPE          NVARCHAR2(64),
   MULTIVAL             NVARCHAR2(1),
   DATE_CREATION        DATE,
   DATE_UPDATE          DATE,
   RUNTIME              NVARCHAR2(1),
   STOREINDB            NVARCHAR2(1),
   constraint PK_WFDATASET primary key (ID_DATASET)
);


/*==============================================================*/
/* Index : IDX_WFDATASET_ID_DATATYPE                            */
/*==============================================================*/


create index IDX_WFDATASET_ID_DATATYPE on WFDATASET (
   ID_DATATYPE ASC
);


/*==============================================================*/
/* Table : WFDATASET_VALUE                                      */
/*==============================================================*/


create table WFDATASET_VALUE  (
   ID_DATASET           INTEGER                          not null,
   NUM_VALUE            INTEGER                          not null,
   VALUE_TEXT           NVARCHAR2(4000),
   VALUE_DATETIME       DATE,
   VALUE_NUMERIC        FLOAT,
   VALUE_FILE_NAME      NVARCHAR2(255),
   VALUE_FILE_SIZE      FLOAT,
   VALUE_FILE_CONTENTTYPE NVARCHAR2(255),
   VALUE_FILE_DESCRIPTION NVARCHAR2(255),
   VALUE_FILE_ORIGINALPATH NVARCHAR2(255),
   VALUE_FILE_DATELASTMODIFIED DATE,
   VALUE_FILE_CONTENT BLOB,
   constraint PK_WFDATASET_VALUE primary key (ID_DATASET, NUM_VALUE),
   constraint FK_WFDATASE_REFERENCE_WFDATASE foreign key (ID_DATASET)
         references WFDATASET (ID_DATASET)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFDATASET_VALUE_ID_DATASET                       */
/*==============================================================*/


create index IDX_WFDATASET_VALUE_ID_DATASET on WFDATASET_VALUE (
   ID_DATASET ASC
);


/*==============================================================*/
/* Table : WFDATATYPE                                           */
/*==============================================================*/


create table WFDATATYPE  (
   ID_DATATYPE          NVARCHAR2(64)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFDATATYPE primary key (ID_DATATYPE)
);


/*==============================================================*/
/* Table : WFDURATION_UNIT                                      */
/*==============================================================*/


create table WFDURATION_UNIT  (
   ID_DURATION_UNIT     NVARCHAR2(10)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFDURATION_UNIT primary key (ID_DURATION_UNIT)
);

/*==============================================================*/
/* Table : WFFOLDER                                             */
/*==============================================================*/


create table WFFOLDER  (
   ID_FOLDER            INTEGER                          not null,
   NAME                 NVARCHAR2(64)                    not null,
   ID_FOLDER_PARENT     INTEGER,
   DESCRIPTION          NVARCHAR2(255),
   constraint PK_WFFOLDER primary key (ID_FOLDER)
);


/*==============================================================*/
/* Index : IDX_WFFOLDER_ID_FOLDER_PARENT                        */
/*==============================================================*/


create index IDX_WFFOLDER_ID_FOLDER_PARENT on WFFOLDER (
   ID_FOLDER_PARENT ASC
);


/*==============================================================*/
/* Table : WFPARTICIPANT_ROLE                                   */
/*==============================================================*/


create table WFPARTICIPANT_ROLE  (
   ID_PARTICIPANT_ROLE  NVARCHAR2(64)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFPARTICIPANT_ROLE primary key (ID_PARTICIPANT_ROLE)
);


/*==============================================================*/
/* Table : WFPARTICIPANT_TYPE                                   */
/*==============================================================*/


create table WFPARTICIPANT_TYPE  (
   ID_PARTICIPANT_TYPE  NVARCHAR2(64)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFPARTICIPANT_TYPE primary key (ID_PARTICIPANT_TYPE)
);


/*==============================================================*/
/* Table : WFPERM_TYPE                                          */
/*==============================================================*/


create table WFPERM_TYPE  (
   ID_PERM_TYPE         NVARCHAR2(64)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFPERM_TYPE primary key (ID_PERM_TYPE)
);


/*==============================================================*/
/* Table : WFPROCESS_STATUS                                     */
/*==============================================================*/


create table WFPROCESS_STATUS  (
   ID_PROCESS_STATUS    NVARCHAR2(64)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFPROCESS_STATUS primary key (ID_PROCESS_STATUS)
);


/*==============================================================*/
/* Table : WFSTATE                                              */
/*==============================================================*/


create table WFSTATE  (
   ID_STATE             NVARCHAR2(20)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFSTATE primary key (ID_STATE)
);


/*==============================================================*/
/* Table : WFSUBSTATE                                           */
/*==============================================================*/


create table WFSUBSTATE  (
   ID_STATE             NVARCHAR2(20)                    not null,
   ID_SUBSTATE          NVARCHAR2(30)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFSUBSTATE primary key (ID_STATE, ID_SUBSTATE),
   constraint FK_WFSUBSTA_REFERENCE_WFSTATE foreign key (ID_STATE)
         references WFSTATE (ID_STATE)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFSUBSTATE_ID_STATE_FK                           */
/*==============================================================*/


create index IDX_WFSUBSTATE_ID_STATE_FK on WFSUBSTATE (
   ID_STATE ASC
);


/*==============================================================*/
/* Index : IDX_WFSUBSTATE_ID_SUBSTATE                           */
/*==============================================================*/


create index IDX_WFSUBSTATE_ID_SUBSTATE on WFSUBSTATE (
   ID_SUBSTATE ASC
);


/*==============================================================*/
/* Table : WFPROCESS                                            */
/*==============================================================*/


create table WFPROCESS  (
   ID_PROCESS           INTEGER                          not null,
   ID_FOLDER            INTEGER,
   NAME                 NVARCHAR2(64)                    not null,
   DESCRIPTION          NVARCHAR2(255),
   VERSION              INTEGER                          not null,
   LIMIT                INTEGER,
   ID_DURATION_UNIT     NVARCHAR2(10),
   ID_PROCESS_STATUS    NVARCHAR2(64),
   DATE_CREATION        DATE,
   DATE_UPDATE          DATE,
   ID_USER_CREATION     INTEGER,
   ID_USER_UPDATE       INTEGER,
   HELP                 CLOB,
   HELP_LINK            NVARCHAR2(255),
   HELP_MAIL            NVARCHAR2(255),
   ARCHIVE_ACTIVITY_RESULT NVARCHAR2(1),
   NOTIFY_COMPLETE      NVARCHAR2(1),
   XPDL_WF              CLOB,
   DURATION_WORKHOUR    NVARCHAR2(1),
   SUBFLOW              NVARCHAR2(1),
   ACCESSLEVEL          NVARCHAR2(64),
   RELDATA_STOREINDB    NVARCHAR2(1),
   BUILTIN_FORM		NVARCHAR2(1),
   constraint PK_WFPROCESS primary key (ID_PROCESS),
   constraint FK_WFPROCES_REFERENCE_WFFOLDER foreign key (ID_FOLDER)
         references WFFOLDER (ID_FOLDER)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_WFDURATI foreign key (ID_DURATION_UNIT)
         references WFDURATION_UNIT (ID_DURATION_UNIT)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFPROCES2 foreign key (ID_PROCESS_STATUS)
         references WFPROCESS_STATUS (ID_PROCESS_STATUS)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_ID_USER_UPDATE                         */
/*==============================================================*/


create index IDX_WFPROCESS_ID_USER_UPDATE on WFPROCESS (
   ID_USER_UPDATE ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_ID_USER_CREATION                       */
/*==============================================================*/


create index IDX_WFPROCESS_ID_USER_CREATION on WFPROCESS (
   ID_USER_CREATION ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_ID_DURATION_UNIT                       */
/*==============================================================*/


create index IDX_WFPROCESS_ID_DURATION_UNIT on WFPROCESS (
   ID_DURATION_UNIT ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_ID_FOLDER                              */
/*==============================================================*/


create index IDX_WFPROCESS_ID_FOLDER on WFPROCESS (
   ID_FOLDER ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_ID_PROCESS_STATU                      */
/*==============================================================*/


create index IDX_WFPROCESS_ID_PROCESS_STATU on WFPROCESS (
   ID_PROCESS_STATUS ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_NAME_VERSION                           */
/*==============================================================*/


create unique index IDX_WFPROCESS_NAME_VERSION on WFPROCESS (
   NAME ASC,
   VERSION ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_NAME                                   */
/*==============================================================*/


create index IDX_WFPROCESS_NAME on WFPROCESS (
   NAME ASC
);


/*==============================================================*/
/* Table : WFPROCESS_CATEGORY                                   */
/*==============================================================*/


create table WFPROCESS_CATEGORY  (
   ID_PROCESS           INTEGER                          not null,
   ID_CATEGORY          INTEGER                          not null,
   constraint PK_WFPROCESS_CATEGORY primary key (ID_PROCESS, ID_CATEGORY),
   constraint FK_WFPROCES_REFEREN_WFPROCES3 foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_WFCATEGO foreign key (ID_CATEGORY)
         references WFCATEGORY (ID_CATEGORY)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_CATEGORY_ID_CAT                        */
/*==============================================================*/


create index IDX_WFPROCESS_CATEGORY_ID_CAT on WFPROCESS_CATEGORY (
   ID_CATEGORY ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_ID_PROCESS                             */
/*==============================================================*/


create index IDX_WFPROCESS_ID_PROCESS on WFPROCESS_CATEGORY (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Table : WFPROCESS_INST                                       */
/*==============================================================*/


create table WFPROCESS_INST  (
   ID_PROCESS_INST      INTEGER                          not null,
   ID_PROCESS           INTEGER,
   DESCRIPTION          NVARCHAR2(255),
   NAME                 NVARCHAR2(64),
   ID_STATE             NVARCHAR2(20),
   ID_SUBSTATE          NVARCHAR2(30),
   ID_USER_REQUESTER    INTEGER,
   ID_USER_REQUESTER_REAL INTEGER,
   ID_USER_ABORTED      INTEGER,
   DATE_OPEN            DATE,
   DATE_START           DATE,
   DATE_CLOSE           DATE,
   DATE_UPDATE          DATE,
   DATE_STATE_UPDATE    DATE,
   DATE_LIMIT           DATE,
   PRIORITY             NVARCHAR2(255),
   TEST                 NVARCHAR2(1),
   ID_PARENTPROCESS_INST INTEGER,
   ID_PARENTACTIVITY_INST INTEGER,
   ID_EXEC_TYPE         NVARCHAR2(64),
   ID_EXCEPTION_TYPE    NVARCHAR2(64),
   APP_ERROR_CODE       NVARCHAR2(20),
   APP_ERROR_MSG        NVARCHAR2(255),
   ID_PROCESS_INST_REL  INTEGER,
   ID_PROCESS_INST_REL_MONTH INTEGER,
   ID_PROCESS_INST_REL_YEAR INTEGER,
   constraint PK_WFPROCESS_INST primary key (ID_PROCESS_INST),
   constraint FK_WFPROCES_REFERENCE_WFSUBSTA foreign key (ID_STATE, ID_SUBSTATE)
         references WFSUBSTATE (ID_STATE, ID_SUBSTATE)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFPROCES8 foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_USERS2 foreign key (ID_USER_REQUESTER)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_USERS3 foreign key (ID_USER_ABORTED)
         references USERS (ID_USER)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_INST_ID_USR_REQ                        */
/*==============================================================*/


create index IDX_WFPROCESS_INST_ID_USR_REQ on WFPROCESS_INST (
   ID_USER_REQUESTER ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_INST_ID_USR_ABOR                       */
/*==============================================================*/


create index IDX_WFPROCESS_INST_ID_USR_ABOR on WFPROCESS_INST (
   ID_USER_ABORTED ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_INST_ID_PROCESS                        */
/*==============================================================*/


create index IDX_WFPROCESS_INST_ID_PROCESS on WFPROCESS_INST (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_INST_ID_STATE_SB                       */
/*==============================================================*/


create index IDX_WFPROCESS_INST_ID_STATE_SB on WFPROCESS_INST (
   ID_STATE ASC,
   ID_SUBSTATE ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCESS_INST_DATELIMIT                         */
/*==============================================================*/


create index IDX_WFPROCESS_INST_DATELIMIT on WFPROCESS_INST (
   ID_STATE ASC,
   DATE_LIMIT ASC
);


/*==============================================================*/
/* Table : WFRELDATA                                            */
/*==============================================================*/


create table WFRELDATA  (
   ID_RELDATA           INTEGER                          not null,
   NAME                 NVARCHAR2(64)            not null,
   DESCRIPTION          NVARCHAR2(255),
   GLOBAL_SCOPE         NVARCHAR2(1),
   ID_PROCESS           INTEGER,
   ID_DATATYPE          NVARCHAR2(64),
   MULTIVAL             NVARCHAR2(255),
   FORMAT_STRING	NVARCHAR2(255),
   FORMAT_CULTURE	NVARCHAR2(10),
   FORMAT_PRECISION	INTEGER,
   FORMAT_TIMEZONE	INTEGER,
   constraint PK_WFRELDATA primary key (ID_RELDATA),
   constraint FK_WFRELDAT_REFERENCE_WFDATATY foreign key (ID_DATATYPE)
         references WFDATATYPE (ID_DATATYPE)
         on delete cascade,
   constraint FK_WFRELDAT_REFERENCE_WFPROCES foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFRELDATE_ID_DATATYPE                            */
/*==============================================================*/


create index IDX_WFRELDATE_ID_DATATYPE on WFRELDATA (
   ID_DATATYPE ASC
);


/*==============================================================*/
/* Index : IDX_WFRELDATA_ID_PROCESS                             */
/*==============================================================*/


create index IDX_WFRELDATA_ID_PROCESS on WFRELDATA (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Index : IDX_WFRELDATA_NAME                             */
/*==============================================================*/


create index IDX_WFRELDATA_NAME on WFRELDATA (
   NAME ASC
);


/*==============================================================*/
/* Table : WFAPPLICATION                                        */
/*==============================================================*/


create table WFAPPLICATION  (
   ID_APPLICATION          INTEGER                       not null,
   NAME                    NVARCHAR2(64)                 not null,
   DESCRIPTION             NVARCHAR2(255),
   ID_APP_TYPE             NVARCHAR2(64),
   ENCTYPE                 NVARCHAR2(255),
   URL                     NVARCHAR2(255),
   WSDL_URL                NVARCHAR2(1024),
   WEBMETHOD               NVARCHAR2(255),
   CONTEXT_SCHEMA          NVARCHAR2(25),
   CONTEXT_SCHEMA_EMBEDDED NVARCHAR2(1),
   USERNAME                NVARCHAR2(255),
   PASSWORD                NVARCHAR2(255),
   ACTIVE                  NVARCHAR2(1),
   DEFAULTAPP              NVARCHAR2(1),
   DISP_ORDER              INTEGER,
   ASSEMBLY                NVARCHAR2(1024),
   CLASS                   NVARCHAR2(255),
   TOKEN                   NVARCHAR2(255),
   CLIENT_ID               NVARCHAR2(255),
   constraint PK_WFAPPLICATION primary key (ID_APPLICATION),
   constraint FK_WFAPPLIC_REFEREN_WFAPPLIC2 foreign key (ID_APP_TYPE)
         references WFAPPLICATION_TYPE (ID_APP_TYPE)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFAPPLICATION_ID_APP_TYPE                        */
/*==============================================================*/


create index IDX_WFAPPLICATION_ID_APP_TYPE on WFAPPLICATION (
   ID_APP_TYPE ASC
);


/*==============================================================*/
/* Index : IDX_WFAPPLICATION_APP_NAME                           */
/*==============================================================*/


create unique index IDX_WFAPPLICATION_APP_NAME on WFAPPLICATION (
   NAME ASC
);


/*==============================================================*/
/* Table : WFAPPLICATION_PARAM                                  */
/*==============================================================*/


create table WFAPPLICATION_PARAM  (
   ID_APPLICATION       INTEGER                         not null,
   NUM_PARAM            INTEGER                         not null,
   NAME                 NVARCHAR2(64)            not null,
   DESCRIPTION          NVARCHAR2(255),
   ID_DATATYPE          NVARCHAR2(64),
   DIRECTION            NVARCHAR2(64),
   "DEFAULT"            NVARCHAR2(1),
   REQUIRED             NVARCHAR2(1),
   constraint PK_WFAPPLICATION_PARAM primary key (ID_APPLICATION, NUM_PARAM),
   constraint FK_WFAPPLIC_REFERENCE_WFAPPLIC foreign key (ID_APPLICATION)
         references WFAPPLICATION (ID_APPLICATION)
         on delete cascade,
   constraint FK_WFAPPLIC_REFERENCE_WFDATATY foreign key (ID_DATATYPE)
         references WFDATATYPE (ID_DATATYPE)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFAPP_PARAM_NUM_PARAM                            */
/*==============================================================*/


create index IDX_WFAPP_PARAM_NUM_PARAM on WFAPPLICATION_PARAM (
   NUM_PARAM ASC
);


/*==============================================================*/
/* Index : IDX_WFAPP_PARAM_ID_APPLICATION                       */
/*==============================================================*/


create index IDX_WFAPP_PARAM_ID_APPLICATION on WFAPPLICATION_PARAM (
   ID_APPLICATION ASC
);


/*==============================================================*/
/* Index : IDX_WFAPP_PARAM_ID_DATATYPE                          */
/*==============================================================*/


create index IDX_WFAPP_PARAM_ID_DATATYPE on WFAPPLICATION_PARAM (
   ID_DATATYPE ASC
);


/*==============================================================*/
/* Table : WFPARTICIPANT                                        */
/*==============================================================*/


create table WFPARTICIPANT  (
   ID_PARTICIPANT       INTEGER                          not null,
   NAME                 NVARCHAR2(64)                    not null,
   DESCRIPTION          NVARCHAR2(255),
   GLOBAL_SCOPE         NVARCHAR2(1),
   ID_PROCESS           INTEGER,
   ID_PARTICIPANT_TYPE  NVARCHAR2(64),
   constraint PK_WFPARTICIPANT primary key (ID_PARTICIPANT),
   constraint FK_WFPARTIC_REFERENCE_WFPROCES foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_WFPARTIC_REFEREN_WFPARTIC2 foreign key (ID_PARTICIPANT_TYPE)
         references WFPARTICIPANT_TYPE (ID_PARTICIPANT_TYPE)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPART_ID_PART_TYPE                              */
/*==============================================================*/


create index IDX_WFPART_ID_PART_TYPE on WFPARTICIPANT (
   ID_PARTICIPANT_TYPE ASC
);


/*==============================================================*/
/* Index : IDX_WFPART_ID_PROCESS                                */
/*==============================================================*/


create index IDX_WFPART_ID_PROCESS on WFPARTICIPANT (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Index : IDX_WFPART_NAME                                      */
/*==============================================================*/


create index IDX_WFPART_NAME on WFPARTICIPANT (
   NAME ASC
);


/*==============================================================*/
/* Table : WFPROCESS_INST_RELDATA                               */
/*==============================================================*/


create table WFPROCESS_INST_RELDATA  (
   ID_PROCESS_INST      INTEGER                          not null,
   ID_RELDATA           INTEGER                          not null,
   DIRECTION            NVARCHAR2(64),
   ID_DATASET           INTEGER,
   DATALOCK             NVARCHAR2(1),
   DATE_LOCK            DATE,
   ID_USER_LOCK_BY      INTEGER,
   constraint PK_WFPROCESS_INST_RELDATA primary key (ID_PROCESS_INST, ID_RELDATA),
   constraint FK_WFPROCES_REFEREN_WFPROCES4 foreign key (ID_PROCESS_INST)
         references WFPROCESS_INST (ID_PROCESS_INST)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFRELDAT3 foreign key (ID_RELDATA)
         references WFRELDATA (ID_RELDATA)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_USERS foreign key (ID_USER_LOCK_BY)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFDATASET foreign key (ID_DATASET)
         references WFDATASET (ID_DATASET)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROC_INS_RLDA_ID_USR_LOC                       */
/*==============================================================*/


create index IDX_WFPROC_INS_RLDA_ID_USR_LOC on WFPROCESS_INST_RELDATA (
   ID_USER_LOCK_BY ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_INS_RLDA_ID_DATASET                       */
/*==============================================================*/


create index IDX_WFPROC_INS_RLDA_ID_DATASET on WFPROCESS_INST_RELDATA (
   ID_DATASET ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_INS_RLDA_ID_PROCINS                       */
/*==============================================================*/


create index IDX_WFPROC_INS_RLDA_ID_PROCINS on WFPROCESS_INST_RELDATA (
   ID_PROCESS_INST ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_INS_RLDA_ID_RELDATA                       */
/*==============================================================*/


create index IDX_WFPROC_INS_RLDA_ID_RELDATA on WFPROCESS_INST_RELDATA (
   ID_RELDATA ASC
);


/*==============================================================*/
/* Table : WFPROCESS_INST_COMMENT                               */
/*==============================================================*/

create table WFPROCESS_INST_COMMENT (
    ID_PROCESS_INST        INTEGER                    not null,
    NUM_COMMENT            INTEGER                    not null,
    ID_USER_AUTHOR         INTEGER                    not null,
    DATE_POST              DATE,
    MESSAGE                NVARCHAR2(2000),
    TAG                    NVARCHAR2(2000),
    GEOLOC_LATITUDE        FLOAT,
    GEOLOC_LONGITUDE       FLOAT,
    GEOLOC_ALTITUDE        FLOAT,
    constraint PK_WFPROCESS_INST_COMMENT primary key (ID_PROCESS_INST, NUM_COMMENT),
    constraint FK_PROC_INS_COM_REF_PROC_INS foreign key (ID_PROCESS_INST)
        references WFPROCESS_INST (ID_PROCESS_INST)
        on delete cascade,
    constraint FK_PROC_INS_COM_REF_USERS foreign key (ID_USER_AUTHOR)
        references USERS (ID_USER)
        on delete cascade
);


/*==============================================================*/
/* Index : IDX_USERS_WFPROC_INS_COM                             */
/*==============================================================*/


create index IDX_USERS_WFPROC_INS_COM on WFPROCESS_INST_COMMENT (
    ID_USER_AUTHOR ASC
);


/*==============================================================*/
/* Index : IDX_NUM_WFPROC_INS_COM                               */
/*==============================================================*/


create index IDX_NUM_WFPROC_INS_COM on WFPROCESS_INST_COMMENT (
    NUM_COMMENT ASC
);


/*==============================================================*/
/* Index : IDX_ID_WFPROC_INS_COM                                */
/*==============================================================*/


create index IDX_ID_WFPROC_INS_COM on WFPROCESS_INST_COMMENT (
    ID_PROCESS_INST ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_INS_COM_DATE_POST                         */
/*==============================================================*/

create index IDX_WFPROC_INS_COM_DATE_POST on WFPROCESS_INST_COMMENT (
   DATE_POST ASC
);


/*==============================================================*/
/* Table : WFPROCESS_PARTICIPANT                                */
/*==============================================================*/


create table WFPROCESS_PARTICIPANT  (
   ID_PROCESS           INTEGER                          not null,
   ID_PARTICIPANT       INTEGER                          not null,
   ID_PARTICIPANT_ROLE  NVARCHAR2(64),
   VIEW_GRAPHICS        NVARCHAR2(1),
   REASSIGN_ACTION      NVARCHAR2(1),
   CANCEL_REQUEST       NVARCHAR2(1),
   VIEW_STATISTICS      NVARCHAR2(1),
   SUPERVISOR_ACCESSRIGHTS  INTEGER,
   DATASOURCE_QUERY     NVARCHAR2(2000),
   DISP_ORDER           INTEGER,
   COMMENTS_PERMISSIONS NVARCHAR2(5),
   constraint PK_WFPROCESS_PARTICIPANT primary key (ID_PROCESS, ID_PARTICIPANT),
   constraint FK_WFPROCES_REFEREN_WFPARTIC2 foreign key (ID_PARTICIPANT_ROLE)
         references WFPARTICIPANT_ROLE (ID_PARTICIPANT_ROLE)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFPROCES5 foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFPARTIC3 foreign key (ID_PARTICIPANT)
         references WFPARTICIPANT (ID_PARTICIPANT)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROC_PART_ID_PART_ROLE                         */
/*==============================================================*/


create index IDX_WFPROC_PART_ID_PART_ROLE on WFPROCESS_PARTICIPANT (
   ID_PARTICIPANT_ROLE ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_PART_ID_PART                              */
/*==============================================================*/


create index IDX_WFPROC_PART_ID_PART on WFPROCESS_PARTICIPANT (
   ID_PARTICIPANT ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_PART_ID_PROCESS                           */
/*==============================================================*/


create index IDX_WFPROC_PART_ID_PROCESS on WFPROCESS_PARTICIPANT (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Table : WFDELEGATE                                           */
/*==============================================================*/


create table WFDELEGATE (
   ID_DELEGATE          INTEGER                          not null,
   ID_PROCESS           INTEGER,
   ID_PARTICIPANT       INTEGER,
   ID_USER              INTEGER,
   ID_USER_DELEGATE     INTEGER,
   DATE_BEGIN           DATE,
   DATE_END             DATE,
   constraint PK_WFDELEGATE primary key (ID_DELEGATE),
   constraint FK_WFDELEGA_REFERENCE_WFPROCES foreign key (ID_PROCESS, ID_PARTICIPANT)
      references WFPROCESS_PARTICIPANT (ID_PROCESS, ID_PARTICIPANT)
      on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFDELEGATE_ID_USER                               */
/*==============================================================*/

create index IDX_WFDELEGATE_ID_USER on WFDELEGATE (
   ID_USER ASC
);


/*==============================================================*/
/* Index : IDX_WFDELEGATE_ID_USER_DELEG                         */
/*==============================================================*/

create index IDX_WFDELEGATE_ID_USER_DELEG on WFDELEGATE (
   ID_USER_DELEGATE ASC
);


/*==============================================================*/
/* Index : IDX_WFDELEGATE_PROCESS_PART                          */
/*==============================================================*/

create index IDX_WFDELEGATE_PROCESS_PART on WFDELEGATE (
   ID_PROCESS ASC,
   ID_PARTICIPANT ASC
);


/*==============================================================*/
/* Index : IDX_WFDELEGATE_DATES                                 */
/*==============================================================*/

create index IDX_WFDELEGATE_DATES on WFDELEGATE (
   ID_USER ASC,
   DATE_BEGIN ASC,
   DATE_END ASC
);



/*==============================================================*/
/* Table : WFPROCESS_RELDATA                                    */
/*==============================================================*/


create table WFPROCESS_RELDATA  (
   ID_PROCESS           INTEGER                          not null,
   ID_RELDATA           INTEGER                          not null,
   ID_DATASET_DEFAULT   INTEGER,
   DIRECTION            NVARCHAR2(64),
   RESTRICT_ALL         NVARCHAR2(1),
   DISP_ORDER            INTEGER,
   DISP_HOME            NVARCHAR2(1),
   DISP_LIST            NVARCHAR2(1),
   DISP_SEARCH          NVARCHAR2(1),
   DISP_SIZE            INTEGER,
   READ_ONLY            NVARCHAR2(1),
   VISIBLE              NVARCHAR2(1),
   constraint PK_WFPROCESS_RELDATA primary key (ID_PROCESS, ID_RELDATA),
   constraint FK_WFPROCES_REFEREN_WFPROCES6 foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_WFRELDAT foreign key (ID_RELDATA)
         references WFRELDATA (ID_RELDATA)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_WFDATASE foreign key (ID_DATASET_DEFAULT)
         references WFDATASET (ID_DATASET)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROC_RLDA_ID_DATASET_DEF                       */
/*==============================================================*/


create index IDX_WFPROC_RLDA_ID_DATASET_DEF on WFPROCESS_RELDATA (
   ID_DATASET_DEFAULT ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_RELDATA_ID_PROCESS                        */
/*==============================================================*/


create index IDX_WFPROC_RELDATA_ID_PROCESS on WFPROCESS_RELDATA (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_RELDATA_ID_RELDATA                        */
/*==============================================================*/


create index IDX_WFPROC_RELDATA_ID_RELDATA on WFPROCESS_RELDATA (
   ID_RELDATA ASC
);


/*==============================================================*/
/* Table : WFPROCESS_RELDATA_RESTRICT                           */
/*==============================================================*/


create table WFPROCESS_RELDATA_RESTRICT  (
   ID_PROCESS           INTEGER                          not null,
   ID_RELDATA           INTEGER                          not null,
   ID_PARTICIPANT       INTEGER                          not null,
   constraint PK_WFPROCESS_RELDATA_RESTRICT primary key (ID_PROCESS, ID_RELDATA, ID_PARTICIPANT),
   constraint FK_WFPROCES_REFEREN_WFPROCES7 foreign key (ID_PROCESS, ID_RELDATA)
         references WFPROCESS_RELDATA (ID_PROCESS, ID_RELDATA)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_WFPARTIC foreign key (ID_PARTICIPANT)
         references WFPARTICIPANT (ID_PARTICIPANT)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROC_RLDA_RESTRT_ID_PART                       */
/*==============================================================*/


create index IDX_WFPROC_RLDA_RESTRT_ID_PART on WFPROCESS_RELDATA_RESTRICT (
   ID_PARTICIPANT ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCRLDA_RT_ID_PROC_RLDA                       */
/*==============================================================*/


create index IDX_WFPROCRLDA_RT_ID_PROC_RLDA on WFPROCESS_RELDATA_RESTRICT (
   ID_PROCESS ASC,
   ID_RELDATA ASC
);


/*==============================================================*/
/* Table : WFACTIVITY                                           */
/*==============================================================*/


create table WFACTIVITY  (
   ID_PROCESS            INTEGER                         not null,
   ID_ACTIVITY           INTEGER                         not null,
   NAME                  NVARCHAR2(64)                   not null,
   DESCRIPTION           NVARCHAR2(255),
   ID_PARTICIPANT        INTEGER,
   ID_APPLICATION        INTEGER,
   ID_ACTIVITY_TYPE      NVARCHAR2(64),
   HELP                  CLOB,
   HELP_LINK             NVARCHAR2(255),
   HELP_MAIL             NVARCHAR2(255),
   LIMIT                 FLOAT,
   ID_DURATION_UNIT      NVARCHAR2(10),
   ID_ASSIGN_TYPE        NVARCHAR2(64),
   ID_PROCESS_ASSIGN     INTEGER,
   ID_RELDATA_ASSIGN     INTEGER,
   DISP_ORDER            INTEGER,
   VISIBLE               NVARCHAR2(1),
   ID_RELDATA_LIMIT      INTEGER,
   OVERDUE_DURATION      FLOAT,
   OVERDUE_DURATION_UNIT NVARCHAR2(10),
   NOTIFY_ASSIGN_TODO    NVARCHAR2(1),
   NOTIFY_CANCEL_ASSIGN  NVARCHAR2(1),
   NOTIFY_DELAY          NVARCHAR2(1),
   NOTIFY_TODO           NVARCHAR2(1),
   NOTIFY_ERROR_ASSIGN   NVARCHAR2(1),
   DURATION_WORKHOUR     NVARCHAR2(1),
   ID_PROCESS_ASSIGN_AS  INTEGER,
   ID_ACTIVITY_ASSIGN_AS INTEGER,
   ID_EXEC_TYPE          NVARCHAR2(64),
   SUBPROCESS            NVARCHAR2(64),
   SUBPROCESS_VERSION    INTEGER,
   COMPLETE_ASYNC        NVARCHAR2(1),
   constraint PK_WFACTIVITY primary key (ID_PROCESS, ID_ACTIVITY),
   constraint FK_WFACTIVI_REFEREN_WFPROCES3 foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFPARTIC foreign key (ID_PARTICIPANT)
         references WFPARTICIPANT (ID_PARTICIPANT)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFAPPLIC foreign key (ID_APPLICATION)
         references WFAPPLICATION (ID_APPLICATION)
         on delete cascade,
   constraint FK_WFACTIVI_REFEREN_WFPROCES4 foreign key (ID_ACTIVITY_TYPE)
         references WFACTIVITY_TYPE (ID_ACTIVITY_TYPE)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFACTIVI foreign key (ID_ASSIGN_TYPE)
         references WFACTIVITY_ASSIGN_TYPE (ID_ASSIGN_TYPE)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFDURATI foreign key (ID_DURATION_UNIT)
         references WFDURATION_UNIT (ID_DURATION_UNIT)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFDURAT1 foreign key (OVERDUE_DURATION_UNIT)
         references WFDURATION_UNIT (ID_DURATION_UNIT)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFPROCES foreign key (ID_PROCESS_ASSIGN, ID_RELDATA_ASSIGN)
         references WFPROCESS_RELDATA (ID_PROCESS, ID_RELDATA)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFRELADA foreign key (ID_RELDATA_LIMIT)
         references WFRELDATA (ID_RELDATA)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_ID_APPLICATION                        */
/*==============================================================*/


create index IDX_WFACTIVITY_ID_APPLICATION on WFACTIVITY (
   ID_APPLICATION ASC
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_ID_DURATION_UNI                       */
/*==============================================================*/


create index IDX_WFACTIVITY_ID_DURATION_UNI on WFACTIVITY (
   ID_DURATION_UNIT ASC
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_ID_ASSIGN_TYPE                        */
/*==============================================================*/


create index IDX_WFACTIVITY_ID_ASSIGN_TYPE on WFACTIVITY (
   ID_ASSIGN_TYPE ASC
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_ID_ACT_TYPE                           */
/*==============================================================*/


create index IDX_WFACTIVITY_ID_ACT_TYPE on WFACTIVITY (
   ID_ACTIVITY_TYPE ASC
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_ID_PROCESS                            */
/*==============================================================*/


create index IDX_WFACTIVITY_ID_PROCESS on WFACTIVITY (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_ID_PARTICIPANT                        */
/*==============================================================*/


create index IDX_WFACTIVITY_ID_PARTICIPANT on WFACTIVITY (
  ID_PARTICIPANT ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_ID_PROC_RD_ASSIGN                          */
/*==============================================================*/


create index IDX_WFACT_ID_PROC_RD_ASSIGN on WFACTIVITY (
  ID_PROCESS_ASSIGN ASC,
  ID_RELDATA_ASSIGN ASC
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_ID_RELDATA_LIMI                       */
/*==============================================================*/


create index IDX_WFACTIVITY_ID_RELDATA_LIMI on WFACTIVITY (
   ID_RELDATA_LIMIT ASC
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_NAME                                  */
/*==============================================================*/


create index IDX_WFACTIVITY_NAME on WFACTIVITY (
   NAME ASC
);

/*==============================================================*/
/* Table : WFPROCESS_TRANSITION                                 */
/*==============================================================*/


create table WFPROCESS_TRANSITION  (
   ID_PROCESS           INTEGER                          not null,
   ID_TRANSITION        INTEGER                          not null,
   ID_PROCESS_FROM      INTEGER,
   ID_ACTIVITY_FROM     INTEGER,
   ID_PROCESS_TO        INTEGER,
   ID_ACTIVITY_TO       INTEGER,
   CONDITION            CLOB,
   ID_CONDITION_TYPE    NVARCHAR2(64),
   ID_EXCEPTION_TYPE    NVARCHAR2(64),
   CONDITION_LANG       NVARCHAR2(64),
   constraint PK_WFPROCESS_TRANSITION primary key (ID_PROCESS, ID_TRANSITION),
   constraint FK_WFPROCES_REFERENCE_WFPROCES foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFACTIVI3 foreign key (ID_PROCESS_FROM, ID_ACTIVITY_FROM)
         references WFACTIVITY (ID_PROCESS, ID_ACTIVITY)
         on delete cascade,
   constraint FK_WFPROCES_REFERENCE_WFACTIVI foreign key (ID_PROCESS_TO, ID_ACTIVITY_TO)
         references WFACTIVITY (ID_PROCESS, ID_ACTIVITY)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPROC_TRANSITION_ID_TRANS                       */
/*==============================================================*/


create index IDX_WFPROC_TRANSITION_ID_TRANS on WFPROCESS_TRANSITION (
   ID_TRANSITION ASC
);


/*==============================================================*/
/* Index : IDX_WFPROCTRANS_IDPRO_IDACTFRO */
/*==============================================================*/


create index IDX_WFPROCTRANS_IDPRO_IDACTFRO on WFPROCESS_TRANSITION (
   ID_PROCESS ASC,
   ID_ACTIVITY_FROM ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_TRANS_ID_PROCESS                          */
/*==============================================================*/


create index IDX_WFPROC_TRANS_ID_PROCESS on WFPROCESS_TRANSITION (
   ID_PROCESS ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_TRANS_IDPF_IDAF                          */
/*==============================================================*/
create index IDX_WFPROC_TRANS_IDPF_IDAF on WFPROCESS_TRANSITION (
   ID_PROCESS_FROM ASC,
   ID_ACTIVITY_FROM ASC
);


/*==============================================================*/
/* Index : IDX_WFPROC_TRANS_IDPT_IDAT                          */
/*==============================================================*/
create index IDX_WFPROC_TRANS_IDPT_IDAT on WFPROCESS_TRANSITION (
   ID_PROCESS_TO ASC,
   ID_ACTIVITY_TO ASC
);


/*==============================================================*/
/* Table : WFPARTICIPANT_MAPTO                                  */
/*==============================================================*/


create table WFPARTICIPANT_MAPTO  (
   ID_PARTICIPANT       INTEGER                          not null,
   NUM_MAPTO            INTEGER                          not null,
   MAPTO                NVARCHAR2(64),
   ID_DIRECTORY         INTEGER,
   ID_GROUP             INTEGER,
   ID_USER              INTEGER,
   COORDINATOR          NVARCHAR2(1),
   constraint PK_WFPARTICIPANT_MAPTO primary key (ID_PARTICIPANT, NUM_MAPTO),
   constraint FK_WFPARTIC_REFERENCE_WFPARTIC foreign key (ID_PARTICIPANT)
         references WFPARTICIPANT (ID_PARTICIPANT)
         on delete cascade,
   constraint FK_WFPAR_MAPTO_REF_USERS foreign key (ID_USER)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_WFPAR_MAPTO_REF_GROUPS foreign key (ID_GROUP)
         references GROUPS (ID_GROUP)
         on delete cascade,
   constraint FK_WFPAR_MAPTO_REF_DIR foreign key (ID_DIRECTORY)
         references DIRECTORY (ID_DIRECTORY)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFPARTICIPANT_MAPTO_ID_DIR                       */
/*==============================================================*/


create index IDX_WFPARTICIPANT_MAPTO_ID_DIR on WFPARTICIPANT_MAPTO (
   ID_DIRECTORY ASC
);


/*==============================================================*/
/* Index : IDX_WFPART_MAPTO_ID_GROUP                            */
/*==============================================================*/


create index IDX_WFPART_MAPTO_ID_GROUP on WFPARTICIPANT_MAPTO (
   ID_GROUP ASC
);


/*==============================================================*/
/* Index : IDX_WFPART_MAPTO_NUM_MAPTO                           */
/*==============================================================*/


create index IDX_WFPART_MAPTO_NUM_MAPTO on WFPARTICIPANT_MAPTO (
   NUM_MAPTO ASC
);


/*==============================================================*/
/* Index : IDX_WFPARTICIPANT_MAPTO_ID_USR                       */
/*==============================================================*/


create index IDX_WFPARTICIPANT_MAPTO_ID_USR on WFPARTICIPANT_MAPTO (
   ID_USER ASC
);


/*==============================================================*/
/* Index : IDX_WFPART_MAPTO_ID_PARTICIPAN                       */
/*==============================================================*/


create index IDX_WFPART_MAPTO_ID_PARTICIPAN on WFPARTICIPANT_MAPTO (
   ID_PARTICIPANT ASC
);


/*==============================================================*/
/* Table : WFDATATYPE                                           */
/*==============================================================*/


create table WFNOTIFY_TYPE  (
   ID_NOTIFY_TYPE       NVARCHAR2(64)                    not null,
   DESCRIPTION_FR       NVARCHAR2(255),
   DESCRIPTION_EN       NVARCHAR2(255),
   DISP_ORDER           INTEGER,
   constraint PK_WFNOTIFY_TYPE primary key (ID_NOTIFY_TYPE)
);


/*==============================================================*/
/* Table : WFACTIVITY_NOTIFY                                    */
/*==============================================================*/


create table WFACTIVITY_NOTIFY  (
   ID_PROCESS           INTEGER                          not null,
   ID_ACTIVITY          INTEGER                          not null,
   NUM_NOTIFY           INTEGER                          not null,
   MAPTO                NVARCHAR2(64),
   ID_PARTICIPANT       INTEGER,
   ID_PROCESS_NOTIFY    INTEGER,
   ID_ACTIVITY_NOTIFY   INTEGER,
   EMAILS_ADDR          NVARCHAR2(255),
   ID_NOTIFY_TYPE       NVARCHAR2(64),
   CONDITION            CLOB,
   ID_RELDATA           INTEGER,
   ID_RELDATA_TEMPLATE  INTEGER,
   CONDITION_LANG       NVARCHAR2(64),
   constraint PK_WFACTIVITY_NOTIFY primary key (ID_PROCESS, ID_ACTIVITY, NUM_NOTIFY),
   constraint FK_WFACTIVI_REFEREN_WFRELDAT1 foreign key (ID_RELDATA)
         references WFRELDATA (ID_RELDATA)
         on delete cascade,
   constraint FK_WFACTIVI_REFEREN_WFRELDAT2 foreign key (ID_RELDATA_TEMPLATE)
         references WFRELDATA (ID_RELDATA)
         on delete cascade,
   constraint FK_WFACTIVI_REFEREN_WFACTIVI3 foreign key (ID_PROCESS, ID_ACTIVITY)
         references WFACTIVITY (ID_PROCESS, ID_ACTIVITY)
         on delete cascade,
   constraint FK_WFACTIVI_REFEREN_WFPARTIC2 foreign key (ID_PARTICIPANT)
         references WFPARTICIPANT (ID_PARTICIPANT)
         on delete cascade,
   constraint FK_WFACTIVI_REFEREN_WFACTIVI4 foreign key (ID_PROCESS_NOTIFY, ID_ACTIVITY_NOTIFY)
         references WFACTIVITY (ID_PROCESS, ID_ACTIVITY)
         on delete cascade,
   constraint FK_WFNOTIFY_REFERENCE_WFNOTIFY foreign key (ID_NOTIFY_TYPE)
         references WFNOTIFY_TYPE (ID_NOTIFY_TYPE)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFACTIVITY_NOTIFY_MAPTO                          */
/*==============================================================*/


create index IDX_WFACTIVITY_NOTIFY_MAPTO on WFACTIVITY_NOTIFY (
   MAPTO ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_NOTIFY_NUM_NOTIFY                          */
/*==============================================================*/


create index IDX_WFACT_NOTIFY_NUM_NOTIFY on WFACTIVITY_NOTIFY (
   NUM_NOTIFY ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_NOTIFY_ID_PARTICIPAN                       */
/*==============================================================*/


create index IDX_WFACT_NOTIFY_ID_PARTICIPAN on WFACTIVITY_NOTIFY (
   ID_PARTICIPANT ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_NOTIFY_IDPROC_IDACT                        */
/*==============================================================*/


create index IDX_WFACT_NOTIFY_IDPROC_IDACT on WFACTIVITY_NOTIFY (
   ID_PROCESS ASC,
   ID_ACTIVITY ASC
);


/*==============================================================*/
/* Index : IDX_WFACTNOT_IDPROCNOTIDACTNOT                       */
/*==============================================================*/


create index IDX_WFACTNOT_IDPROCNOTIDACTNOT on WFACTIVITY_NOTIFY (
   ID_PROCESS_NOTIFY ASC,
   ID_ACTIVITY_NOTIFY ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_NOTIFY_ID_PROC                             */
/*==============================================================*/


create index IDX_WFACT_NOTIFY_ID_PROC on WFACTIVITY_NOTIFY (
   ID_PROCESS ASC
);

/*==============================================================*/
/* Table : WFACTIVITY_PARAM                                     */
/*==============================================================*/


create table WFACTIVITY_PARAM  (
   ID_PROCESS           INTEGER                          not null,
   ID_ACTIVITY          INTEGER                          not null,
   PARAM                NVARCHAR2(440)                   not null,
   DIRECTION            NVARCHAR2(64),
   MAPTO                NVARCHAR2(64),
   ID_RELDATA           INTEGER,
   VALUE_TEXT           NVARCHAR2(4000),
   ID_RELDATA_DEFAULT   INTEGER,
   PARAM_LANG           NVARCHAR2(64),
   constraint PK_WFACTIVITY_PARAM primary key (ID_PROCESS, ID_ACTIVITY, PARAM),
   constraint FK_WFPROCES_REFEREN_WFRELDAT2 foreign key (ID_RELDATA)
         references WFRELDATA (ID_RELDATA)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFRELDAT4 foreign key (ID_RELDATA_DEFAULT)
         references WFRELDATA (ID_RELDATA)
         on delete cascade,
   constraint FK_WFPROCES_REFEREN_WFACTIVI2 foreign key (ID_PROCESS, ID_ACTIVITY)
         references WFACTIVITY (ID_PROCESS, ID_ACTIVITY)
         on delete cascade
);


/*==============================================================*/
/* Index : WFACT_PARAM_ID_PROC_ID_ACT                           */
/*==============================================================*/


create index WFACT_PARAM_ID_PROC_ID_ACT on WFACTIVITY_PARAM (
   ID_PROCESS ASC,
   ID_ACTIVITY ASC
);


/*==============================================================*/
/* Index : WFACTIVITY_PARAM_ID_RELDATA                          */
/*==============================================================*/


create index WFACTIVITY_PARAM_ID_RELDATA on WFACTIVITY_PARAM (
   ID_RELDATA ASC
);


/*==============================================================*/
/* Table : WFACTIVITY_INST                                      */
/*==============================================================*/


create table WFACTIVITY_INST  (
   ID_PROCESS_INST      INTEGER                          not null,
   ID_ACTIVITY_INST     INTEGER                          not null,
   ID_PROCESS           INTEGER,
   ID_ACTIVITY          INTEGER,
   DESCRIPTION          NVARCHAR2(255),
   NAME                 NVARCHAR2(64),
   ID_STATE             NVARCHAR2(20),
   ID_SUBSTATE          NVARCHAR2(30),
   DATE_OPEN            DATE,
   DATE_START           DATE,
   DATE_ASSIGN          DATE,
   DATE_CLOSE           DATE,
   DATE_UPDATE          DATE,
   DATE_STATE_UPDATE    DATE,
   DATE_NOTIFY_DELAY    DATE,
   PRIORITY             NVARCHAR2(255),
   DATE_LIMIT           DATE,
   ID_USER_REQUESTER    INTEGER,
   ID_USER_ASSIGNEE     INTEGER,
   ID_USER_ASSIGNEE_REAL INTEGER,
   ID_USER_ASSIGNED_BY  INTEGER,
   ID_USER_ABORTED      INTEGER,
   ID_DURATION_UNIT     NVARCHAR2(50),
   DATE_REASSIGN_DELAY  DATE,
   ID_SUBPROCESS_INST   INTEGER,
   ID_EXCEPTION_TYPE    NVARCHAR2(64),
   MSG_THREAD_INDEX	NVARCHAR2(32),
   APP_ERROR_CODE       NVARCHAR2(20),
   APP_ERROR_MSG        NVARCHAR2(4000),
   APP_ERROR_NUMBER            INTEGER,
   APP_ERROR_SOURCE            NVARCHAR2(70),
   constraint PK_WFACTIVITY_INST primary key (ID_PROCESS_INST, ID_ACTIVITY_INST),
   constraint FK_WFACTIVI_REFEREN_WFPROCES2 foreign key (ID_PROCESS_INST)
         references WFPROCESS_INST (ID_PROCESS_INST)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFSUBSTA foreign key (ID_STATE, ID_SUBSTATE)
         references WFSUBSTATE (ID_STATE, ID_SUBSTATE)
         on delete cascade,
   constraint FK_WFACTIVI_REFEREN_WFACTIVI5 foreign key (ID_PROCESS, ID_ACTIVITY)
         references WFACTIVITY (ID_PROCESS, ID_ACTIVITY)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_USERS2 foreign key (ID_USER_REQUESTER)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_USERS3 foreign key (ID_USER_ASSIGNEE)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_USERS4 foreign key (ID_USER_ABORTED)
         references USERS (ID_USER)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_USERS foreign key (ID_USER_ASSIGNED_BY)
         references USERS (ID_USER)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_ACT_INST                           */
/*==============================================================*/


create index IDX_WFACT_INST_ID_ACT_INST on WFACTIVITY_INST (
   ID_ACTIVITY_INST ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_USR_REQ                            */
/*==============================================================*/


create index IDX_WFACT_INST_ID_USR_REQ on WFACTIVITY_INST (
   ID_USER_REQUESTER ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_USR_ASSIGNEE                       */
/*==============================================================*/


create index IDX_WFACT_INST_ID_USR_ASSIGNEE on WFACTIVITY_INST (
   ID_USER_ASSIGNEE ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_USR_ASSIGNBY                       */
/*==============================================================*/


create index IDX_WFACT_INST_ID_USR_ASSIGNBY on WFACTIVITY_INST (
   ID_USER_ASSIGNED_BY ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_USR_ABOR                           */
/*==============================================================*/


create index IDX_WFACT_INST_ID_USR_ABOR on WFACTIVITY_INST (
   ID_USER_ABORTED ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_PROC_ID_ACT                        */
/*==============================================================*/


create index IDX_WFACT_INST_ID_PROC_ID_ACT on WFACTIVITY_INST (
   ID_PROCESS ASC,
   ID_ACTIVITY ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_PROC_INST                          */
/*==============================================================*/


create index IDX_WFACT_INST_ID_PROC_INST on WFACTIVITY_INST (
   ID_PROCESS_INST ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_ID_STATE_IDSUB                        */
/*==============================================================*/


create index IDX_WFACT_INST_ID_STATE_IDSUB on WFACTIVITY_INST (
   ID_STATE ASC,
   ID_SUBSTATE ASC
);

/*==============================================================*/
/* Index : IDX_WFACT_INST_DATELIMIT                             */
/*==============================================================*/


create index IDX_WFACT_INST_DATELIMIT on WFACTIVITY_INST (
   ID_STATE ASC,
   DATE_LIMIT ASC
);


/*==============================================================*/
/* Table : WFACTIVITY_INST_RELDATA                              */
/*==============================================================*/


create table WFACTIVITY_INST_RELDATA  (
   ID_PROCESS_INST      INTEGER                          not null,
   ID_ACTIVITY_INST     INTEGER                          not null,
   ID_RELDATA           INTEGER                          not null,
   DIRECTION            NVARCHAR2(64),
   ID_DATASET           INTEGER,
   constraint PK_WFACTIVITY_INST_RELDATA primary key (ID_PROCESS_INST, ID_ACTIVITY_INST, ID_RELDATA),
   constraint FK_WFACTIVI_REFEREN_WFACTIVI2 foreign key (ID_PROCESS_INST, ID_ACTIVITY_INST)
         references WFACTIVITY_INST (ID_PROCESS_INST, ID_ACTIVITY_INST)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFDATASE foreign key (ID_DATASET)
         references WFDATASET (ID_DATASET)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFACTINSTRLDA_IDPROCINSTAC                       */
/*==============================================================*/


create index IDX_WFACTINSTRLDA_IDPROCINSTAC on WFACTIVITY_INST_RELDATA (
   ID_PROCESS_INST ASC,
   ID_ACTIVITY_INST ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_RLDA_ID_DATASET                       */
/*==============================================================*/


create index IDX_WFACT_INST_RLDA_ID_DATASET on WFACTIVITY_INST_RELDATA (
   ID_DATASET ASC
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_RLDA_ID_RLDA                          */
/*==============================================================*/


create index IDX_WFACT_INST_RLDA_ID_RLDA on WFACTIVITY_INST_RELDATA (
   ID_RELDATA ASC
);


/*==============================================================*/
/* Table : WFACTIVITY_INST_NOTIFY_OVERDUE                       */
/*==============================================================*/

create table WFACTIVITY_INST_NOTIFY_OVERDUE  (
   ID_PROCESS_INST      INTEGER                          not null,
   ID_ACTIVITY_INST     INTEGER                          not null,
   ID_PROCESS           INTEGER                          not null,
   ID_ACTIVITY          INTEGER                          not null,
   NUM_NOTIFY           INTEGER                          not null,
   DATE_NOTIFY          DATE,
   constraint PK_WFACTIVITY_INST_NOTIFY_OVER primary key (ID_PROCESS_INST, ID_ACTIVITY_INST, ID_PROCESS, ID_ACTIVITY, NUM_NOTIFY),
   constraint FK_WFACTIVI_REFERENCE_WFACTIV2 foreign key (ID_PROCESS_INST, ID_ACTIVITY_INST)
         references WFACTIVITY_INST (ID_PROCESS_INST, ID_ACTIVITY_INST)
         on delete cascade,
   constraint FK_WFACTIVI_REFERENCE_WFACTIV1 foreign key (ID_PROCESS, ID_ACTIVITY, NUM_NOTIFY)
         references WFACTIVITY_NOTIFY (ID_PROCESS, ID_ACTIVITY, NUM_NOTIFY)
         on delete cascade
);


/*==============================================================*/
/* Table : WFFOLDER_PERM                                        */
/*==============================================================*/


create table WFFOLDER_PERM  (
   ID_FOLDER            INTEGER                          not null,
   ID_PARTICIPANT       INTEGER                          not null,
   ID_PERM_TYPE         NVARCHAR2(64)                     not null,
   constraint PK_WFFOLDER_PERM primary key (ID_FOLDER, ID_PARTICIPANT, ID_PERM_TYPE),
   constraint FK_WFFOLDER_REFERENCE_WFFOLDER foreign key (ID_FOLDER)
         references WFFOLDER (ID_FOLDER)
         on delete cascade,
   constraint FK_WFFOLDER_REFERENCE_WFPERM_T foreign key (ID_PERM_TYPE)
         references WFPERM_TYPE (ID_PERM_TYPE)
         on delete cascade,
   constraint FK_WFFOLDER_REFERENCE_WFPARTIC foreign key (ID_PARTICIPANT)
         references WFPARTICIPANT (ID_PARTICIPANT)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFFOLDER_PERM_ID_FOLDER                          */
/*==============================================================*/


create index IDX_WFFOLDER_PERM_ID_FOLDER on WFFOLDER_PERM (
   ID_FOLDER ASC
);


/*==============================================================*/
/* Index : IDX_WFFOLDER_PERM_ID_PARTICIPA                       */
/*==============================================================*/


create index IDX_WFFOLDER_PERM_ID_PARTICIPA on WFFOLDER_PERM (
   ID_PARTICIPANT ASC
);


/*==============================================================*/
/* Index : IDX_WFFOLDER_PERM_ID_PERM_TYPE                       */
/*==============================================================*/


create index IDX_WFFOLDER_PERM_ID_PERM_TYPE on WFFOLDER_PERM (
   ID_PERM_TYPE ASC
);


/*==============================================================*/
/* Table : WFACTIVITY_INST_MAPTO                                */
/*==============================================================*/


create table WFACTIVITY_INST_MAPTO  (
   ID_PROCESS_INST      INTEGER                          not null,
   ID_ACTIVITY_INST     INTEGER                          not null,
   ID_USER              INTEGER                          not null,
   constraint PK_WFACTIVITY_INST_MAPTO primary key (ID_PROCESS_INST, ID_ACTIVITY_INST, ID_USER),
   constraint FK_WFACTINSTMAPTO_WFACTINST foreign key (ID_PROCESS_INST, ID_ACTIVITY_INST)
         references WFACTIVITY_INST (ID_PROCESS_INST, ID_ACTIVITY_INST)
         on delete cascade,
   constraint FK_WFACTINSTMAPTO_REF_USERS foreign key (ID_USER)
         references USERS (ID_USER)
         on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFACT_INST_MAPTO_ID_USR                          */
/*==============================================================*/


create index IDX_WFACT_INST_MAPTO_ID_USR on WFACTIVITY_INST_MAPTO (
   ID_USER ASC
);


/*==============================================================*/
/* Index : IDX_WFACTINSTMAPTO_IDPROCINSTA                       */
/*==============================================================*/


create index IDX_WFACTINSTMAPTO_IDPROCINSTA on WFACTIVITY_INST_MAPTO (
   ID_PROCESS_INST ASC,
   ID_ACTIVITY_INST ASC
);


/*==============================================================*/
/* Table : USERS_VIEWS_MAPTO                                    */
/*==============================================================*/


create table USERS_VIEWS_MAPTO (
   ID_USER              INTEGER                          not null,
   NUM_VIEW             INTEGER                          not null,
   ID_PARTICIPANT       INTEGER                          not null,
   constraint PK_USERS_VIEWS_MAPTO primary key (ID_USER, NUM_VIEW, ID_PARTICIPANT),
   constraint FK_USERS_VIEWS_MAPTO_REF_UV foreign key (ID_USER, NUM_VIEW)
         references USERS_VIEWS (ID_USER, NUM_VIEW)
         on delete cascade,
   constraint FK_USERS_VIEWS_MAPTO_REF_PAR foreign key (ID_PARTICIPANT)
         references WFPARTICIPANT (ID_PARTICIPANT)
         on delete cascade
);


/*==============================================================*/
/* Table : WFLIST                                               */
/*==============================================================*/


create table WFLIST  (
    ID_LIST             INTEGER                         not null,
    NAME                NVARCHAR2(255)                  not null,
    ID_PARTICIPANT      INTEGER,
    DATE_UPDATE         DATE                            not null,
    ID_USER_UPDATE      INTEGER,
    NB_ITEMS            INTEGER                         not null,
    FIELD1_NAME         NVARCHAR2(255),
    FIELD1_TYPE         NVARCHAR2(50),
    FIELD2_NAME         NVARCHAR2(255),
    FIELD2_TYPE         NVARCHAR2(50),
    FIELD3_NAME         NVARCHAR2(255),
    FIELD3_TYPE         NVARCHAR2(50),
    FIELD4_NAME         NVARCHAR2(255),
    FIELD4_TYPE         NVARCHAR2(50),
    FIELD5_NAME         NVARCHAR2(255),
    FIELD5_TYPE         NVARCHAR2(50),
    FIELD6_NAME         NVARCHAR2(255),
    FIELD6_TYPE         NVARCHAR2(50),
    FIELD7_NAME         NVARCHAR2(255),
    FIELD7_TYPE         NVARCHAR2(50),
    FIELD8_NAME         NVARCHAR2(255),
    FIELD8_TYPE         NVARCHAR2(50),
    FIELD9_NAME         NVARCHAR2(255),
    FIELD9_TYPE         NVARCHAR2(50),
    FIELD10_NAME        NVARCHAR2(255),
    FIELD10_TYPE        NVARCHAR2(50),
	FIELD11_NAME        NVARCHAR2(255),
    FIELD11_TYPE        NVARCHAR2(50),
    FIELD12_NAME        NVARCHAR2(255),
    FIELD12_TYPE        NVARCHAR2(50),
    FIELD13_NAME        NVARCHAR2(255),
    FIELD13_TYPE        NVARCHAR2(50),
    FIELD14_NAME        NVARCHAR2(255),
    FIELD14_TYPE        NVARCHAR2(50),
    FIELD15_NAME        NVARCHAR2(255),
    FIELD15_TYPE        NVARCHAR2(50),
    FIELD16_NAME        NVARCHAR2(255),
    FIELD16_TYPE        NVARCHAR2(50),
    FIELD17_NAME        NVARCHAR2(255),
    FIELD17_TYPE        NVARCHAR2(50),
    FIELD18_NAME        NVARCHAR2(255),
    FIELD18_TYPE        NVARCHAR2(50),
    FIELD19_NAME        NVARCHAR2(255),
    FIELD19_TYPE        NVARCHAR2(50),
    FIELD20_NAME        NVARCHAR2(255),
    FIELD20_TYPE        NVARCHAR2(50),
    FIELDS_ALL_NAME     CLOB,
    CONNECTION_MODE     NVARCHAR2(64),
    CONNECTION_NAME     NVARCHAR2(64),
    CONNECTION_STRING   NVARCHAR2(500),
    PROVIDER_NAME       NVARCHAR2(64),
	SELECT_COMMAND      CLOB,
    constraint PK_WFLIST primary key (ID_LIST),   
    constraint FK_WFLIST_USERS foreign key (ID_USER_UPDATE)
        references USERS (ID_USER)
        on delete set null,
    constraint FK_WFLIST_WFPARTICIPANT foreign key (ID_PARTICIPANT)
        references WFPARTICIPANT (ID_PARTICIPANT)
        on delete set null
);

 
/*==============================================================*/
/* Table : WFLIST_ITEMS                                         */
/*==============================================================*/
 
 create table WFLIST_ITEMS  (
    ID_LIST         INTEGER                         not null,
    LANGUAGE        NVARCHAR2(7)                    not null,
    DISP_ORDER      INTEGER                         not null,
    FIELD1_TEXT     NVARCHAR2(255),
    FIELD1_NUMERIC  FLOAT,
    FIELD1_DATE     DATE,
    FIELD2_TEXT     NVARCHAR2(255),
    FIELD2_NUMERIC  FLOAT,
    FIELD2_DATE     DATE,
    FIELD3_TEXT     NVARCHAR2(255),
    FIELD3_NUMERIC  FLOAT,
    FIELD3_DATE     DATE,
    FIELD4_TEXT     NVARCHAR2(255),
    FIELD4_NUMERIC  FLOAT,
    FIELD4_DATE     DATE,
    FIELD5_TEXT     NVARCHAR2(255),
    FIELD5_NUMERIC  FLOAT,
    FIELD5_DATE     DATE,
    FIELD6_TEXT     NVARCHAR2(255),
    FIELD6_NUMERIC  FLOAT,
    FIELD6_DATE     DATE,
    FIELD7_TEXT     NVARCHAR2(255),
    FIELD7_NUMERIC  FLOAT,
    FIELD7_DATE     DATE,
    FIELD8_TEXT     NVARCHAR2(255),
    FIELD8_NUMERIC  FLOAT,
    FIELD8_DATE     DATE,
    FIELD9_TEXT     NVARCHAR2(255),
    FIELD9_NUMERIC  FLOAT,
    FIELD9_DATE     DATE,
    FIELD10_TEXT    NVARCHAR2(255), 
    FIELD10_NUMERIC FLOAT,
    FIELD10_DATE    DATE,
	FIELD11_TEXT    NVARCHAR2(255),
    FIELD11_NUMERIC FLOAT,
    FIELD11_DATE    DATE,
    FIELD12_TEXT    NVARCHAR2(255),
    FIELD12_NUMERIC FLOAT,
    FIELD12_DATE    DATE,
    FIELD13_TEXT    NVARCHAR2(255),
    FIELD13_NUMERIC FLOAT,
    FIELD13_DATE    DATE,
    FIELD14_TEXT    NVARCHAR2(255),
    FIELD14_NUMERIC FLOAT,
    FIELD14_DATE    DATE,
    FIELD15_TEXT    NVARCHAR2(255),
    FIELD15_NUMERIC FLOAT,
    FIELD15_DATE    DATE,
    FIELD16_TEXT    NVARCHAR2(255),
    FIELD16_NUMERIC FLOAT,
    FIELD16_DATE    DATE,
    FIELD17_TEXT    NVARCHAR2(255),
    FIELD17_NUMERIC FLOAT,
    FIELD17_DATE    DATE,
    FIELD18_TEXT    NVARCHAR2(255),
    FIELD18_NUMERIC FLOAT,
    FIELD18_DATE    DATE,
    FIELD19_TEXT    NVARCHAR2(255),
    FIELD19_NUMERIC FLOAT,
    FIELD19_DATE    DATE,
    FIELD20_TEXT    NVARCHAR2(255), 
    FIELD20_NUMERIC FLOAT,
    FIELD20_DATE    DATE,
    constraint PK_WFLIST_ITEMS primary key (ID_LIST, LANGUAGE, DISP_ORDER),   
    constraint FK_WFLIST_ITEMS_WFLIST foreign key (ID_LIST)
        references WFLIST (ID_LIST)
        on delete cascade
);


/*==============================================================*/
/* Index : IDX_WFLIST_UNIQUE_NAME                       */
/*==============================================================*/

create unique index IDX_WFLIST_UNIQUE_NAME on WFLIST (
   NAME ASC
);


/*==============================================================*/
/* Index : IDX_WFLIST_ID_PARTICIPANT                       */
/*==============================================================*/

create index IDX_WFLIST_ID_PARTICIPANT on WFLIST (
   ID_PARTICIPANT ASC
);

/*==============================================================*/
/* Table : FAVORITE_TYPE                                    */
/*==============================================================*/


create table FAVORITE_TYPE (
   ID_FAVORITE_TYPE     NVARCHAR2(64)					not null,
   DESCRIPTION		    NVARCHAR2(255),

   constraint PK_FAVORITE_TYPE primary key (ID_FAVORITE_TYPE)
);


/*==============================================================*/
/* Table : FAVORITE		                                   */
/*==============================================================*/

create table FAVORITE (
   ID_FAVORITE			INTEGER							not null,
   ID_USER_FAVORITE		INTEGER							not null,
   ID_FAVORITE_TYPE     NVARCHAR2(64)					not null,
   DESCRIPTION		    NVARCHAR2(255),
   ID_PROCESS			INTEGER,
   ID_USER				INTEGER,
   NUM_VIEW				INTEGER,


   constraint PK_FAVORITE primary key (ID_FAVORITE),
   constraint FK_FAVORITE_REF_FAVORITE_TYPE foreign key (ID_FAVORITE_TYPE)
         references FAVORITE_TYPE (ID_FAVORITE_TYPE)
         on delete cascade,
   constraint FK_FAVORITE_REF_WFPROCESS foreign key (ID_PROCESS)
         references WFPROCESS (ID_PROCESS)
         on delete cascade,
   constraint FK_FAVORITE_REF_USERS_VIEWS foreign key (ID_USER,NUM_VIEW)
		 references USERS_VIEWS (ID_USER,NUM_VIEW)
		 on delete cascade,
   constraint FK_FAVORITE_REF_USERS foreign key (ID_USER_FAVORITE)
		 references USERS (ID_USER)
		 on delete cascade
);

