/**
 * config.production.js
 * This file contains the initialization of the configuration.
 */
'use strict';

module.exports = {
  app: {
    port: process.env.PORT || 8080
  },
  oAuth: {
    provider: process.env.ApplicationSecurityAuthProvider || 'azure-v1',
    clientId: process.env.ApplicationSecurityAuthClientId,
    clientSecret: process.env.ApplicationSecurityAuthClientSecret,
    callBackUrl: `${process.env.ApplicationUrl}/auth/callback`,
    logoutReturnToUrl: `${process.env.ApplicationUrl}/auth/logout/return`,
    logoutUrl: process.env.ApplicationSecurityAuthLogoutUrl, // Needed for non OIDC session mgt compliant providers
    metadataUrl: process.env.ApplicationSecurityAuthMetadataUrl,
    metadataCacheMaxAge: 3600, // seconds,
    responseMode: 'form_post', // Supported values are 'form_post' or 'query'
    usernameClaim: process.env.ApplicationSecurityAuthUsernameClaim || 'sub',
    audience: process.env.ApplicationSecurityAuthAudience || `${process.env.ApplicationUrl}/graphql`,
    tokenValidation: {
      algorithms: ['RS256'],
      audience: process.env.ApplicationSecurityAuthClientId,
      clockTolerance: process.env.ApplicationSecurityAuthClockTolerance || 60 // seconds
    },
    webviewTokenValidation: {
      algorithms: ['RS256'],
      audience: process.env.ApplicationSecurityAuthAudience || `${process.env.ApplicationUrl}/graphql`,
      clockTolerance: process.env.ApplicationSecurityAuthClockTolerance || 60 // seconds
    },
    jwksClient: {
      rateLimit: true,
      jwksRequestsPerMinute: 120,
      cache: true,
      cacheMaxEntries: 10
    }
  },
  login: {
    parameters: {
      returnTo: 'redirect_uri'
    },
    allowedHttpMethods: ['GET', 'POST'],
    allowedUrlStartsWith: process.env.ApplicationUrl
  },
  logout: {
    parameters: {
      postLogoutReturnTo: 'post_logout_redirect_uri'
    },
    allowedHttpMethods: ['GET', 'POST'],
    allowedUrlStartsWith: process.env.ApplicationUrl
  },
  session: {
    cookies: {
      token: process.env.ApplicationSecurityAuthSessionTokenCookie || 'wfgen_token',
      returnTo: 'wfgen_auth_return_to',
      postLogoutReturnTo: 'wfgen_auth_post_logout_return_to',
      state: 'wfgen_auth_state',
      nonce: 'wfgen_auth_nonce',
      sessionId: 'wfgen_auth_session_id',
      sessionState: 'wfgen_auth_session_state',
      logoutState: 'wfgen_auth_logout_state'
    },
    token: {
      signingSecret: process.env.ApplicationSecurityAuthSessionTokenSigningSecret,
      issuer: process.env.ApplicationSecurityAuthSessionTokenIssuers || `${process.env.ApplicationUrl}/auth`,
      audience: process.env.ApplicationSecurityAuthSessionTokenAudience || process.env.ApplicationUrl,
      maxAge: process.env.ApplicationSecurityAuthSessionTokenMaxAge || 7200
    }
  }
};
