/**
* debugController.js
* Contains the debug endpoints.
*/
'use strict';

/* eslint-disable no-multi-spaces */
const express  = require('express');
const mem      = require('mem');
const got      = require('got');
const urlLib   = require('url');
const router   = express.Router();

const config   = require('../config');
const {logger} = require('../utils/logger.js');
/* eslint-enable */

const getMetadata = mem(
  () => got(config.oAuth.metadataUrl)
    .then(result => Promise.resolve(JSON.parse(result.body))),
  {
    maxAge: config.oAuth.metadataCacheMaxAge * 1000
  }
);
const getUrlOrigin = urlString => {
  const urlObject = urlLib.parse(urlString);

  return `${urlObject.protocol}//${urlObject.host}`;
};
const logDebug = log => logger('DEBUG', log);

const start = (req, res) => {
  logDebug(`${req.path}: Render debug start page`);
  res.render('debug/start', {
    returnTo: config.debug.returnTo,
    returnToParameter: config.login.parameters.returnTo,
    action: '/auth/'
  });
};

const loginResult = (req, res) => {
  logDebug(`${req.path}: Render debug result page`);

  // Retrieves OIDC provider metadata and renders the result
  if (config.oAuth.provider === 'azure-v1') {
    getMetadata()
      .then(metadata => res.render('debug/result', {
        appTokenName: config.session.cookies.token,
        appTokenValue: req.cookies[config.session.cookies.token],
        postLogoutReturnTo: config.debug.postLogoutReturnTo,
        postLogoutReturnToParameter: config.logout.parameters.postLogoutReturnTo,
        action: '/auth/logout',
        checkSessionIFrame: metadata.check_session_iframe,
        sessionState: req.cookies[config.session.cookies.sessionState],
        clientId: config.oAuth.clientId,
        providerOrigin: metadata.check_session_iframe ? getUrlOrigin(metadata.check_session_iframe) : null
      }));
  } else {
    res.render('debug/result', {
      appTokenName: config.session.cookies.token,
      appTokenValue: req.cookies[config.session.cookies.token],
      postLogoutReturnTo: config.debug.postLogoutReturnTo,
      postLogoutReturnToParameter: config.logout.parameters.postLogoutReturnTo,
      action: '/auth/logout'
    });
  }
};

const logoutResult = (req, res) => {
  logDebug(`${req.path}: Render debug logout result page`);
  res.render('debug/logoutResult');
};

router.get('/debug', start);
router.get('/debug/result', loginResult);
router.get('/debug/logout/result', logoutResult);

module.exports = router;
