/**
* server.js
* Contains the initialization code of the application.
*/
'use strict';

/* eslint-disable no-multi-spaces */
const express         = require('express');
const bodyParser      = require('body-parser');
const cookieParser    = require('cookie-parser');
const path            = require('path');
const app             = express();

const config          = require('./config');
const {logger}        = require('./utils/logger.js');
const tokenController = require('./controllers/tokenController');
const oidcController  = require('./controllers/oidcController');
const keysController  = require('./controllers/keysController');
/* eslint-enable */

const ROOT_URL = '(\/\\w+)?\/auth'; // eslint-disable-line
const KEYS_URL = `${ROOT_URL}/keys`;

app.use(bodyParser.urlencoded({extended: true}));
app.use(cookieParser());
app.use(ROOT_URL, tokenController);
app.use(ROOT_URL, oidcController);
app.use(KEYS_URL, keysController);

// Debug endpoints
/* istanbul ignore next */
if (process.env.NODE_ENV === 'development') {
  app.use(ROOT_URL, express.static(path.join(__dirname, 'static')));
  app.set('views', './views');
  app.set('view engine', 'pug');
  app.use(ROOT_URL, require('./controllers/debugController.js'));
}

// Else path is never taken in tests.
/* istanbul ignore else */
if (process.env.NODE_ENV === 'test') {
  module.exports = app;
} else {
  // Start Express Server
  app.listen(config.app.port, function () {
    logger('INFO', 'Authentication Server running on port ' + config.app.port);
  });
}
