/**
 * config.production.js
 * This file contains the initialization of the configuration.
 */
'use strict';
const path = require('path');
const { logger } = require('./utils/logger.js');

module.exports = {
  app: {
    port: process.env.PORT || 8080
  },
  graphql: {
    graphiqlEnabled: process.env.GraphqlGraphiqlEnabled ? (process.env.GraphqlGraphiqlEnabled === 'Y') : true,
    mocksEnabled: false,
    debugEnabled: process.env.GraphqlDebugEnabled ? (process.env.GraphqlDebugEnabled === 'Y') : false,
    queryTimeout: process.env.GraphqlQueryTimeout ? parseInt(process.env.GraphqlQueryTimeout) : 90000,
    maxRequestBodySize: 100
  },
  workflowService: {
    debugEnabled: process.env.GraphqlDebugEnabled ? (process.env.GraphqlDebugEnabled === 'Y') : false,
    configFilePath: path.normalize(path.join(__dirname, '../web.config')),
    serviceAssemblyFilePath: process.env.AdvantysWorkflowDllPath || path.normalize(path.join(__dirname, '../bin/Advantys.workflow.dll')),
    logHandler: (text) => logger('DEBUG', text),
    maxPageSize: process.env.GraphqlMaxPageSize ? parseInt(process.env.GraphqlMaxPageSize) : 100,
    maxBatchSize: process.env.GraphqlMaxBatchSize ? parseInt(process.env.GraphqlMaxBatchSize) : 1000,
    defaultPageSize: process.env.GraphqlDefaultPageSize ? parseInt(process.env.GraphqlDefaultPageSize) : 30,
    defaultPageNumber: process.env.GraphqlDefaultPageNumber ? parseInt(process.env.GraphqlDefaultPageNumber) : 1,
    operationTimeout: process.env.GraphqlOperationTimeout ? parseInt(process.env.GraphqlOperationTimeout) : 30000,
    maxOperationCount: process.env.GraphqlMaxOperationCount ? parseInt(process.env.GraphqlMaxOperationCount) : 10000,
    maxInputFileSize: process.env.GraphqlMaxInputFileSize ? parseInt(process.env.GraphqlMaxInputFileSize) : 10240,
    maxInputFileContentSize: process.env.GraphqlMaxInputFileContentSize ? parseInt(process.env.GraphqlMaxInputFileContentSize) : 0,
    inputFileDownloadTimeout: process.env.GraphqlInputFileDownloadTimeout ? parseInt(process.env.GraphqlInputFileDownloadTimeout) : 100000,
    maxOperationRetries: process.env.GraphqlMaxOperationRetries ? parseInt(process.env.GraphqlMaxOperationRetries) : 20,
    operationRetryDelay: process.env.GraphqlOperationRetryDelay ? parseInt(process.env.GraphqlOperationRetryDelay) : 200,
    inputFileAllowedFolders: process.env.GraphqlInputFileAllowedFolders || ''
  },
  loaders: {
    cacheEnabled: process.env.GraphqlLoadersCacheEnabled ? (process.env.GraphqlLoadersCacheEnabled === 'Y') : true,
    batchEnabled: process.env.GraphqlLoadersBatchEnabled ? (process.env.GraphqlLoadersBatchEnabled === 'Y') : true
  },
  oAuth: {
    metadataUrl: process.env.ApplicationSecurityAuthMetadataUrl,
    metadataCacheMaxAge: 3600, // seconds,
    accessTokenUsernameClaim: process.env.ApplicationSecurityAuthUsernameClaim || 'https://api.workflowgen.com/username',
    accessTokenAppIdClaim: process.env.ApplicationSecurityAuthAppIdClaim || 'sub',
    accessTokenProvider: process.env.ApplicationSecurityAuthProvider,
    tokenValidation: {
      algorithms: ['RS256'],
      audience: process.env.ApplicationSecurityAuthAudience || `${process.env.ApplicationUrl}/graphql`,
      clockTolerance: process.env.ApplicationSecurityAuthClockTolerance ? process.env.ApplicationSecurityAuthClockTolerance : 60 // seconds
    },
    jwksClient: {
      rateLimit: true,
      jwksRequestsPerMinute: 120,
      cache: true,
      cacheMaxEntries: 10
    }
  }
};
