/**
* error.js
* Contains the definition of several error types.
*/
'use strict';

/**
 * Higher order error to rethrow in a Promise chain.
 */
class RethrowError extends Error {
  /**
   * Instanciates a new RethrowError.
   * @param {Object} options The options for the rethrow error.
   * @param {String} options.message A human readable error message.
   * @param {Error} options.originalError The encapsulated error.
   */
  constructor (options) {
    const {
      message,
      originalError
    } = options;

    super(message);
    this.originalError = originalError;
  }
}

class InvalidRequest extends Error {}

module.exports = {
  RethrowError,
  InvalidRequest
};
