/**
 * category.js
 * Category loaders
 */
'use strict';

/**
 * Get category by name.
 * @param {Object} context A context.
 * @param {Array} keys An Array of keys.
 * @return {Promise<Array<value>>} A promise resolved with an Array of values.
 */
function getBatchCategoryByName (context, keys) {
  return new Promise(function (resolve, reject) {
    context.workflow.service.invoke(
      'getCategories',
      context.workflow.context,
      {
        names: keys,
        isBatch: true
      }).then(function (result) {
      const nodes = keys.map(key => {
        const node = result.items.find(item => item.name === key);
        return node || Promise.reject(new Error('The category name does not exist.'));
      });
      resolve(nodes);
    }, function (error) {
      reject(error);
    });
  });
}

module.exports = {getBatchCategoryByName};
