/**
 * user.js
 * User loaders
 */
'use strict';

/**
 * Get users by username.
 * @param {Object} context A context.
 * @param {Array} keys An Array of keys.
 * @return {Promise<Array<value>>} A promise resolved with an Array of values.
 */
function getBatchUsersByUserName (context, keys) {
  return new Promise(function (resolve, reject) {
    context.workflow.service.invoke(
      'getUsers',
      context.workflow.context,
      {
        userNames: keys,
        isBatch: true
      }).then(function (result) {
      const users = keys.map(key => {
        const user = result.items.find(item => item.userName.toLowerCase() === key);
        return user || Promise.reject(new Error('The username does not exist.'));
      });
      resolve(users);
    }, function (error) {
      reject(error);
    });
  });
}

module.exports = {getBatchUsersByUserName};
