/**
 * action.js
 * GraphQL resolvers
 */
'use strict';

const actionResolveFunctions = {
  Action: {
    request (action, args, context) {
      context.incrementResolverCount();
      var requestArgs = {};
      requestArgs.id = action.requestId;
      if (action.userId) {
        requestArgs.userId = action.userId;
      }
      if (action.onBehalfOf) {
        requestArgs.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getRequest', args: requestArgs});
    },
    activity (action, args, context) {
      context.incrementResolverCount();
      args.id = action.activityId;
      if (action.userId) {
        args.userId = action.userId;
      }
      return context.loaders.operations.load({operation: 'getActivity', args: args});
    },
    childRequest (action, args, context) {
      if (action.childRequestId != null) {
        context.incrementResolverCount();
        var requestArgs = {};
        requestArgs.id = action.childRequestId;
        if (action.userId) {
          requestArgs.userId = action.userId;
        }
        if (action.onBehalfOf) {
          requestArgs.onBehalfOf = action.onBehalfOf;
        }
        return context.loaders.operations.load({operation: 'getRequest', args: requestArgs});
      } else {
        return null;
      }
    },
    initiator (action, args, context) {
      if (action.initiatorId != null) {
        context.incrementResolverCount();
        return context.loaders.users.load(action.initiatorId);
      } else {
        return null;
      }
    },
    assignee (action, args, context) {
      if (action.assigneeId != null) {
        context.incrementResolverCount();
        return context.loaders.users.load(action.assigneeId);
      } else {
        return null;
      }
    },
    delegatedAssignee (action, args, context) {
      if (action.delegatedAssigneeId != null) {
        context.incrementResolverCount();
        return context.loaders.users.load(action.delegatedAssigneeId);
      } else {
        return null;
      }
    },
    assignor (action, args, context) {
      if (action.assignorId != null) {
        context.incrementResolverCount();
        return context.loaders.users.load(action.assignorId);
      } else {
        return null;
      }
    },
    abortedBy (action, args, context) {
      if (action.abortedById != null) {
        context.incrementResolverCount();
        return context.loaders.users.load(action.abortedById);
      } else {
        return null;
      }
    },
    dataset (action, args, context) {
      context.incrementResolverCount();
      args.actionId = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getActionDataset', args: args});
    },
    canAssign (action, args, context) {
      context.incrementResolverCount();
      args.id = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canAssignAction', args: args});
    },
    canAssignUser (action, args, context) {
      context.incrementResolverCount();
      args.id = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canAssignUserToAction', args: args});
    },
    canCancel (action, args, context) {
      context.incrementResolverCount();
      args.id = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canCancelAction', args: args});
    },
    canCancelAssignment (action, args, context) {
      context.incrementResolverCount();
      args.id = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canCancelActionAssignment', args: args});
    },
    assignableUsers (action, args, context) {
      context.incrementResolverCount();
      args.id = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getActionAssignableUsers', args: args}).then(result => {
        result.items = result.items.map(function (id) {
          context.incrementResolverCount();
          return context.loaders.users.load(id);
        });
        return result;
      });
    },
    canComplete (action, args, context) {
      context.incrementResolverCount();
      args.id = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canCompleteAction', args: args});
    },
    parameters (action, args, context) {
      context.incrementResolverCount();
      args.actionId = action.id;
      if (action.userId) {
        args.userId = action.userId;
      }
      if (action.onBehalfOf) {
        args.onBehalfOf = action.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getActionParameters', args: args});
    }
  }
};

module.exports = actionResolveFunctions;
