/**
 * activity.js
 * GraphQL resolvers
 */
'use strict';

const activityResolveFunctions = {
  Activity: {
    process (activity, args, context) {
      context.incrementResolverCount();
      if (activity.userId) {
        args.userId = activity.userId;
      }
      if (activity.onBehalfOf) {
        args.onBehalfOf = activity.onBehalfOf;
      }
      args.id = activity.processId;
      return context.loaders.operations.load({operation: 'getProcess', args: args});
    },
    participant (activity, args, context) {
      if (activity.participantId != null) {
        context.incrementResolverCount();
        if (activity.userId) {
          args.userId = activity.userId;
        }
        if (activity.onBehalfOf) {
          args.onBehalfOf = activity.onBehalfOf;
        }
        args.id = activity.participantId;
        return context.loaders.operations.load({operation: 'getParticipant', args: args});
      } else {
        return null;
      }
    },
    application (activity, args, context) {
      context.incrementResolverCount();
      if (activity.applicationId != null) {
        args.id = activity.applicationId;
        if (activity.userId) {
          args.userId = activity.userId;
        }
        return context.loaders.operations.load({operation: 'getApplication', args: args});
      } else {
        return null;
      }
    },
    hasQuickApproval (activity, args, context) {
      context.incrementResolverCount();
      args.id = activity.id;
      if (activity.userId) {
        args.userId = activity.userId;
      }
      if (activity.onBehalfOf) {
        args.onBehalfOf = activity.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'hasQuickApprovalActivity', args: args});
    },
    isForm (activity, args, context) {
      context.incrementResolverCount();
      args.id = activity.id;
      if (activity.userId) {
        args.userId = activity.userId;
      }
      if (activity.onBehalfOf) {
        args.onBehalfOf = activity.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'isFormActivity', args: args});
    }
  }
};

module.exports = activityResolveFunctions;
