/**
 * delegation.js
 * GraphQL resolvers
 */
'use strict';

const delegationResolveFunctions = {
  Delegation: {
    delegator (delegation, args, context) {
      context.incrementResolverCount();
      return context.loaders.users.load(delegation.delegatorId);
    },
    delegatee (delegation, args, context) {
      context.incrementResolverCount();
      return context.loaders.users.load(delegation.delegateeId);
    },
    process (delegation, args, context) {
      if (delegation.processId != null) {
        context.incrementResolverCount();
        return context.loaders.processes.load(delegation.processId);
      } else {
        return null;
      }
    },
    participant (delegation, args, context) {
      if (delegation.participantId != null) {
        context.incrementResolverCount();
        return context.loaders.participants.load(delegation.participantId);
      } else {
        return null;
      }
    }
  },
  DelegableProcessParticipant: {
    process (delegableProcessParticipant, args, context) {
      if (delegableProcessParticipant.processId != null) {
        context.incrementResolverCount();
        return context.loaders.processes.load(delegableProcessParticipant.processId);
      } else {
        return null;
      }
    },
    participant (delegableProcessParticipant, args, context) {
      if (delegableProcessParticipant.participantId != null) {
        context.incrementResolverCount();
        return context.loaders.participants.load(delegableProcessParticipant.participantId);
      } else {
        return null;
      }
    }
  }};

module.exports = delegationResolveFunctions;
