/**
 * participant.js
 * GraphQL resolvers
 */
'use strict';
const { fromGlobalId } = require('graphql-relay');

const participantResolveFunctions = {

  Participant: {
    __resolveType (participant, context, info) {
      return info.schema.getType(fromGlobalId(participant.id).type);
    }
  },
  LocalProcessParticipant: {
    process (localProcessParticipant, args, context) {
      context.incrementResolverCount();
      if (localProcessParticipant.userId) {
        args.userId = localProcessParticipant.userId;
      }
      if (localProcessParticipant.onBehalfOf) {
        args.onBehalfOf = localProcessParticipant.onBehalfOf;
      }
      args.id = localProcessParticipant.processId;
      return context.loaders.operations.load({operation: 'getProcess', args: args});
    },
    users (localProcessParticipant, args, context) {
      context.incrementResolverCount();
      if (localProcessParticipant.userId) {
        args.userId = localProcessParticipant.userId;
      }
      args.participantId = localProcessParticipant.id;
      return context.loaders.operations.load({operation: 'getLocalProcessParticipantUserAssociations', args: args});
    },
    coordinators (localProcessParticipant, args, context) {
      context.incrementResolverCount();
      if (localProcessParticipant.userId) {
        args.userId = localProcessParticipant.userId;
      }
      args.participantId = localProcessParticipant.id;
      return context.loaders.operations.load({operation: 'getLocalProcessParticipanCoordinatorAssociations', args: args});
    },
    groups (localProcessParticipant, args, context) {
      context.incrementResolverCount();
      if (localProcessParticipant.userId) {
        args.userId = localProcessParticipant.userId;
      }
      args.participantId = localProcessParticipant.id;
      return context.loaders.operations.load({operation: 'getLocalProcessParticipanGroupAssociations', args: args});
    },
    directories (localProcessParticipant, args, context) {
      context.incrementResolverCount();
      if (localProcessParticipant.userId) {
        args.userId = localProcessParticipant.userId;
      }
      args.participantId = localProcessParticipant.id;
      return context.loaders.operations.load({operation: 'getLocalProcessParticipanDirectoryAssociations', args: args});
    }
  },
  GlobalParticipant: {
    users (globalParticipant, args, context) {
      context.incrementResolverCount();
      if (globalParticipant.userId) {
        args.userId = globalParticipant.userId;
      }
      args.participantId = globalParticipant.id;
      return context.loaders.operations.load({operation: 'getGlobalParticipantUserAssociations', args: args});
    },
    coordinators (globalParticipant, args, context) {
      context.incrementResolverCount();
      if (globalParticipant.userId) {
        args.userId = globalParticipant.userId;
      }
      args.participantId = globalParticipant.id;
      return context.loaders.operations.load({operation: 'getGlobalParticipantCoordinatorAssociations', args: args});
    },
    groups (globalParticipant, args, context) {
      context.incrementResolverCount();
      if (globalParticipant.userId) {
        args.userId = globalParticipant.userId;
      }
      args.participantId = globalParticipant.id;
      return context.loaders.operations.load({operation: 'getGlobalParticipanGroupAssociations', args: args});
    },
    directories (globalParticipant, args, context) {
      context.incrementResolverCount();
      if (globalParticipant.userId) {
        args.userId = globalParticipant.userId;
      }
      args.participantId = globalParticipant.id;
      return context.loaders.operations.load({operation: 'getGlobalParticipanDirectoryAssociations', args: args});
    }
  }
};

module.exports = participantResolveFunctions;
