/**
 * process.js
 * GraphQL resolvers
 */
'use strict';

const processResolveFunctions = {

  Process: {
    dataset (process, args, context) {
      context.incrementResolverCount();
      args.processId = process.id;
      if (process.userId) {
        args.userId = process.userId;
      }
      if (process.onBehalfOf) {
        args.onBehalfOf = process.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getProcessDataset', args: args});
    },
    updatedBy (process, args, context) {
      context.incrementResolverCount();
      return context.loaders.users.load(process.updatedById);
    },
    activities (process, args, context) {
      context.incrementResolverCount();
      args.processId = process.id;
      if (process.userId) {
        args.userId = process.userId;
      }
      if (process.onBehalfOf) {
        args.onBehalfOf = process.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getActivities', args: args});
    },
    categories (process, args, context) {
      context.incrementResolverCount();
      if (!args.filter) {
        args.filter = {};
      }
      args.filter.processId = process.id;
      if (process.userId) {
        args.userId = process.userId;
      }
      if (process.onBehalfOf) {
        args.onBehalfOf = process.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getCategories', args: args});
    },
    participants (process, args, context) {
      context.incrementResolverCount();
      if (process.userId) {
        args.userId = process.userId;
      }
      args.processId = process.id;
      if (process.onBehalfOf) {
        args.onBehalfOf = process.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getProcessParticipants', args: args});
    },
    participantProfiles (process, args, context) {
      context.incrementResolverCount();
      if (process.userId) {
        args.userId = process.userId;
      }
      args.processId = process.id;
      if (process.onBehalfOf) {
        args.onBehalfOf = process.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getProcessParticipantProfiles', args: args});
    },
    canCreateRequest (process, args, context) {
      context.incrementResolverCount();
      args.id = process.id;
      if (process.userId) {
        args.userId = process.userId;
      }
      if (process.onBehalfOf) {
        args.onBehalfOf = process.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canCreateRequest', args: args});
    },
    hasGraphicalViewAccess (process, args, context) {
      context.incrementResolverCount();
      args.id = process.id;
      if (process.userId) {
        args.userId = process.userId;
      }
      if (process.onBehalfOf) {
        args.onBehalfOf = process.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'hasGraphicalViewAccess', args: args});
    }
  }

};

module.exports = processResolveFunctions;
