/**
 * query.js
 * GraphQL resolvers
 */
'use strict';
const { fromGlobalId } = require('graphql-relay');

const queryResolveFunctions = {
  Query: {
    node (root, args, context) {
      context.incrementResolverCount();
      switch (fromGlobalId(args.id).type) {
        case 'Request':
          return context.loaders.operations.load({operation: 'getRequest', args: args});
        case 'Action':
          return context.loaders.operations.load({operation: 'getAction', args: args});
        case 'View':
          return context.loaders.operations.load({operation: 'getView', args: args});
        case 'User':
          return context.loaders.users.load(args.id);
        case 'Process':
          return !args.onBehalfOf
            ? context.loaders.processes.load(args.id)
            : context.loaders.operations.load({operation: 'getProcess', args: args});
        case 'Activity':
          return context.loaders.operations.load({operation: 'getActivity', args: args});
        case 'Category':
          return !args.onBehalfOf
            ? context.loaders.categories.load(args.id)
            : context.loaders.operations.load({operation: 'getCategory', args: args});
        case 'GlobalParticipant':
          return !args.onBehalfOf
            ? context.loaders.participants.load(args.id)
            : context.loaders.operations.load({operation: 'getParticipant', args: args});
        case 'LocalProcessParticipant':
          return !args.onBehalfOf
            ? context.loaders.participants.load(args.id)
            : context.loaders.operations.load({operation: 'getParticipant', args: args});
        case 'ProcessParticipantProfile':
          return context.loaders.operations.load({operation: 'getProcessParticipantProfile', args: args});
        case 'Delegation':
          return context.loaders.operations.load({operation: 'getDelegation', args: args});
        case 'ProcessData':
          return context.loaders.operations.load({operation: 'getProcessData', args: args});
        case 'Comment':
          return context.loaders.operations.load({operation: 'getComment', args: args});
        case 'RequestData':
          return context.loaders.operations.load({operation: 'getRequestData', args: args});
        case 'ActionData':
          return context.loaders.operations.load({operation: 'getActionData', args: args});
        case 'DelegableProcessParticipant':
          return context.loaders.operations.load({operation: 'getDelegableProcessParticipant', args: args});
        case 'Favorite':
          return context.loaders.operations.load({operation: 'getFavorite', args: args});
        case 'Directory':
          return context.loaders.operations.load({operation: 'getDirectory', args: args});
        case 'Group':
          return context.loaders.operations.load({operation: 'getGroup', args: args});
        case 'Application':
          return context.loaders.operations.load({operation: 'getApplication', args: args});
        case 'ApplicationParameter':
          return context.loaders.operations.load({operation: 'getApplicationParameter', args: args});
        case 'ActionParameter':
          return context.loaders.operations.load({operation: 'getActionParameter', args: args});
        default: return Promise.reject(new Error("Could not resolve to a node with the global id of '" + args.id + "'."));
      }
    },
    nodes (root, args, context) {
      return args.ids.map(function (id) {
        context.incrementResolverCount();
        var operationArgs = {};
        operationArgs.id = id;
        if (args.onBehalfOf) {
          operationArgs.onBehalfOf = args.onBehalfOf;
        }
        switch (fromGlobalId(id).type) {
          case 'Request':
            return context.loaders.operations.load({operation: 'getRequest', args: operationArgs});
          case 'Action':
            return context.loaders.operations.load({operation: 'getAction', args: operationArgs});
          case 'View':
            return context.loaders.operations.load({operation: 'getView', args: operationArgs});
          case 'User':
            return context.loaders.users.load(id);
          case 'Process':
            return !args.onBehalfOf
              ? context.loaders.processes.load(id)
              : context.loaders.operations.load({operation: 'getProcess', args: operationArgs});
          case 'Activity':
            return context.loaders.operations.load({operation: 'getActivity', args: operationArgs});
          case 'Category':
            return !args.onBehalfOf
              ? context.loaders.categories.load(id)
              : context.loaders.operations.load({operation: 'getCategory', args: operationArgs});
          case 'GlobalParticipant':
            return !args.onBehalfOf
              ? context.loaders.participants.load(id)
              : context.loaders.operations.load({operation: 'getParticipant', args: operationArgs});
          case 'LocalProcessParticipant':
            return !args.onBehalfOf
              ? context.loaders.participants.load(id)
              : context.loaders.operations.load({operation: 'getParticipant', args: operationArgs});
          case 'ProcessParticipantProfile':
            return context.loaders.operations.load({operation: 'getProcessParticipantProfile', args: operationArgs});
          case 'Delegation':
            return context.loaders.operations.load({operation: 'getDelegation', args: operationArgs});
          case 'ProcessData':
            return context.loaders.operations.load({operation: 'getProcessData', args: operationArgs});
          case 'Comment':
            return context.loaders.operations.load({operation: 'getComment', args: operationArgs});
          case 'RequestData':
            return context.loaders.operations.load({operation: 'getRequestData', args: operationArgs});
          case 'ActionData':
            return context.loaders.operations.load({operation: 'getActionData', args: operationArgs});
          case 'DelegableProcessParticipant':
            return context.loaders.operations.load({operation: 'getDelegableProcessParticipant', args: operationArgs});
          case 'Favorite':
            return context.loaders.operations.load({operation: 'getFavorite', args: operationArgs});
          case 'Directory':
            return context.loaders.operations.load({operation: 'getDirectory', args: operationArgs});
          case 'Group':
            return context.loaders.operations.load({operation: 'getGroup', args: operationArgs});
          case 'Application':
            return context.loaders.operations.load({operation: 'getApplication', args: operationArgs});
          case 'ApplicationParameter':
            return context.loaders.operations.load({operation: 'getApplicationParameter', args: operationArgs});
          case 'ActionParameter':
            return context.loaders.operations.load({operation: 'getActionParameter', args: operationArgs});
          default: return Promise.reject(new Error("Could not resolve to a node with the global id of '" + id + "'."));
        }
      });
    },
    server (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getServer', args: args});
    },
    viewer (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getViewer', args: args}).then(user => {
        context.loaders.users.prime(user.id, user);
        return user;
      });
    },
    user (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.usersByUserName.load(args.userName.toLowerCase());
    },
    users (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getUsers', args: args});
    },
    group (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getGroup', args: args});
    },
    groups (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getGroups', args: args});
    },
    directory (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getDirectory', args: args});
    },
    directories (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getDirectories', args: args});
    },
    process (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getProcess', args: args});
    },
    processes (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getProcesses', args: args});
    },
    request (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getRequest', args: args});
    },
    requests (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getRequests', args: args});
    },
    action (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getAction', args: args});
    },
    actions (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getActions', args: args});
    },
    globalParticipant (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getGlobalParticipant', args: args});
    },
    localProcessParticipant (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getLocalProcessParticipant', args: args});
    },
    participants (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getParticipants', args: args});
    },
    delegations (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getDelegations', args: args});
    },
    application (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getApplication', args: args});
    },
    applications (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getApplications', args: args});
    },
    category (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.categoryByName.load(args.name);
    },
    categories (root, args, context) {
      context.incrementResolverCount();
      return context.loaders.operations.load({operation: 'getCategories', args: args});
    }
  }
};

module.exports = queryResolveFunctions;
