/**
 * request.js
 * GraphQL resolvers
 */
'use strict';

const requestResolveFunctions = {
  Request: {
    requester (request, args, context) {
      context.incrementResolverCount();
      return context.loaders.users.load(request.requesterId);
    },
    delegatedRequester (request, args, context) {
      if (request.delegatedRequesterId) {
        context.incrementResolverCount();
        return context.loaders.users.load(request.delegatedRequesterId);
      } else {
        return null;
      }
    },
    abortedBy (request, args, context) {
      if (request.abortedById) {
        context.incrementResolverCount();
        return context.loaders.users.load(request.abortedById);
      } else {
        return null;
      }
    },
    parentAction (request, args, context) {
      if (request.parentActionId) {
        context.incrementResolverCount();
        var actionArgs = {};
        actionArgs.id = request.parentActionId;
        if (request.userId) {
          actionArgs.userId = request.userId;
        }
        if (request.onBehalfOf) {
          actionArgs.onBehalfOf = request.onBehalfOf;
        }
        return context.loaders.operations.load({operation: 'getAction', args: actionArgs});
      } else {
        return null;
      }
    },
    process (request, args, context) {
      context.incrementResolverCount();
      if (request.userId) {
        args.userId = request.userId;
      }
      if (request.onBehalfOf) {
        args.onBehalfOf = request.onBehalfOf;
      }
      args.id = request.processId;
      return context.loaders.operations.load({operation: 'getProcess', args: args});
    },
    actions (request, args, context) {
      context.incrementResolverCount();
      if (!args.filter) {
        args.filter = {};
      }
      args.filter.requestId = request.id;
      if (request.userId) {
        args.userId = request.userId;
      }
      if (request.onBehalfOf) {
        args.onBehalfOf = request.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getActions', args: args});
    },
    comments (request, args, context) {
      context.incrementResolverCount();
      args.requestId = request.id;
      if (request.userId) {
        args.userId = request.userId;
      }
      if (request.onBehalfOf) {
        args.onBehalfOf = request.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getCommentsByRequest', args: args});
    },
    dataset (request, args, context) {
      context.incrementResolverCount();
      args.requestId = request.id;
      if (request.userId) {
        args.userId = request.userId;
      }
      if (request.onBehalfOf) {
        args.onBehalfOf = request.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'getRequestDataset', args: args});
    },
    canCancel (request, args, context) {
      context.incrementResolverCount();
      args.id = request.id;
      if (request.userId) {
        args.userId = request.userId;
      }
      if (request.onBehalfOf) {
        args.onBehalfOf = request.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canCancelRequest', args: args});
    },
    canDelete (request, args, context) {
      context.incrementResolverCount();
      args.id = request.id;
      if (request.userId) {
        args.userId = request.userId;
      }
      if (request.onBehalfOf) {
        args.onBehalfOf = request.onBehalfOf;
      }
      return context.loaders.operations.load({operation: 'canDeleteRequest', args: args});
    }
  }

};

module.exports = requestResolveFunctions;
