/**
 * user.js
 * GraphQL resolvers
 */
'use strict';

const userResolveFunctions = {

  User: {
    manager (user, args, context) {
      if (user.managerId) {
        context.incrementResolverCount();
        return context.loaders.users.load(user.managerId);
      } else {
        return null;
      }
    },
    directory (user, args, context) {
      if (user.directoryId) {
        context.incrementResolverCount();
        var directoryArgs = {};
        directoryArgs.id = user.directoryId;
        directoryArgs.userAsMember = true;
        return context.loaders.operations.load({operation: 'getDirectory', args: directoryArgs});
      } else {
        return null;
      }
    },
    groups (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      args.userAsMember = true;
      return context.loaders.operations.load({operation: 'getGroups', args: args});
    },
    processes (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      args.userAsMember = true;
      return context.loaders.operations.load({operation: 'getProcesses', args: args});
    },
    launchableProcesses (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      return context.loaders.operations.load({operation: 'getLaunchableProcesses', args: args});
    },
    requests (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      args.userAsMember = true;
      return context.loaders.operations.load({operation: 'getRequests', args: args});
    },
    actions (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      args.userAsMember = true;
      return context.loaders.operations.load({operation: 'getActions', args: args});
    },
    comments (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      return context.loaders.operations.load({operation: 'getComments', args: args});
    },
    participants (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      args.userAsMember = true;
      return context.loaders.operations.load({operation: 'getParticipants', args: args});
    },
    favorites (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      return context.loaders.operations.load({operation: 'getFavorites', args: args});
    },
    views (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      return context.loaders.operations.load({operation: 'getViews', args: args});
    },
    delegations (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      return context.loaders.operations.load({operation: 'getDelegations', args: args});
    },
    delegators (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      return context.loaders.operations.load({operation: 'getDelegators', args: args}).then(result => {
        result.items = result.items.map(function (id) {
          context.incrementResolverCount();
          return context.loaders.users.load(id);
        });
        return result;
      });
    },
    delegableProcessParticipants (user, args, context) {
      context.incrementResolverCount();
      args.userId = user.id;
      return context.loaders.operations.load({operation: 'getDelegableProcessParticipants', args: args});
    }
  }
};

module.exports = userResolveFunctions;
