/**
 * actionparameter.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const actionParameterTypeDefs = `

# An action parameter.
type ActionParameter implements Node {

  # Action parameter identifier.
  id: ID!

  # Action parameter name.
  name: String!

  # Action parameter data type.
  type: WorkflowDataType!

  # Action parameter direction.
  direction: ParameterDirection!

  # Action parameter text value.
  textValue: String

  # Action parameter numeric value.
  numericValue: Float

  # Action parameter date and time value.
  dateTimeValue: DateTime

  # Action parameter file value.
  fileValue: File

  # Indicates if the action parameter has a value.
  hasValue: Boolean!
}

# A paginated list of action parameters.
type ActionParameterListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of action parameters.
  items: [ActionParameter]
}

# A filter on action parameters.
input ActionParameterFilter {

  # Filter action parameters by quick approval parameters.
  isQuickApproval: Boolean
}

`;

module.exports = actionParameterTypeDefs;
