/**
 * activity.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const activityTypeDefs = `

# An activity.
type Activity implements Node {

  # Activity identifier.
  id: ID!

  # Activity name.
  name: String!

  # Activity description.
  description: String!

  # Activity type.
  type: ActivityType!

  # Identifies the process associated to the activity.
  process: Process!

  # Identifies the participant associated to the activity.
  participant: Participant

  # Identifies the application associated to the activity.
  application: Application

  # Activity help information.
  help: Help

  # Indicates if the action is displayed in the request's actions history.
  isVisibleInHistory: Boolean

  # Indicates if the activity is a form based application.
  isForm: Boolean

  # Indicates if the activity has quick approval parameters.
  hasQuickApproval: Boolean
}

# A paginated list of activities.
type ActivityListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of activities.
  items: [Activity]
}

# A filter on activities.
input ActivityFilter {

  # Filter activities by type.
  type: ActivityType
  
  # Filter activities by visibility in history
  isVisibleInHistory: Boolean
}

# An activity list order.
input ActivityListOrder {

  # Field to order activities by.
  field: ActivityListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order an activity list.
enum ActivityListOrderField {

  # Order activities by name.
  NAME

  # Order activities by display order.
  DISP_ORDER
}

# Represent the possible activity types.
enum ActivityType {

  # Application.
  APPLICATION

  # Manual action.
  MANUAL
  
  # Synchronization.
  ROUTE

  # Subprocess.
  SUBFLOW
}
`;

module.exports = activityTypeDefs;
