/**
 * category.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const categoryTypeDefs = `

# A category.
type Category implements Node {

  # Category identifier.
  id: ID!

  # Category name.
  name: String!

  # Category description.
  description: String!

  # List of processes associated to this category.
  processes (page: Page, orderBy: ProcessListOrder, filter: CategoryProcessFilter): ProcessListPage!

  # List of launchable processes associated to this category.
  launchableProcesses (page: Page, orderBy: ProcessListOrder): ProcessListPage!
}

# A paginated list of categories.
type CategoryListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of categories.
  items: [Category]
}

# A filter on categories.
input CategoryFilter {

  # Filter categories by name.
  nameContains: String

  # Filter categories by description.  
  descriptionContains: String

  # Filter categories by process ID.
  processId: ID
}

# A category list order.
input CategoryListOrder {

  # Field to order categories by.
  field: CategoryListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List possible fields to order a category list.
enum CategoryListOrderField {

  # Order categories by name.
  NAME

  # Order categories by description.
  DESCRIPTION
}

# A filter on category processes.
input CategoryProcessFilter {

  # Filter by state.
  state: ProcessState
}
`;

module.exports = categoryTypeDefs;
