/**
 * comment.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const commentTypeDefs = `

# A comment.
type Comment implements Node {

  # Comment identifier.
  id: ID!

  # The user who has posted the comment.
  author: User!

  # The message of the comment.
  message: String!

  # Identifies the date and time when the comment has been posted.
  postedAt: DateTime!

  # The object on which the comment has been added.
  subject: Node!
}

# A paginated list of comments.
type CommentListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of comments.
  items: [Comment]
}

# A comment list order.
input CommentListOrder {

  # Field to order comments by.
  field: CommentListOrderField
  
  # Ordering direction.
  direction: ListOrderDirection
}

# A list of fields to order a list of comments.
enum CommentListOrderField {
  
  # Order comments by when the comments were posted.
  POSTED_AT

  # Order comments by the name of the author.
  AUTHOR_NAME
}

# Add a comment input.
input AddCommentInput {
  
  # Client mutation identifier.
  clientMutationId: String
  
  # Identifier of the object on which the comment will be added.
  subjectId: ID!

  # New comment message.
  message: String!
}

# Add a comment result.
type AddCommentResult {

  # Client mutation identifier.
  clientMutationId: String

  # Comment that has been added.
  comment: Comment!
}

# A remove comment input.
input RemoveCommentInput {
  
  # Client mutation identifier.
  clientMutationId: String
  
  # Comment identifier.
  id: ID!
}

# A remove comment result.
type RemoveCommentResult {

  # Client mutation identifier.
  clientMutationId: String
}

`;

module.exports = commentTypeDefs;
