/**
 * directory.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const directoryTypeDefs = `

# A directory.
type Directory implements Node {

  # Directory identifier.
  id: ID!

  # Directory name.
  name: String!

  # Directory description.
  description: String!

  # Is the default directory?
  isDefault: Boolean
  
  # Is the user password managed by WorkflowGen?
  isUserPasswordManaged: Boolean

  # Directory's list users.
  users (page: Page, orderBy: UserListOrder, filter: UserFilter): UserListPage!
  
  # Directory's list groups.
  groups (page: Page, orderBy: GroupListOrder): GroupListPage!

  # Directory synchronization connector.
  synchronizationConnector: DirectorySynchronizationConnector

}

# A paginated list of directories.
type DirectoryListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of directories.
  items: [Directory]
}

# A filter on directories.
input DirectoryFilter {

  # Filter by directory's name.
  nameContains: String

  # Filter by directory's synchronization connector.
  synchronizationConnector: DirectorySynchronizationConnector

}

# A directory list order.
input DirectoryListOrder {

  # Field to order directories by.
  field: DirectoryListOrderField
  
  # Ordering direction.
  direction: ListOrderDirection
}

# A list of fields to order a list of directories.
enum DirectoryListOrderField {
  
  # Order directories by name.
  NAME
}

# A list of synchronization connectors.
enum DirectorySynchronizationConnector {
  ADS
  TEXT
  LDAP
  AZURE_SCIM_V2
}

`;

module.exports = directoryTypeDefs;
