/**
 * favorite.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const favoriteTypeDefs = `

# A favorite.
type Favorite implements Node {

  # Favorite identifier.
  id: ID!

  # Identifies the user who added the favorite.
  owner: User!

  # Favorite description.
  description: String!
 
  # Favorite item.
  item: Node!

  # Favorite type.
  type: FavoriteType!
}

# Represent the possible favorite types.
enum FavoriteType {

  # Favorite of type Process.
  PROCESS

  # Favorite of type View.
  VIEW
}

# A paginated list of favorites.
type FavoriteListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of favorites.
  items: [Favorite]
}

# A filter on favorites.
input FavoriteFilter {
    
  # Filter favorites by type  
  type: FavoriteType
}

# A favorite list order.
input FavoriteListOrder {

  # Field to order favorites by.
  field: FavoriteListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# A list of fields to order a favorite list.
enum FavoriteListOrderField {

  # Order by type.
  TYPE
}

# A create favorite input.
input CreateFavoriteInput {

  # Client mutation identifier.
  clientMutationId: String

  # Favorite item.
  itemId: ID!

  # Favorite description.
  description: String
}

# A create favorite result.
type CreateFavoriteResult {

  # Client mutation identifier.
  clientMutationId: String

  # Favorite that has been created.
  favorite: Favorite!
}

# An update favorite input.
input UpdateFavoriteInput {

  # Client mutation identifier.
  clientMutationId: String

  # Favorite identifier.
  id: ID!
  
  # Favorite description.
  description: String
}

# An update favorite result.
type UpdateFavoriteResult {
  
  # Client mutation identifier.
  clientMutationId: String
  
  # The favorite that has been updated.
  favorite: Favorite!
}

# A delete favorite input.
input DeleteFavoriteInput {
  
  # Client mutation identifier.
  clientMutationId: String
  
  # Favorite identifier.
  id: ID!
}

# A delete favorite result.
type DeleteFavoriteResult {

  # Client mutation identifier.
  clientMutationId: String
}

`;

module.exports = favoriteTypeDefs;
