/**
 * mutation.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const mutationTypeDefs = `

# the schema allows the following mutation:
type Mutation {

  # Creates a new a request.
  createRequest (input: CreateRequestInput): CreateRequestResult

  # Cancels a request.
  cancelRequest (input: CancelRequestInput): CancelRequestResult
  
  # Deletes a request.
  deleteRequest (input: DeleteRequestInput): DeleteRequestResult

  # Updates request dataset.
  updateRequestDataset (input: UpdateRequestDatasetInput): UpdateRequestDatasetResult

  # Completes an action.
  completeAction (input: CompleteActionInput): CompleteActionResult

  # Completes a form action.
  completeFormAction (input: CompleteActionInput): CompleteActionResult

  # Assigns an action.
  assignAction (input: AssignActionInput): AssignActionResult

  # Cancels an action assignment
  cancelActionAssignment (input: CancelActionAssignmentInput): CancelActionAssignmentResult

  # Cancels an action.
  cancelAction (input: CancelActionInput): CancelActionResult

  # Cancels a request's actions by name.
  cancelRequestActionsByName (input: CancelRequestActionsByNameInput): CancelRequestActionsByNameResult
  
  # Creates a delegation.
  createDelegation (input: CreateDelegationInput): CreateDelegationResult

  # Updates a delegation.
  updateDelegation (input: UpdateDelegationInput): UpdateDelegationResult

  # Deletes a delegation.
  deleteDelegation (input: DeleteDelegationInput): DeleteDelegationResult

  # Adds a new comment.
  addComment (input: AddCommentInput): AddCommentResult

  # Removes a comment.
  removeComment (input: RemoveCommentInput): RemoveCommentResult  

  # Creates a favorite.
  createFavorite (input: CreateFavoriteInput): CreateFavoriteResult

  # Updates a favorite.
  updateFavorite (input: UpdateFavoriteInput): UpdateFavoriteResult

  # Deletes a favorite.
  deleteFavorite (input: DeleteFavoriteInput): DeleteFavoriteResult

  # Creates a new user.
  createUser (input: CreateUserInput): CreateUserResult

  # Updates a user.
  updateUser (input: UpdateUserInput): UpdateUserResult

  # Deletes a user.
  deleteUser (input: DeleteUserInput): DeleteUserResult
    
  # Updates the viewer preferences.
  updateViewerPreferences (input: UpdateViewerPreferencesInput): UpdateViewerPreferencesResult

  # Creates a new group.
  createGroup (input: CreateGroupInput): CreateGroupResult

  # Updates a group.
  updateGroup (input: UpdateGroupInput): UpdateGroupResult

  # Deletes a group.
  deleteGroup (input: DeleteGroupInput): DeleteGroupResult

  # Adds users to a group.
  addUsersToGroup (input: AddUsersToGroupInput): AddUsersToGroupResult

  # Removes users from a group.
  removeUsersFromGroup (input: RemoveUsersFromGroupInput): RemoveUsersFromGroupResult

  # Adds groups to a user.
  addGroupsToUser (input: AddGroupsToUserInput): AddGroupsToUserResult

  # Removes groups from a user.
  removeGroupsFromUser (input: RemoveGroupsFromUserInput): RemoveGroupsFromUserResult
}

`;

module.exports = mutationTypeDefs;
