/**
 * participant.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const participantTypeDefs = `

# An interface participant.
interface Participant {

  # Participant identifier.
  id: ID!

  # Participant name.
  name: String

  # Participant description.
  description: String!

  # Participant type.
  type: ParticipantType

  # List of the users associated to the participant.
  users(page: Page, orderBy: UserListOrder): UserListPage

  # List of the groups associated to the participant.
  groups(page: Page, orderBy: GroupListOrder): GroupListPage

  # List of the directories associated to the participant.
  directories(page: Page, orderBy: DirectoryListOrder): DirectoryListPage

  # List of the coordinators associated to the participant.
  coordinators(page: Page, orderBy: UserListOrder): UserListPage
}

# A global participant.
type GlobalParticipant implements Node, Participant {

  # Global participant identifier.
  id: ID!

  # Global participant name.
  name: String

  # Global participant description.
  description: String!

  # Global participant type.
  type: ParticipantType

  # List of the users associated to the global participant.
  users(page: Page, orderBy: UserListOrder): UserListPage

  # List of the groups associated to the global participant.
  groups(page: Page, orderBy: GroupListOrder): GroupListPage

  # List of the directories associated to the global participant.
  directories(page: Page, orderBy: DirectoryListOrder): DirectoryListPage

  # List of the coordinators associated to the global participant.
  coordinators(page: Page, orderBy: UserListOrder): UserListPage
}

# A local process participant.
type LocalProcessParticipant implements Node, Participant {

  # Local process participant identifier.
  id: ID!

  # Local process participant process.
  process: Process!

  # Local process participant name.
  name: String

  # Local process participant description.
  description: String!

  # Local process participant type.
  type: ParticipantType

  # List of the users associated to the local process participant.
  users(page: Page, orderBy: UserListOrder): UserListPage

  # List of the groups associated to the local process participant.
  groups(page: Page, orderBy: GroupListOrder): GroupListPage

  # List of the directories associated to the local process participant.
  directories(page: Page, orderBy: DirectoryListOrder): DirectoryListPage

  # List of the coordinators associated to the local process participant.
  coordinators(page: Page, orderBy: UserListOrder): UserListPage
}

# A paginated list of participants.
type ParticipantListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of participants.
  items: [Participant]
}

# A filter on participants.
input ParticipantFilter {

  # Indicates if the participant is global.
  isGlobal: Boolean
}

# A participant list order.
input ParticipantListOrder {

  # Field to order participants by.
  field: ParticipantListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order a participant list.
enum ParticipantListOrderField {

  # Order participants by name.
  NAME

  # Order participants by type.
  TYPE
}

# A list of participant's types.
enum ParticipantType {

  # Participant human type.
  HUMAN

  # Participant role type.
  ROLE

  # Participant coordinator type.
  COORDINATOR
}

`;

module.exports = participantTypeDefs;
