/**
 * process.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const processTypeDefs = `

# A process.
type Process implements Node {

  # Process identifier.
  id: ID!

  # Process name.
  name: String!

  # Process version.
  version: Int!

  # Process description.
  description: String!
  
  # Process state.
  state: ProcessState!
  
  # Process help information.
  help: Help
  
  # Identifies the date and time when the process was updated.
  updatedAt: DateTime!
  
  # Identifies the user who updated the process.
  updatedBy: User!
  
  # URL to launch a new request.
  launchUrl: URI
  
  # URL to launch a new request with the portal displayed.
  launchPortalUrl: URI

  # URL to display the graphical view of the process.
  graphicalViewUrl: URI

  # URL to display the graphical view of the process displayed in the portal.
  graphicalViewPortalUrl: URI
  
  # Categories associated to the process.
  categories(page: Page, orderBy: CategoryListOrder, filter: CategoryFilter): CategoryListPage!
  
  # Activities associated to the process.
  activities(page: Page, orderBy: ActivityListOrder, filter: ActivityFilter): ActivityListPage!
  
  # Data associated to the process.
  dataset(page: Page, orderBy: ProcessDataListOrder): ProcessDataListPage!

  # Participants associated to the process.
  participants(page:Page, filter: ParticipantFilter, orderBy: ParticipantListOrder): ParticipantListPage!

  # Participant profiles associated to the process.
  participantProfiles(page: Page, orderBy: ProcessParticipantProfileListOrder): ProcessParticipantProfileListPage!

  # Indicates if the user has permissions to launch a new request.
  canCreateRequest: Boolean
  
  # Indicates if the user has graphical view access.
  hasGraphicalViewAccess: Boolean
}

# A paginated list of processes.
type ProcessListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of processes.
  items: [Process]
}

# A filter on processes.
input ProcessFilter {

  # Filter by state.
  state: ProcessState

  # Filter by category identifier.
  categoryId: ID

  # Filter by category name.
  categoryName: String
}

# A filter on launchable processes.
input LaunchableProcessFilter {

  # Filter by category identifier.
  categoryId: ID

  # Filter by category name.
  categoryName: String

}

# A process list order.
input ProcessListOrder {

  # Field to order processes by.
  field: ProcessListOrderField

  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order a process list.
enum ProcessListOrderField {

  # Order processes by name.
  NAME

  # Order processes by when they were updated.
  UPDATED_AT
}

# List possible process state.
enum ProcessState {

  # In development.
  DEV

  # In test.
  TEST

  # Active.
  ACTIVE

  # Archived.
  ARCHIVE
}

`;

module.exports = processTypeDefs;
