/**
 * processdata.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const processDataTypeDefs = `

# A process data
type ProcessData implements Node, WorkflowData {

  # Process data identifier.
  id: ID!

  # Process data name.
  name: String!
 
  # Process data description.
  description: String!

  # Process data type.
  type: WorkflowDataType!

  # Process data text value.
  textValue: String

  # Process data numeric value.
  numericValue: Float

  # Process data date and time value.
  dateTimeValue: DateTime

  # Process data file value.
  fileValue: File 

  # Indicates the direction when the process data is a subprocess parameter.
  direction: ParameterDirection

  # Indicates if the process data has a value.
  hasValue: Boolean!

  # Process associated to the process data.
  process: Process!
  
}

# A paginated list of process data.
type ProcessDataListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of process data.
  items: [ProcessData]
}

# A process data list order.
input ProcessDataListOrder {

  # Field to order process data by.
  field: ProcessDataListOrderField
  
  # Ordering direction.
  direction: ListOrderDirection
}

# List possible fields to order a process data list.
enum ProcessDataListOrderField {

  # Order process data by name.
  NAME

  # Order process data by description.
  DESCRIPTION

  # Order process data by display order.
  DISP_ORDER
}

`;

module.exports = processDataTypeDefs;
