/**
 * processparticipantprofile.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const processParticipantProfileTypeDefs = `

# A process participant profile.
type ProcessParticipantProfile implements Node {

  # Process participant profile identifier.
  id: ID!

  # Process participant profile process.
  process: Process!
  
  # Process participant profile participant.
  participant: Participant!

  # Process participant profile role.
  role: ProcessParticipantProfileRole!

  # Indicates if the participant profile has permissions to view the graphical follow-up.
  canViewGraphicalFollowup: Boolean!

  # Indicates if the participant profile has permissions to reassign actions.
  canReassignActions: Boolean!
    
  # Indicates if the participant profile has permissions to cancel requests.
  canCancelRequests: Boolean!

  # Indicates if the participant profile has permissions to view statistics.
  canViewStatistics: Boolean!

  # Indicates if the participant profile has permissions to read comments.
  canReadComments: Boolean!

  # Indicates if the participant profile has permissions to write comments.
  canWriteComments: Boolean!

  # Process participant profile query.
  query: String
}

# A paginated list of process participant profiles.
type ProcessParticipantProfileListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!

  # List of process participant profiles.
  items: [ProcessParticipantProfile]
}

# A process participant profile list order.
input ProcessParticipantProfileListOrder {

  # Field to order process participant profiles by.
  field: ProcessParticipantProfileListOrderField
         
  # Ordering direction.
  direction: ListOrderDirection
}

# List of possible fields to order a process participant profile list.
enum ProcessParticipantProfileListOrderField {

  # Order process participant profiles by name.
  NAME

  # Order process participant profiles by type.
  TYPE

  # Order process participant profiles by role.
  ROLE

  # Order process participant profiles by display order.
  DISP_ORDER
}

# A list of participant process profile' roles.
enum ProcessParticipantProfileRole {

  # Process participant profile requester role.
  REQUESTER

  # Process participant profile actor role.
  ACTOR

  # Process participant profile supervisor role.
  SUPERVISOR
}

`;

module.exports = processParticipantProfileTypeDefs;
