/**
 * requestdata.js
 * GraphQL Type definitions using schema language
 */
'use strict';

const requestDataTypeDefs = `

# A request data.
type RequestData implements Node, WorkflowData {

  # Request data identifier.
  id: ID!
  
  # Request data name.
  name: String!

  # Request data description.
  description: String!

  # Request data type.
  type: WorkflowDataType!  

  # Request data text value.
  textValue: String

  # Request data numeric value.
  numericValue: Float

  # Request data date and time value.
  dateTimeValue: DateTime

  # Request data file value.
  fileValue: File

  # Indicates if the request data has a value.
  hasValue: Boolean!

  # Request associated to the request data.
  request: Request!
}

# A paginated list of request data.
type RequestDataListPage {

  # Identifies the total count of items in the page.
  totalCount: Int!

  # Indicates if there are more pages to fetch.
  hasNextPage: Boolean!

  # Indicates if there are any pages prior to the current page.
  hasPreviousPage: Boolean!
  
  # List of request data.
  items: [RequestData]
}

# A filter on requests data.
input RequestDataFilter {

  # Filter request data by type.
  type: WorkflowDataType

  # Filter request data by name.
  names: [String]
}

# A request data list order.
input RequestDataListOrder {
 
  # Field to order request data by.
  field: RequestDataListOrderField
 
  # Ordering direction.
  direction: ListOrderDirection
}

# List possible fields to order a request data list.
enum RequestDataListOrderField {

  # Order request data by name.
  NAME

  # Order request data by type.
  TYPE

  # Order request data by display order.
  DISP_ORDER
}

# An update request dataset input.
input UpdateRequestDatasetInput {

  # Client mutation identifier.
  clientMutationId: String

  # Request identifier.
  id: ID

  # Request number.
  number: Int

  # Array of parameters.
  parameters: [ParameterInput]
}

# An update request dataset result.
type UpdateRequestDatasetResult {

  # Client mutation identifier.
  clientMutationId: String

  # Request data that have been updated.
  dataset: RequestDataListPage!
}


`;

module.exports = requestDataTypeDefs;
