/**
 * config.production.js
 * This file contains the initialization of the configuration.
 */
'use strict';
const path = require('path');
const { logger } = require('./utils/logger.js');

var config = {
  app: {
    port: process.env.PORT || 8080
  },
  hooks: {
    debugEnabled: process.env.HooksDebugEnabled ? (process.env.HooksDebugEnabled === 'Y') : false,
    maxRequestBodySize: 100,
    operations: [
      'createRequest',
      'cancelRequest',
      'updateRequestDataset',
      'completeAction',
      'cancelAction',
      'cancelRequestActionsByName',
      'assignAction',
      'cancelActionAssignment',
      'createFavorite',
      'updateFavorite',
      'deleteFavorite',
      'addComment',
      'removeComment'
    ]
  },
  workflowService: {
    debugEnabled: process.env.HooksDebugEnabled ? (process.env.HooksDebugEnabled === 'Y') : false,
    configFilePath: path.normalize(path.join(__dirname, '../web.config')),
    serviceAssemblyFilePath: path.normalize(path.join(__dirname, '../bin/Advantys.workflow.dll')),
    logHandler: (text) => logger('DEBUG', text),
    operationTimeout: process.env.HooksOperationTimeout ? parseInt(process.env.HooksOperationTimeout) : 30000,
    maxOperationCount: process.env.HooksMaxOperationCount ? parseInt(process.env.HooksMaxOperationCount) : 10000,
    maxInputFileSize: process.env.HooksMaxInputFileSize ? parseInt(process.env.HooksMaxInputFileSize) : 10240,
    maxInputFileContentSize: process.env.HooksMaxInputFileContentSize ? parseInt(process.env.HooksMaxInputFileContentSize) : 0,
    inputFileDownloadTimeout: process.env.HooksInputFileDownloadTimeout ? parseInt(process.env.HooksInputFileDownloadTimeout) : 100000,
    maxOperationRetries: process.env.HooksMaxOperationRetries ? parseInt(process.env.HooksMaxOperationRetries) : 20,
    operationRetryDelay: process.env.HooksOperationRetryDelay ? parseInt(process.env.HooksOperationRetryDelay) : 200,
    inputFileAllowedFolders: process.env.HooksInputFileAllowedFolders || ''
  }
};

module.exports = config;
