/**
 * config.production.js
 * This file contains the initialization of the configuration.
 */
'use strict';
const path = require('path');
const { logger } = require('./utils/altlogger');

const APP_DATA_PATH = process.env.ApplicationDataPath
  ? process.env.ApplicationDataPath
  : path.normalize(path.join(__dirname, '../App_Data'));

var config = {
  app: {
    port: process.env.PORT || 8080,
    dataPath: APP_DATA_PATH,
    logsPath: path.join(APP_DATA_PATH, 'logFiles', 'dir', 'synchro'),
    cacheEnabled: true,
    cacheMaxAge: 15 // seconds
  },
  workflowService: {
    debugEnabled: process.env.ScimDebugEnabled ? (process.env.ScimDebugEnabled === 'Y') : false,
    configFilePath: process.env.ScimWfgenConfigFilePath
      ? path.normalize(process.env.ScimWfgenConfigFilePath)
      : path.normalize(path.join(__dirname, '/../web.config')),
    serviceAssemblyFilePath: process.env.ScimWfgenAssemblyFilePath
      ? path.normalize(process.env.ScimWfgenAssemblyFilePath)
      : path.normalize(path.join(__dirname, '/../bin/Advantys.workflow.dll')),
    logHandler: (text) => logger.console.debug(text),
    operationTimeout: process.env.ScimOperationTimeout ? parseInt(process.env.ScimOperationTimeout) : 30000,
    maxOperationCount: process.env.ScimMaxOperationCount ? parseInt(process.env.ScimMaxOperationCount) : 10000,
    maxInputFileSize: process.env.ScimMaxInputFileSize ? parseInt(process.env.ScimMaxInputFileSize) : 10240,
    inputFileDownloadTimeout: process.env.ScimInputFileDownloadTimeout ? parseInt(process.env.ScimInputFileDownloadTimeout) : 100000,
    maxOperationRetries: process.env.ScimMaxOperationRetries ? parseInt(process.env.ScimMaxOperationRetries) : 20,
    operationRetryDelay: process.env.ScimOperationRetryDelay ? parseInt(process.env.ScimOperationRetryDelay) : 200
  }
};

module.exports = config;
