/**
 * group.js
 * Definition of a group resource.
*/
'use strict';

const constants = require('../models/constants');
const Resource = require('./resource');

/**
 * Represents a group resource.
 * @class GroupResource
 */
class GroupResource extends Resource {
  /**
   * Creates an instance of GroupResource.
   */
  constructor (obj = null) {
    super('Group');
    this.schemas = [constants.schemas.group];
    this._requiredAttributes.push('displayName');

    if (obj) {
      for (let prop in obj) {
        this[prop] = obj[prop];
      }
    }
  }

  /**
   * @description Adds the full url location to the representation.
   * @param {String} baseUrl The base url of the resource.
   * @memberOf GroupResource
   */
  addUrlLocation (baseUrl) {
    this.meta.location = `${baseUrl}/${this.id}`;

    if (this.members) {
      this.members.forEach(member => {
        member.$ref = `${baseUrl.replace('Groups', 'Users')}/${member.value}`;
      });
    }
  }
}

/**
 * Represents a WorkflowGen Group.
 * @class WFGGroup
 */
class WFGGroup {}

module.exports = {
  GroupResource,
  WFGGroup
};
