/**
* logger.js
* Contains some helpers for logging messages.
*/
'use strict';
const { logger } = require('../../utils/altlogger');

/**
 * This function logs a message to the synchronization log. Since getting the
 * name of the directory is asynchronous, this function takes care of the problem
 * for you. You just have to call this synchronously like any normal log.
 * @param {String} action The WFG action to log.
 * @param {Object} directory The directory object that performs the action.
 * @param {String} message String or format for string that represents the message to log.
 */
function logToFile (action, directory, ...message) {
  directory.getInfo()
    .then(info => {
      logger.file.info(...message, {action: action, directory: info.name});
    })
    .catch(err => logger.console.error(err.message));
}

/**
 * Contains the possible actions of user and group provisionning.
 * This object is to be used with the logger.
 */
class Actions {
  static get GENERAL () {
    return 'GENERAL';
  }

  static get USER () {
    return 'USER';
  }

  static get USER_ADD () {
    return 'USER/ADD';
  }

  static get USER_UPDATE () {
    return 'USER/UPDATE';
  }

  static get USER_DELETE () {
    return 'USER/DELETE';
  }

  static get USER_ERROR () {
    return 'USER/ERROR';
  }

  static get GROUP () {
    return 'GROUP';
  }

  static get GROUP_ADD () {
    return 'GROUP/ADD';
  }

  static get GROUP_UPDATE () {
    return 'GROUP/UPDATE';
  }

  static get GROUP_DELETE () {
    return 'GROUP/DELETE';
  }

  static get GROUP_ERROR () {
    return 'GROUP/ERROR';
  }

  static get HIERARCHY () {
    return 'HIERARCHY';
  }

  static get HIERARCHY_ERROR () {
    return 'HIERARCHY_ERROR';
  }
}

module.exports = {
  logToFile,
  Actions
};
