/**
* grouptranslator.js
* Contains the definition of the GroupTranslator class.
*/
'use strict';
const Translator = require('./translator');
const WFGGroup = require('../group').WFGGroup;
const GroupResource = require('../group').GroupResource;
const UserTranslator = require('./usertranslator');

/**
 * Concrete Group translator.
 */
class GroupTranslator extends Translator {
  /**
   * @see {@link Translator#_getSCIMAttributesMap}
   */
  _getSCIMAttributesMap () {
    return new Map([
      ['id', 'id'],
      ['displayName', 'name'],
      ['members', 'users'],
      ['externalId', 'systemIdentifier']
    ]);
  }

  /**
   * @see {@link Translator#_translateToWFG}
   */
  _translateToWFG (object) {
    let group = new WFGGroup();

    group.id = object.id;
    group.name = object.displayName;
    group.systemIdentifier = object.externalId;

    if (object.members) {
      // TODO: Better translation with correct member items.
      group.users = object.members.map(m => new UserTranslator(UserTranslator.SCIM_TO_WFG_TYPE, m).translate());
    }

    Object.cleanProperties(group, false);
    return group;
  }

  /**
   * @see {@link Translator#_translateToSCIM}
   */
  _translateToSCIM (object) {
    let group = new GroupResource();

    group.id = object.id;
    group.displayName = object.name;
    group.externalId = object.systemIdentifier;

    if (object.users) {
      // TODO: Better translation with correct member items.
      group.members = object.users.map(u => new UserTranslator(UserTranslator.WFG_TO_SCIM_TYPE, u).translate());
    }

    Object.cleanProperties(group, false);
    return group;
  }
}

module.exports = GroupTranslator;
