'use strict';

/**
 * Groups an array by a property.
 * @see {@link http://codereview.stackexchange.com/a/37132}
 * @param {Array} array The array to group.
 * @param {Function} f The grouping function.
 * @return {Array} The grouped by array.
 */
function groupBy (array, f) {
  var groups = {};
  array.forEach(function (o) {
    var group = JSON.stringify(f(o));
    groups[group] = groups[group] || [];
    groups[group].push(o);
  });

  return Object.keys(groups).map(function (group) {
    return groups[group];
  });
}

/**
 * @desc Gets the values common in the two arrays.
 * @param {Array} array1 The array to filter.
 * @param {Array} array2 The array to compare array1 with.
 * @return {Array} An array containing the common elements between the two arrays.
 */
function intersect (array1, array2) {
  return array1.filter(e => array2.includes(e));
}

module.exports = {
  groupBy,
  intersect
};
