/**
 * extensions.js
 * Contains extension methods to add functionality to base objects.
 */
const express = require('express');

/**
* Cleans an object of null properties. Recursive function.
* @param {Object} objectToClean The object to clean.
* @param {bool} cleanAll Clean undefined and null if true. Only undefined if false.
*/
Object.cleanProperties = function (objectToClean, cleanAll = true) {
  if (typeof objectToClean !== 'object') {
    return;
  }

  for (let key in objectToClean) {
    if (typeof objectToClean[key] === 'undefined') {
      delete objectToClean[key];
    } else if (cleanAll && objectToClean[key] === null) {
      delete objectToClean[key];
    } else if (objectToClean[key] instanceof Array &&
      (cleanAll && (objectToClean[key].length <= 0 || key === '_requiredAttributes'))) { // Empty array
      delete objectToClean[key];
    } else if (objectToClean[key] instanceof Array) {
      for (let value of objectToClean[key]) {
        Object.cleanProperties(value, cleanAll); // All values in array of a user are objects.
      }
    } else if (typeof objectToClean[key] === 'object' &&
        objectToClean[key] !== null &&
        !(objectToClean[key] instanceof Date) &&
        Object.keys(objectToClean[key]) <= 0) { // Empty object
      delete objectToClean[key];
    } else if (typeof objectToClean[key] === 'object') {
      Object.cleanProperties(objectToClean[key], cleanAll);
    }
  }
};

/**
 * Simple test to check is an object is assigned.
 * @param {Object} object The object to check.
 * @return {Boolean} If the object is assigned.
 */
Object.isNullOrUndefined = function (object) {
  return typeof object === 'undefined' || object === null;
};

/**
 * Returns the base URL of the Express request.
 * @return {String} The URL.
 */
express.request.getBaseUrl = function () {
  return `${'encrypted' in this.connection ? 'https://' : 'http://'}${this.headers.host}${this.baseUrl}`;
};
